@@ -3,8 +3,8 @@ package main
 import (
 	"fmt"
 
-	"github.com/johnkerl/miller/pkg/bifs"
-	"github.com/johnkerl/miller/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/bifs"
+	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
 func main() {
