@@ -1,6 +1,4 @@
-// ================================================================
 // Boolean expressions for ==, !=, >, >=, <, <=
-// ================================================================
 
 package bifs
 
@@ -11,31 +9,27 @@ import (
 func BIF_logical_NOT(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsBool() {
 		return mlrval.FromBool(!input1.AcquireBoolValue())
-	} else {
-		return mlrval.FromTypeErrorUnary("!", input1)
 	}
+	return mlrval.FromTypeErrorUnary("!", input1)
 }
 
 func BIF_logical_AND(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsBool() && input2.IsBool() {
 		return mlrval.FromBool(input1.AcquireBoolValue() && input2.AcquireBoolValue())
-	} else {
-		return mlrval.FromTypeErrorUnary("&&", input1)
 	}
+	return mlrval.FromTypeErrorUnary("&&", input1)
 }
 
 func BIF_logical_OR(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsBool() && input2.IsBool() {
 		return mlrval.FromBool(input1.AcquireBoolValue() || input2.AcquireBoolValue())
-	} else {
-		return mlrval.FromTypeErrorUnary("||", input1)
 	}
+	return mlrval.FromTypeErrorUnary("||", input1)
 }
 
 func BIF_logical_XOR(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsBool() && input2.IsBool() {
 		return mlrval.FromBool(input1.AcquireBoolValue() != input2.AcquireBoolValue())
-	} else {
-		return mlrval.FromTypeErrorUnary("^^", input1)
 	}
+	return mlrval.FromTypeErrorUnary("^^", input1)
 }
