@@ -9,7 +9,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
-// ================================================================
 // Map/array count. Scalars (including strings) have length 1; strlen is for string length.
 func BIF_length(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	switch input1.Type() {
@@ -27,7 +26,6 @@ func BIF_length(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromInt(1)
 }
 
-// ================================================================
 func depth_from_array(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	maxChildDepth := int64(0)
 	arrayval := input1.AcquireArrayValue()
@@ -89,7 +87,6 @@ func BIF_depth(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	return depth_dispositions[input1.Type()](input1)
 }
 
-// ================================================================
 func leafcount_from_array(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	sumChildLeafCount := int64(0)
 	arrayval := input1.AcquireArrayValue()
@@ -160,7 +157,6 @@ func BIF_leafcount(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	return leafcount_dispositions[input1.Type()](input1)
 }
 
-// ----------------------------------------------------------------
 func has_key_in_array(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input2.IsString() {
 		return mlrval.FALSE
@@ -176,9 +172,8 @@ func has_key_in_array(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 func has_key_in_map(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input2.IsString() || input2.IsInt() {
 		return mlrval.FromBool(input1.AcquireMapValue().Has(input2.String()))
-	} else {
-		return mlrval.FromNotNamedTypeError("haskey", input2, "string or int")
 	}
+	return mlrval.FromNotNamedTypeError("haskey", input2, "string or int")
 }
 
 func BIF_haskey(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -186,12 +181,10 @@ func BIF_haskey(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 		return has_key_in_array(input1, input2)
 	} else if input1.IsMap() {
 		return has_key_in_map(input1, input2)
-	} else {
-		return mlrval.FromNotCollectionError("haskey", input1)
 	}
+	return mlrval.FromNotCollectionError("haskey", input1)
 }
 
-// ================================================================
 func BIF_concat(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	output := mlrval.FromEmptyArray()
 
@@ -209,7 +202,6 @@ func BIF_concat(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ================================================================
 func BIF_mapselect(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	if len(mlrvals) < 1 {
 		return mlrval.FromErrorString("mapselect: received a zero-length array as input")
@@ -250,7 +242,6 @@ func BIF_mapselect(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromMap(newMap)
 }
 
-// ----------------------------------------------------------------
 func BIF_mapexcept(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	if len(mlrvals) < 1 {
 		return mlrval.FromErrorString("mapexcept: received a zero-length array as input")
@@ -281,7 +272,6 @@ func BIF_mapexcept(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromMap(newMap)
 }
 
-// ----------------------------------------------------------------
 func BIF_mapsum(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	if len(mlrvals) == 0 {
 		return mlrval.FromEmptyMap()
@@ -307,7 +297,6 @@ func BIF_mapsum(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromMap(newMap)
 }
 
-// ----------------------------------------------------------------
 func BIF_mapdiff(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	if len(mlrvals) == 0 {
 		return mlrval.FromEmptyMap()
@@ -333,7 +322,6 @@ func BIF_mapdiff(mlrvals []*mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromMap(newMap)
 }
 
-// ================================================================
 // joink([1,2,3], ",") -> "1,2,3"
 // joink({"a":3,"b":4,"c":5}, ",") -> "a,b,c"
 func BIF_joink(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -364,12 +352,10 @@ func BIF_joink(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 
 		return mlrval.FromString(buffer.String())
-	} else {
-		return mlrval.FromNotCollectionError("joink", input1)
 	}
+	return mlrval.FromNotCollectionError("joink", input1)
 }
 
-// ----------------------------------------------------------------
 // joinv([3,4,5], ",") -> "3,4,5"
 // joinv({"a":3,"b":4,"c":5}, ",") -> "3,4,5"
 func BIF_joinv(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -400,12 +386,10 @@ func BIF_joinv(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 
 		return mlrval.FromString(buffer.String())
-	} else {
-		return mlrval.FromNotCollectionError("joinv", input1)
 	}
+	return mlrval.FromNotCollectionError("joinv", input1)
 }
 
-// ----------------------------------------------------------------
 // joinkv([3,4,5], "=", ",") -> "1=3,2=4,3=5"
 // joinkv({"a":3,"b":4,"c":5}, "=", ",") -> "a=3,b=4,c=5"
 func BIF_joinkv(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -445,12 +429,10 @@ func BIF_joinkv(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 
 		return mlrval.FromString(buffer.String())
-	} else {
-		return mlrval.FromNotCollectionError("joinkv", input1)
 	}
+	return mlrval.FromNotCollectionError("joinkv", input1)
 }
 
-// ================================================================
 // splitkv("a=3,b=4,c=5", "=", ",") -> {"a":3,"b":4,"c":5}
 func BIF_splitkv(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsStringOrVoid() {
@@ -485,7 +467,6 @@ func BIF_splitkv(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ----------------------------------------------------------------
 // splitkvx("a=3,b=4,c=5", "=", ",") -> {"a":"3","b":"4","c":"5"}
 func BIF_splitkvx(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsStringOrVoid() {
@@ -521,7 +502,6 @@ func BIF_splitkvx(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ----------------------------------------------------------------
 // splitnv("a,b,c", ",") -> {"1":"a","2":"b","3":"c"}
 func BIF_splitnv(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsStringOrVoid() {
@@ -543,7 +523,6 @@ func BIF_splitnv(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ----------------------------------------------------------------
 // splitnvx("3,4,5", ",") -> {"1":"3","2":"4","3":"5"}
 func BIF_splitnvx(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsStringOrVoid() {
@@ -565,7 +544,6 @@ func BIF_splitnvx(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ----------------------------------------------------------------
 // splita("3,4,5", ",") -> [3,4,5]
 func BIF_splita(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsLegit() {
@@ -589,7 +567,6 @@ func BIF_splita(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromArray(arrayval)
 }
 
-// ----------------------------------------------------------------
 // BIF_splitax splits a string to an array, without type-inference:
 // e.g. splitax("3,4,5", ",") -> ["3","4","5"]
 func BIF_splitax(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -619,7 +596,6 @@ func bif_splitax_helper(input string, separator string) *mlrval.Mlrval {
 	return mlrval.FromArray(arrayval)
 }
 
-// ----------------------------------------------------------------
 func BIF_get_keys(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsMap() {
 		// TODO: make a ReferenceFrom with comments
@@ -640,12 +616,10 @@ func BIF_get_keys(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 		return mlrval.FromArray(arrayval)
 
-	} else {
-		return mlrval.FromNotCollectionError("get_keys", input1)
 	}
+	return mlrval.FromNotCollectionError("get_keys", input1)
 }
 
-// ----------------------------------------------------------------
 func BIF_get_values(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsMap() {
 		mapval := input1.AcquireMapValue()
@@ -665,12 +639,10 @@ func BIF_get_values(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 		return mlrval.FromArray(arrayval)
 
-	} else {
-		return mlrval.FromNotCollectionError("get_values", input1)
 	}
+	return mlrval.FromNotCollectionError("get_values", input1)
 }
 
-// ----------------------------------------------------------------
 func BIF_append(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	if !input1.IsArray() {
 		return mlrval.FromNotArrayError("append", input1)
@@ -681,7 +653,6 @@ func BIF_append(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return output
 }
 
-// ----------------------------------------------------------------
 // First argument is prefix.
 // Second argument is delimiter.
 // Third argument is map or array.
@@ -700,9 +671,8 @@ func BIF_flatten(input1, input2, input3 *mlrval.Mlrval) *mlrval.Mlrval {
 
 		retval := input3.FlattenToMap(prefix, delimiter)
 		return &retval
-	} else {
-		return input3
 	}
+	return input3
 }
 
 // flatten($*, ".") is the same as flatten("", ".", $*)
@@ -710,7 +680,6 @@ func BIF_flatten_binary(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return BIF_flatten(mlrval.VOID, input2, input1)
 }
 
-// ----------------------------------------------------------------
 // First argument is a map.
 // Second argument is a delimiter string.
 // unflatten({"a.b.c", ".") is {"a": { "b": { "c": 4}}}.
@@ -727,7 +696,6 @@ func BIF_unflatten(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromMap(newmap)
 }
 
-// ----------------------------------------------------------------
 // Converts maps with "1", "2", ... keys into arrays. Recurses nested data structures.
 func BIF_arrayify(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsMap() {
@@ -756,9 +724,8 @@ func BIF_arrayify(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 			}
 			return mlrval.FromArray(arrayval)
 
-		} else {
-			return input1
 		}
+		return input1
 
 	} else if input1.IsArray() {
 		// TODO: comment (or rethink) that this modifies its inputs!!
@@ -769,34 +736,30 @@ func BIF_arrayify(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 		}
 		return output
 
-	} else {
-		return input1
 	}
+	return input1
 }
 
-// ----------------------------------------------------------------
 func BIF_json_parse(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	if input1.IsVoid() {
 		return input1
 	} else if !input1.IsString() {
 		return mlrval.FromNotStringError("json_parse", input1)
-	} else {
-		output := mlrval.FromPending()
-		err := output.UnmarshalJSON([]byte(input1.AcquireStringValue()))
-		if err != nil {
-			return mlrval.FromError(err)
-		}
-		return output
 	}
+	output := mlrval.FromPending()
+	err := output.UnmarshalJSON([]byte(input1.AcquireStringValue()))
+	if err != nil {
+		return mlrval.FromError(err)
+	}
+	return output
 }
 
 func BIF_json_stringify_unary(input1 *mlrval.Mlrval) *mlrval.Mlrval {
 	outputBytes, err := input1.MarshalJSON(mlrval.JSON_SINGLE_LINE, false)
 	if err != nil {
 		return mlrval.FromError(err)
-	} else {
-		return mlrval.FromString(string(outputBytes))
 	}
+	return mlrval.FromString(string(outputBytes))
 }
 
 func BIF_json_stringify_binary(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
@@ -812,9 +775,8 @@ func BIF_json_stringify_binary(input1, input2 *mlrval.Mlrval) *mlrval.Mlrval {
 	outputBytes, err := input1.MarshalJSON(jsonFormatting, false)
 	if err != nil {
 		return mlrval.FromError(err)
-	} else {
-		return mlrval.FromString(string(outputBytes))
 	}
+	return mlrval.FromString(string(outputBytes))
 }
 
 func unaliasArrayIndex(array *[]*mlrval.Mlrval, mindex int) (int, bool) {
@@ -859,20 +821,17 @@ func unaliasArrayLengthIndex(n int, mindex int) (int, bool) {
 		zindex := mindex - 1
 		if mindex <= n { // in bounds
 			return zindex, true
-		} else { // out of bounds
-			return zindex, false
-		}
+		} // out of bounds
+		return zindex, false
 	} else if mindex <= -1 {
 		zindex := mindex + n
 		if -n <= mindex { // in bounds
 			return zindex, true
-		} else { // out of bounds
-			return zindex, false
-		}
-	} else {
-		// mindex is 0
-		return -1, false
+		} // out of bounds
+		return zindex, false
 	}
+	// mindex is 0
+	return -1, false
 }
 
 // MillerSliceAccess is code shared by the string-slicer and the array-slicer.
