@@ -8,7 +8,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
-// ----------------------------------------------------------------
 // We would need a second pass through the data to compute the error-bars given
 // the data and the m and the b.
 //
@@ -24,7 +23,6 @@ import (
 //
 //	output = [m, b, math.sqrt(var_m), math.sqrt(var_b)]
 
-// ----------------------------------------------------------------
 func BIF_finalize_variance(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	n, isInt := mn.GetIntValue()
 	lib.InternalCodingErrorIf(!isInt)
@@ -46,7 +44,6 @@ func BIF_finalize_variance(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return mlrval.FromFloat(numerator / denominator)
 }
 
-// ----------------------------------------------------------------
 func BIF_finalize_stddev(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	mvar := BIF_finalize_variance(mn, msum, msum2)
 	if mvar.IsVoid() {
@@ -55,7 +52,6 @@ func BIF_finalize_stddev(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return BIF_sqrt(mvar)
 }
 
-// ----------------------------------------------------------------
 func BIF_finalize_mean_eb(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	mvar := BIF_finalize_variance(mn, msum, msum2)
 	if mvar.IsVoid() {
@@ -64,7 +60,6 @@ func BIF_finalize_mean_eb(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 	return BIF_sqrt(BIF_divide(mvar, mn))
 }
 
-// ----------------------------------------------------------------
 // Unbiased estimator:
 //    (1/n)   sum{(xi-mean)**3}
 //  -----------------------------
@@ -87,7 +82,6 @@ func BIF_finalize_mean_eb(mn, msum, msum2 *mlrval.Mlrval) *mlrval.Mlrval {
 //   = sumx2 - 2 n mean^2 + n mean^2
 //   = sumx2 - n mean^2
 
-// ----------------------------------------------------------------
 func BIF_finalize_skewness(mn, msum, msum2, msum3 *mlrval.Mlrval) *mlrval.Mlrval {
 	n, isInt := mn.GetIntValue()
 	lib.InternalCodingErrorIf(!isInt)
@@ -124,7 +118,6 @@ func BIF_finalize_skewness(mn, msum, msum2, msum3 *mlrval.Mlrval) *mlrval.Mlrval
 //   = sumx4 - mean*(4 sumx3 - 6 mean sumx2 + 3 n mean^3)
 //   = sumx4 - mean*(4 sumx3 - mean*(6 sumx2 - 3 n mean^2))
 
-// ----------------------------------------------------------------
 func BIF_finalize_kurtosis(mn, msum, msum2, msum3, msum4 *mlrval.Mlrval) *mlrval.Mlrval {
 	n, isInt := mn.GetIntValue()
 	lib.InternalCodingErrorIf(!isInt)
@@ -151,7 +144,6 @@ func BIF_finalize_kurtosis(mn, msum, msum2, msum3, msum4 *mlrval.Mlrval) *mlrval
 
 }
 
-// ================================================================
 // STATS ROUTINES -- other than min/max which are placed separately.
 
 // This is a helper function for BIFs which operate only on array or map.
@@ -188,30 +180,28 @@ func collection_sum_of_function(
 }
 
 func BIF_count(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "count")
+	ok, valueIfNot := check_collection(collection, "count")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	if collection.IsArray() {
 		arrayval := collection.AcquireArrayValue()
 		return mlrval.FromInt(int64(len(arrayval)))
-	} else {
-		mapval := collection.AcquireMapValue()
-		return mlrval.FromInt(mapval.FieldCount)
 	}
+	mapval := collection.AcquireMapValue()
+	return mlrval.FromInt(mapval.FieldCount)
 }
 
 func BIF_null_count(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "null_count")
+	ok, valueIfNot := check_collection(collection, "null_count")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	f := func(element *mlrval.Mlrval) *mlrval.Mlrval {
 		if element.IsVoid() || element.IsNull() {
 			return mlrval.FromInt(1)
-		} else {
-			return mlrval.FromInt(0)
 		}
+		return mlrval.FromInt(0)
 	}
 	return mlrval.CollectionFold(
 		collection,
@@ -223,9 +213,9 @@ func BIF_null_count(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_distinct_count(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "distinct_count")
+	ok, valueIfNot := check_collection(collection, "distinct_count")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	counts := make(map[string]int)
 	if collection.IsArray() {
@@ -257,20 +247,20 @@ func bif_mode_or_antimode(
 	funcname string,
 	cmp func(int, int) bool,
 ) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, funcname)
+	ok, valueIfNot := check_collection(collection, funcname)
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 
 	// Do not use a Go map[string]int as that makes the output in the case of ties
 	// (e.g. input = [3,3,4,4]) non-determinstic. That's bad for unit tests and also
 	// simply bad UX.
-	counts := lib.NewOrderedMap()
+	counts := lib.NewOrderedMap[int]()
 
 	// We use stringification to detect uniqueness. Yet we want the output to be typed,
 	// e.g. mode of an array of ints should be an int, not a string. Here we store
 	// a reference to one representative for each equivalence class.
-	reps := lib.NewOrderedMap()
+	reps := lib.NewOrderedMap[*mlrval.Mlrval]()
 
 	if collection.IsArray() {
 		a := collection.AcquireArrayValue()
@@ -280,7 +270,7 @@ func bif_mode_or_antimode(
 		for _, e := range a {
 			valueString := e.OriginalString()
 			if counts.Has(valueString) {
-				counts.Put(valueString, counts.Get(valueString).(int)+1)
+				counts.Put(valueString, counts.Get(valueString)+1)
 			} else {
 				counts.Put(valueString, 1)
 				reps.Put(valueString, e)
@@ -294,7 +284,7 @@ func bif_mode_or_antimode(
 		for pe := m.Head; pe != nil; pe = pe.Next {
 			valueString := pe.Value.OriginalString()
 			if counts.Has(valueString) {
-				counts.Put(valueString, counts.Get(valueString).(int)+1)
+				counts.Put(valueString, counts.Get(valueString)+1)
 			} else {
 				counts.Put(valueString, 1)
 				reps.Put(valueString, pe.Value)
@@ -306,22 +296,21 @@ func bif_mode_or_antimode(
 	maxv := -1
 	for pf := counts.Head; pf != nil; pf = pf.Next {
 		k := pf.Key
-		v := pf.Value.(int)
+		v := pf.Value
 		if first || cmp(v, maxv) {
 			maxk = k
 			maxv = v
 			first = false
 		}
 	}
-	// OrderedMap has interface{} values, so dereference as Mlrval. Then, copy the Mlrval
-	// so we're not returning a pointer to input data.
-	return reps.Get(maxk).(*mlrval.Mlrval).Copy()
+	// Copy the Mlrval so we're not returning a pointer to input data.
+	return reps.Get(maxk).Copy()
 }
 
 func BIF_sum(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "sum")
+	ok, valueIfNot := check_collection(collection, "sum")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	return collection_sum_of_function(
 		collection,
@@ -332,9 +321,9 @@ func BIF_sum(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_sum2(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "sum2")
+	ok, valueIfNot := check_collection(collection, "sum2")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	f := func(element *mlrval.Mlrval) *mlrval.Mlrval {
 		return BIF_times(element, element)
@@ -343,9 +332,9 @@ func BIF_sum2(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_sum3(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "sum3")
+	ok, valueIfNot := check_collection(collection, "sum3")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	f := func(element *mlrval.Mlrval) *mlrval.Mlrval {
 		return BIF_times(element, BIF_times(element, element))
@@ -354,9 +343,9 @@ func BIF_sum3(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_sum4(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "sum4")
+	ok, valueIfNot := check_collection(collection, "sum4")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	f := func(element *mlrval.Mlrval) *mlrval.Mlrval {
 		sq := BIF_times(element, element)
@@ -366,9 +355,9 @@ func BIF_sum4(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_mean(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "mean")
+	ok, valueIfNot := check_collection(collection, "mean")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	if n.AcquireIntValue() == 0 {
@@ -379,9 +368,9 @@ func BIF_mean(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_meaneb(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "meaneb")
+	ok, valueIfNot := check_collection(collection, "meaneb")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	sum := BIF_sum(collection)
@@ -390,9 +379,9 @@ func BIF_meaneb(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_variance(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "variance")
+	ok, valueIfNot := check_collection(collection, "variance")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	sum := BIF_sum(collection)
@@ -401,9 +390,9 @@ func BIF_variance(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_stddev(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "stddev")
+	ok, valueIfNot := check_collection(collection, "stddev")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	sum := BIF_sum(collection)
@@ -412,9 +401,9 @@ func BIF_stddev(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_skewness(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "skewness")
+	ok, valueIfNot := check_collection(collection, "skewness")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	sum := BIF_sum(collection)
@@ -424,9 +413,9 @@ func BIF_skewness(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_kurtosis(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "kurtosis")
+	ok, valueIfNot := check_collection(collection, "kurtosis")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	n := BIF_count(collection)
 	sum := BIF_sum(collection)
@@ -437,33 +426,31 @@ func BIF_kurtosis(collection *mlrval.Mlrval) *mlrval.Mlrval {
 }
 
 func BIF_minlen(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "minlen")
+	ok, valueIfNot := check_collection(collection, "minlen")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	if collection.IsArray() {
 		return BIF_minlen_variadic(collection.AcquireArrayValue())
-	} else {
-		return BIF_minlen_within_map_values(collection.AcquireMapValue())
 	}
+	return BIF_minlen_within_map_values(collection.AcquireMapValue())
 }
 
 func BIF_maxlen(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "maxlen")
+	ok, valueIfNot := check_collection(collection, "maxlen")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 	if collection.IsArray() {
 		return BIF_maxlen_variadic(collection.AcquireArrayValue())
-	} else {
-		return BIF_maxlen_within_map_values(collection.AcquireMapValue())
 	}
+	return BIF_maxlen_within_map_values(collection.AcquireMapValue())
 }
 
 func BIF_sort_collection(collection *mlrval.Mlrval) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, "sort_collection")
+	ok, valueIfNot := check_collection(collection, "sort_collection")
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 
 	var array []*mlrval.Mlrval
@@ -471,7 +458,7 @@ func BIF_sort_collection(collection *mlrval.Mlrval) *mlrval.Mlrval {
 		arrayval := collection.AcquireArrayValue()
 		n := len(arrayval)
 		array = make([]*mlrval.Mlrval, n)
-		for i := 0; i < n; i++ {
+		for i := range n {
 			array[i] = arrayval[i].Copy()
 		}
 	} else {
@@ -545,9 +532,9 @@ func bif_percentile_with_options_aux(
 	outputs := bif_percentiles_with_options_aux(collection, percentiles, options, funcname)
 
 	// Check for error/absent returns from the main impl body
-	ok, value_if_not := check_collection(outputs, funcname)
+	ok, valueIfNot := check_collection(outputs, funcname)
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 
 	return outputs.AcquireMapValue().Head.Value
@@ -559,14 +546,14 @@ func bif_percentiles_with_options_aux(
 	options *mlrval.Mlrval,
 	funcname string,
 ) *mlrval.Mlrval {
-	ok, value_if_not := check_collection(collection, funcname)
+	ok, valueIfNot := check_collection(collection, funcname)
 	if !ok {
-		return value_if_not
+		return valueIfNot
 	}
 
-	array_is_sorted := false
-	interpolate_linearly := false
-	output_array_not_map := false
+	arrayIsSorted := false
+	interpolateLinearly := false
+	outputArrayNotMap := false
 
 	if options != nil {
 		om := options.GetMap()
@@ -576,25 +563,25 @@ func bif_percentiles_with_options_aux(
 		for pe := om.Head; pe != nil; pe = pe.Next {
 			if pe.Key == "array_is_sorted" || pe.Key == "ais" {
 				if mlrval.Equals(pe.Value, mlrval.TRUE) {
-					array_is_sorted = true
+					arrayIsSorted = true
 				} else if mlrval.Equals(pe.Value, mlrval.FALSE) {
-					array_is_sorted = false
+					arrayIsSorted = false
 				} else {
 					return type_error_named_argument(funcname, "boolean", pe.Key, pe.Value)
 				}
 			} else if pe.Key == "interpolate_linearly" || pe.Key == "il" {
 				if mlrval.Equals(pe.Value, mlrval.TRUE) {
-					interpolate_linearly = true
+					interpolateLinearly = true
 				} else if mlrval.Equals(pe.Value, mlrval.FALSE) {
-					interpolate_linearly = false
+					interpolateLinearly = false
 				} else {
 					return type_error_named_argument(funcname, "boolean", pe.Key, pe.Value)
 				}
 			} else if pe.Key == "output_array_not_map" || pe.Key == "oa" {
 				if mlrval.Equals(pe.Value, mlrval.TRUE) {
-					output_array_not_map = true
+					outputArrayNotMap = true
 				} else if mlrval.Equals(pe.Value, mlrval.FALSE) {
-					output_array_not_map = false
+					outputArrayNotMap = false
 				} else {
 					return type_error_named_argument(funcname, "boolean", pe.Key, pe.Value)
 				}
@@ -602,30 +589,30 @@ func bif_percentiles_with_options_aux(
 		}
 	}
 
-	var sorted_array *mlrval.Mlrval
-	if array_is_sorted {
+	var sortedArray *mlrval.Mlrval
+	if arrayIsSorted {
 		if !collection.IsArray() {
 			return mlrval.FromNotArrayError(funcname+" collection", collection)
 		}
-		sorted_array = collection
+		sortedArray = collection
 	} else {
-		sorted_array = BIF_sort_collection(collection)
+		sortedArray = BIF_sort_collection(collection)
 	}
 
 	return bif_percentiles_impl(
-		sorted_array.AcquireArrayValue(),
+		sortedArray.AcquireArrayValue(),
 		percentiles,
-		interpolate_linearly,
-		output_array_not_map,
+		interpolateLinearly,
+		outputArrayNotMap,
 		funcname,
 	)
 }
 
 func bif_percentiles_impl(
-	sorted_array []*mlrval.Mlrval,
+	sortedArray []*mlrval.Mlrval,
 	percentiles *mlrval.Mlrval,
-	interpolate_linearly bool,
-	output_array_not_map bool,
+	interpolateLinearly bool,
+	outputArrayNotMap bool,
 	funcname string,
 ) *mlrval.Mlrval {
 
@@ -640,25 +627,24 @@ func bif_percentiles_impl(
 		p, ok := ps[i].GetNumericToFloatValue()
 		if !ok {
 			outputs[i] = type_error_named_argument(funcname, "numeric", "percentile", ps[i])
-		} else if len(sorted_array) == 0 {
+		} else if len(sortedArray) == 0 {
 			outputs[i] = mlrval.VOID
 		} else {
-			if interpolate_linearly {
-				outputs[i] = GetPercentileLinearlyInterpolated(sorted_array, len(sorted_array), p)
+			if interpolateLinearly {
+				outputs[i] = GetPercentileLinearlyInterpolated(sortedArray, len(sortedArray), p)
 			} else {
-				outputs[i] = GetPercentileNonInterpolated(sorted_array, len(sorted_array), p)
+				outputs[i] = GetPercentileNonInterpolated(sortedArray, len(sortedArray), p)
 			}
 		}
 	}
 
-	if output_array_not_map {
+	if outputArrayNotMap {
 		return mlrval.FromArray(outputs)
-	} else {
-		m := mlrval.NewMlrmap()
-		for i := range ps {
-			sp := ps[i].String()
-			m.PutCopy(sp, outputs[i])
-		}
-		return mlrval.FromMap(m)
 	}
+	m := mlrval.NewMlrmap()
+	for i := range ps {
+		sp := ps[i].String()
+		m.PutCopy(sp, outputs[i])
+	}
+	return mlrval.FromMap(m)
 }
