@@ -1,4 +1,3 @@
-// ================================================================
 // Miller support for command-line flags.
 //
 // * Flags are used for several purposes:
@@ -33,12 +32,12 @@
 //   mlr, and -f/-n/-r etc can be used more than once for mlr sort, etc. I also
 //   insist on total control of flag formatting including alphabetization of
 //   flags for on-line help and documentation systems.
-// ================================================================
 
 package cli
 
 import (
 	"fmt"
+	"slices"
 	"sort"
 	"strings"
 
@@ -46,7 +45,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
-// ----------------------------------------------------------------
 // Data types used within the flags table.
 
 // FlagParser is a function which takes a flag such as `--foo`.
@@ -64,8 +62,6 @@ type FlagParser func(
 	options *TOptions,
 )
 
-// ----------------------------------------------------------------
-
 // FlagTable holds all the flags for Miller, organized into sections.
 type FlagTable struct {
 	sections []*FlagSection
@@ -121,7 +117,6 @@ type Flag struct {
 	suppressFlagEnumeration bool
 }
 
-// ================================================================
 // FlagTable methods
 
 // Sort organizes the sections in the table alphabetically, to make on-line
@@ -328,7 +323,6 @@ func (ft *FlagTable) NilCheck() {
 	fmt.Println("Flag-table nil check completed successfully.")
 }
 
-// ================================================================
 // FlagSection methods
 
 // Sort organizes the flags in the section alphabetically, to make on-line help
@@ -388,7 +382,6 @@ func (fs *FlagSection) NilCheck() {
 	}
 }
 
-// ================================================================
 // Flag methods
 
 // Owns determines whether this object handles a command-line flag such as
@@ -398,12 +391,7 @@ func (flag *Flag) Owns(input string) bool {
 	if flag.name == input {
 		return true
 	}
-	for _, name := range flag.altNames {
-		if name == input {
-			return true
-		}
-	}
-	return false
+	return slices.Contains(flag.altNames, input)
 }
 
 // Matches is like Owns but is for substring matching, for on-line help with
@@ -525,7 +513,6 @@ func (flag *Flag) NilCheck() {
 	lib.InternalCodingErrorWithMessageIf(flag.parser == nil, "Nil parser help for flag "+flag.name)
 }
 
-// ================================================================
 // Helper methods
 
 // NoOpParse1 is a helper function for flags which take no argument and are
