@@ -87,6 +87,8 @@ var defaultFSes = map[string]string{
 	"csvlite":  ",",
 	"dkvp":     ",",
 	"json":     "N/A", // not alterable; not parameterizable in JSON format
+	"yaml":     "N/A",
+	"dcf":      "N/A",
 	"nidx":     " ",
 	"markdown": " ",
 	"pprint":   " ",
@@ -100,6 +102,8 @@ var defaultPSes = map[string]string{
 	"csvlite":  "N/A",
 	"dkvp":     "=",
 	"json":     "N/A", // not alterable; not parameterizable in JSON format
+	"yaml":     "N/A",
+	"dcf":      "N/A",
 	"markdown": "N/A",
 	"nidx":     "N/A",
 	"pprint":   "N/A",
@@ -113,6 +117,8 @@ var defaultRSes = map[string]string{
 	"csvlite":  "\n",
 	"dkvp":     "\n",
 	"json":     "N/A", // not alterable; not parameterizable in JSON format
+	"yaml":     "N/A",
+	"dcf":      "N/A",
 	"markdown": "\n",
 	"nidx":     "\n",
 	"pprint":   "\n",
@@ -126,6 +132,8 @@ var defaultAllowRepeatIFSes = map[string]bool{
 	"csvlite":  false,
 	"dkvp":     false,
 	"json":     false,
+	"yaml":     false,
+	"dcf":      false,
 	"markdown": false,
 	"nidx":     false,
 	"pprint":   true,
