@@ -1,6 +1,4 @@
-// ================================================================
 // Print routines for AST and ASTNode
-// ================================================================
 
 package dsl
 
@@ -9,7 +7,6 @@ import (
 	"strings"
 )
 
-// ================================================================
 // Print is indent-style multiline print.
 // Example, given parse of '$y = 2 * $x + 1':
 //
@@ -52,8 +49,6 @@ func (ast *AST) PrintParexOneLine() {
 	ast.RootNode.PrintParexOneLine()
 }
 
-// ================================================================
-
 // Print is indent-style multiline print.
 func (node *ASTNode) Print() {
 	node.printAux(0)
@@ -62,7 +57,7 @@ func (node *ASTNode) Print() {
 // printAux is a recursion-helper for Print.
 func (node *ASTNode) printAux(depth int) {
 	// Indent
-	for i := 0; i < depth; i++ {
+	for range depth {
 		fmt.Print("    ")
 	}
 
@@ -80,8 +75,6 @@ func (node *ASTNode) printAux(depth int) {
 	}
 }
 
-// ----------------------------------------------------------------
-
 // PrintParex is parenthesized-expression print.
 func (node *ASTNode) PrintParex() {
 	node.printParexAux(0)
@@ -90,14 +83,14 @@ func (node *ASTNode) PrintParex() {
 // printParexAux is a recursion-helper for PrintParex.
 func (node *ASTNode) printParexAux(depth int) {
 	if node.IsLeaf() {
-		for i := 0; i < depth; i++ {
+		for range depth {
 			fmt.Print("    ")
 		}
 		fmt.Println(node.Text())
 
 	} else if node.ChildrenAreAllLeaves() {
 		// E.g. (= sum 0) or (+ 1 2)
-		for i := 0; i < depth; i++ {
+		for range depth {
 			fmt.Print("    ")
 		}
 		fmt.Print("(")
@@ -111,7 +104,7 @@ func (node *ASTNode) printParexAux(depth int) {
 
 	} else {
 		// Parent and opening parenthesis on first line
-		for i := 0; i < depth; i++ {
+		for range depth {
 			fmt.Print("    ")
 		}
 		fmt.Print("(")
@@ -123,15 +116,13 @@ func (node *ASTNode) printParexAux(depth int) {
 		}
 
 		// Closing parenthesis on last line
-		for i := 0; i < depth; i++ {
+		for range depth {
 			fmt.Print("    ")
 		}
 		fmt.Println(")")
 	}
 }
 
-// ----------------------------------------------------------------
-
 // PrintParexOneLine is parenthesized-expression print, all on one line.
 func (node *ASTNode) PrintParexOneLine() {
 	node.printParexOneLineAux()
@@ -153,8 +144,6 @@ func (node *ASTNode) printParexOneLineAux() {
 	}
 }
 
-// ----------------------------------------------------------------
-
 // IsLeaf determines if an AST node is a leaf node.
 func (node *ASTNode) IsLeaf() bool {
 	return len(node.Children) == 0
@@ -170,8 +159,6 @@ func (node *ASTNode) ChildrenAreAllLeaves() bool {
 	return true
 }
 
-// ----------------------------------------------------------------
-
 // Text makes a human-readable, whitespace-free name for an AST node. Some
 // nodes have non-nil tokens; other, nil. And token-types can have spaces in
 // them. In this method we use custom mappings to always get a whitespace-free
