@@ -1,6 +1,4 @@
-// ================================================================
 // CST build/execute for assignment and unset statements.
-// ================================================================
 
 package cst
 
@@ -10,7 +8,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ================================================================
 func (root *RootNode) BuildAssignmentNode(
 	astNode *dsl.ASTNode,
 ) (*AssignmentNode, error) {
@@ -40,22 +37,11 @@ func (root *RootNode) BuildAssignmentNode(
 	}, nil
 }
 
-// ----------------------------------------------------------------
 type AssignmentNode struct {
 	lvalueNode IAssignable
 	rvalueNode IEvaluable
 }
 
-func NewAssignmentNode(
-	lvalueNode IAssignable,
-	rvalueNode IEvaluable,
-) *AssignmentNode {
-	return &AssignmentNode{
-		lvalueNode: lvalueNode,
-		rvalueNode: rvalueNode,
-	}
-}
-
 func (node *AssignmentNode) Execute(
 	state *runtime.State,
 ) (*BlockExitPayload, error) {
@@ -69,7 +55,6 @@ func (node *AssignmentNode) Execute(
 	return nil, nil
 }
 
-// ================================================================
 func (root *RootNode) BuildUnsetNode(
 	astNode *dsl.ASTNode,
 ) (*UnsetNode, error) {
@@ -91,19 +76,10 @@ func (root *RootNode) BuildUnsetNode(
 	}, nil
 }
 
-// ----------------------------------------------------------------
 type UnsetNode struct {
 	lvalueNodes []IAssignable
 }
 
-func NewUnsetNode(
-	lvalueNodes []IAssignable,
-) *UnsetNode {
-	return &UnsetNode{
-		lvalueNodes: lvalueNodes,
-	}
-}
-
 func (node *UnsetNode) Execute(state *runtime.State) (*BlockExitPayload, error) {
 	for _, lvalueNode := range node.lvalueNodes {
 		lvalueNode.Unassign(state)
