@@ -1,7 +1,5 @@
-// ================================================================
 // This is for things that get us out of statement blocks: break, continue,
 // return.
-// ================================================================
 
 package cst
 
@@ -13,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ----------------------------------------------------------------
 type BreakNode struct {
 }
 
@@ -32,7 +29,6 @@ func (node *BreakNode) Execute(state *runtime.State) (*BlockExitPayload, error)
 	}, nil
 }
 
-// ----------------------------------------------------------------
 type ContinueNode struct {
 }
 
@@ -51,7 +47,6 @@ func (node *ContinueNode) Execute(state *runtime.State) (*BlockExitPayload, erro
 	}, nil
 }
 
-// ----------------------------------------------------------------
 type ReturnNode struct {
 	returnValueExpression IEvaluable
 }
@@ -67,10 +62,9 @@ func (root *RootNode) BuildReturnNode(astNode *dsl.ASTNode) (*ReturnNode, error)
 			return nil, err
 		}
 		return &ReturnNode{returnValueExpression: returnValueExpression}, nil
-	} else {
-		lib.InternalCodingErrorIf(true)
 	}
-	return nil, fmt.Errorf("internal coding error: statement should not be reached.")
+	lib.InternalCodingErrorIf(true)
+	return nil, fmt.Errorf("internal coding error: statement should not be reached")
 }
 
 func (node *ReturnNode) Execute(state *runtime.State) (*BlockExitPayload, error) {
