@@ -1,7 +1,5 @@
-// ================================================================
 // This is for begin and end blocks, but not the main block which is direct
 // from the CST root.
-// ================================================================
 
 package cst
 
@@ -11,19 +9,16 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ----------------------------------------------------------------
 func NewStatementBlockNode() *StatementBlockNode {
 	return &StatementBlockNode{
-		executables: make([]IExecutable, 0),
+		executables: []IExecutable{},
 	}
 }
 
-// ----------------------------------------------------------------
 func (node *StatementBlockNode) AppendStatementNode(executable IExecutable) {
 	node.executables = append(node.executables, executable)
 }
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildStatementBlockNodeFromBeginOrEnd(
 	astBeginOrEndNode *dsl.ASTNode,
 ) (*StatementBlockNode, error) {
@@ -67,12 +62,10 @@ func (root *RootNode) BuildStatementBlockNodeFromBeginOrEnd(
 	statementBlockNode, err := root.BuildStatementBlockNode(astStatementBlockNode)
 	if err != nil {
 		return nil, err
-	} else {
-		return statementBlockNode, nil
 	}
+	return statementBlockNode, nil
 }
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildStatementBlockNode(
 	astNode *dsl.ASTNode,
 ) (*StatementBlockNode, error) {
@@ -93,7 +86,6 @@ func (root *RootNode) BuildStatementBlockNode(
 	return statementBlockNode, nil
 }
 
-// ----------------------------------------------------------------
 func (node *StatementBlockNode) Execute(state *runtime.State) (*BlockExitPayload, error) {
 	state.Stack.PushStackFrame()
 	defer state.Stack.PopStackFrame()
@@ -110,7 +102,6 @@ func (node *StatementBlockNode) Execute(state *runtime.State) (*BlockExitPayload
 	return nil, nil
 }
 
-// ----------------------------------------------------------------
 // Assumes the caller has wrapped PushStackFrame() / PopStackFrame().  That
 // could be done here, but is instead done in the caller to simplify the
 // binding of for-loop variables. In particular, in
