@@ -1,6 +1,4 @@
-// ================================================================
 // Methods for built-in functions
-// ================================================================
 
 package cst
 
@@ -15,7 +13,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildBuiltinFunctionCallsiteNode(
 	astNode *dsl.ASTNode,
 ) (IEvaluable, error) {
@@ -52,18 +49,16 @@ func (root *RootNode) BuildBuiltinFunctionCallsiteNode(
 			return root.BuildVariadicFunctionCallsiteNode(astNode, builtinFunctionInfo)
 		} else if builtinFunctionInfo.variadicFuncWithState != nil {
 			return root.BuildVariadicFunctionWithStateCallsiteNode(astNode, builtinFunctionInfo)
-		} else {
-			return nil, fmt.Errorf(
-				"at CST BuildFunctionCallsiteNode: builtin function not implemented yet: %s",
-				functionName,
-			)
 		}
+		return nil, fmt.Errorf(
+			"at CST BuildFunctionCallsiteNode: builtin function not implemented yet: %s",
+			functionName,
+		)
 	}
 
 	return nil, nil // not found
 }
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildMultipleArityFunctionCallsiteNode(
 	astNode *dsl.ASTNode,
 	builtinFunctionInfo *BuiltinFunctionInfo,
@@ -85,7 +80,6 @@ func (root *RootNode) BuildMultipleArityFunctionCallsiteNode(
 	)
 }
 
-// ----------------------------------------------------------------
 type ZaryFunctionCallsiteNode struct {
 	zaryFunc bifs.ZaryFunc
 }
@@ -98,7 +92,7 @@ func BuildZaryFunctionCallsiteNode(
 	expectedArity := 0
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -117,7 +111,6 @@ func (node *ZaryFunctionCallsiteNode) Evaluate(
 	return node.zaryFunc()
 }
 
-// ----------------------------------------------------------------
 type UnaryFunctionCallsiteNode struct {
 	unaryFunc  bifs.UnaryFunc
 	evaluable1 IEvaluable
@@ -131,7 +124,7 @@ func (root *RootNode) BuildUnaryFunctionCallsiteNode(
 	expectedArity := 1
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -156,7 +149,6 @@ func (node *UnaryFunctionCallsiteNode) Evaluate(
 	return node.unaryFunc(node.evaluable1.Evaluate(state))
 }
 
-// ----------------------------------------------------------------
 type UnaryFunctionWithContextCallsiteNode struct {
 	unaryFuncWithContext bifs.UnaryFuncWithContext
 	evaluable1           IEvaluable
@@ -170,7 +162,7 @@ func (root *RootNode) BuildUnaryFunctionWithContextCallsiteNode(
 	expectedArity := 1
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -195,7 +187,6 @@ func (node *UnaryFunctionWithContextCallsiteNode) Evaluate(
 	return node.unaryFuncWithContext(node.evaluable1.Evaluate(state), state.Context)
 }
 
-// ----------------------------------------------------------------
 type BinaryFunctionCallsiteNode struct {
 	binaryFunc bifs.BinaryFunc
 	evaluable1 IEvaluable
@@ -210,7 +201,7 @@ func (root *RootNode) BuildBinaryFunctionCallsiteNode(
 	expectedArity := 2
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -269,7 +260,6 @@ func (node *BinaryFunctionCallsiteNode) Evaluate(
 	)
 }
 
-// ----------------------------------------------------------------
 type BinaryFunctionWithStateCallsiteNode struct {
 	binaryFuncWithState BinaryFuncWithState
 	evaluable1          IEvaluable
@@ -284,7 +274,7 @@ func (root *RootNode) BuildBinaryFunctionWithStateCallsiteNode(
 	expectedArity := 2
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -318,7 +308,6 @@ func (node *BinaryFunctionWithStateCallsiteNode) Evaluate(
 	)
 }
 
-// ----------------------------------------------------------------
 type TernaryFunctionWithStateCallsiteNode struct {
 	ternaryFuncWithState TernaryFuncWithState
 	evaluable1           IEvaluable
@@ -334,7 +323,7 @@ func (root *RootNode) BuildTernaryFunctionWithStateCallsiteNode(
 	expectedArity := 3
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -374,7 +363,6 @@ func (node *TernaryFunctionWithStateCallsiteNode) Evaluate(
 	)
 }
 
-// ----------------------------------------------------------------
 // RegexCaptureBinaryFunctionCallsiteNode special-cases the =~ and !=~
 // operators which set the CST State object's captures array for "\1".."\9".
 // This is identical to BinaryFunctionCallsite except that
@@ -420,7 +408,7 @@ func (root *RootNode) BuildRegexCaptureBinaryFunctionCallsiteNode(
 	expectedArity := 2
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -455,7 +443,6 @@ func (node *RegexCaptureBinaryFunctionCallsiteNode) Evaluate(
 	return output
 }
 
-// ----------------------------------------------------------------
 // DotCallsiteNode special-cases the dot operator, which is:
 // * string + string, with coercion to string if either side is int/float/bool/etc.
 // * map attribute access, if the left-hand side is a map.
@@ -472,7 +459,7 @@ func (root *RootNode) BuildDotCallsiteNode(
 	expectedArity := 2
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			".",
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -509,17 +496,14 @@ func (node *DotCallsiteNode) Evaluate(
 		value2 := mapvalue1.Get(node.string2)
 		if value2 == nil {
 			return mlrval.ABSENT.StrictModeCheck(state.StrictMode, "map access ["+node.string2+"]")
-		} else {
-			return value2
 		}
-	} else {
-		// Case 2: string concatenation
-		value2 := node.evaluable2.Evaluate(state)
-		return bifs.BIF_dot(value1, value2)
+		return value2
 	}
+	// Case 2: string concatenation
+	value2 := node.evaluable2.Evaluate(state)
+	return bifs.BIF_dot(value1, value2)
 }
 
-// ----------------------------------------------------------------
 type TernaryFunctionCallsiteNode struct {
 	ternaryFunc bifs.TernaryFunc
 	evaluable1  IEvaluable
@@ -535,7 +519,7 @@ func (root *RootNode) BuildTernaryFunctionCallsiteNode(
 	expectedArity := 3
 	if callsiteArity != expectedArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s invoked with %d argument%s; expected %d",
+			"function %s invoked with %d argument%s; expected %d",
 			builtinFunctionInfo.name,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -583,7 +567,6 @@ func (node *TernaryFunctionCallsiteNode) Evaluate(
 	)
 }
 
-// ----------------------------------------------------------------
 type VariadicFunctionCallsiteNode struct {
 	variadicFunc bifs.VariadicFunc
 	evaluables   []IEvaluable
@@ -600,7 +583,7 @@ func (root *RootNode) BuildVariadicFunctionCallsiteNode(
 
 	if callsiteArity < builtinFunctionInfo.minimumVariadicArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s takes minimum argument count %d; got %d",
+			"function %s takes minimum argument count %d; got %d",
 			builtinFunctionInfo.name,
 			builtinFunctionInfo.minimumVariadicArity,
 			callsiteArity,
@@ -610,7 +593,7 @@ func (root *RootNode) BuildVariadicFunctionCallsiteNode(
 	if builtinFunctionInfo.maximumVariadicArity != 0 {
 		if callsiteArity > builtinFunctionInfo.maximumVariadicArity {
 			return nil, fmt.Errorf(
-				"mlr: function %s takes maximum argument count %d; got %d",
+				"function %s takes maximum argument count %d; got %d",
 				builtinFunctionInfo.name,
 				builtinFunctionInfo.maximumVariadicArity,
 				callsiteArity,
@@ -618,7 +601,7 @@ func (root *RootNode) BuildVariadicFunctionCallsiteNode(
 		}
 	}
 
-	var err error = nil
+	var err error
 	for i, astChildNode := range astNode.Children {
 		evaluables[i], err = root.BuildEvaluableNode(astChildNode)
 		if err != nil {
@@ -641,7 +624,6 @@ func (node *VariadicFunctionCallsiteNode) Evaluate(
 	return node.variadicFunc(args)
 }
 
-// ----------------------------------------------------------------
 type VariadicFunctionWithStateCallsiteNode struct {
 	variadicFuncWithState VariadicFuncWithState
 	evaluables            []IEvaluable
@@ -658,7 +640,7 @@ func (root *RootNode) BuildVariadicFunctionWithStateCallsiteNode(
 
 	if callsiteArity < builtinFunctionInfo.minimumVariadicArity {
 		return nil, fmt.Errorf(
-			"mlr: function %s takes minimum argument count %d; got %d",
+			"function %s takes minimum argument count %d; got %d",
 			builtinFunctionInfo.name,
 			builtinFunctionInfo.minimumVariadicArity,
 			callsiteArity,
@@ -668,7 +650,7 @@ func (root *RootNode) BuildVariadicFunctionWithStateCallsiteNode(
 	if builtinFunctionInfo.maximumVariadicArity != 0 {
 		if callsiteArity > builtinFunctionInfo.maximumVariadicArity {
 			return nil, fmt.Errorf(
-				"mlr: function %s takes maximum argument count %d; got %d",
+				"function %s takes maximum argument count %d; got %d",
 				builtinFunctionInfo.name,
 				builtinFunctionInfo.maximumVariadicArity,
 				callsiteArity,
@@ -676,7 +658,7 @@ func (root *RootNode) BuildVariadicFunctionWithStateCallsiteNode(
 		}
 	}
 
-	var err error = nil
+	var err error
 	for i, astChildNode := range astNode.Children {
 		evaluables[i], err = root.BuildEvaluableNode(astChildNode)
 		if err != nil {
@@ -699,7 +681,6 @@ func (node *VariadicFunctionWithStateCallsiteNode) Evaluate(
 	return node.variadicFuncWithState(args, state)
 }
 
-// ================================================================
 type LogicalANDOperatorNode struct {
 	a, b IEvaluable
 }
@@ -799,7 +780,6 @@ func (node *LogicalANDOperatorNode) Evaluate(
 	return bifs.BIF_logical_AND(aout, bout)
 }
 
-// ================================================================
 type LogicalOROperatorNode struct {
 	a, b IEvaluable
 }
@@ -882,7 +862,6 @@ func (node *LogicalOROperatorNode) Evaluate(
 	return bifs.BIF_logical_OR(aout, bout)
 }
 
-// ================================================================
 // a ?? b evaluates to b only when a is absent. Example: '$foo ?? 0' when the
 // current record has no field $foo.
 type AbsentCoalesceOperatorNode struct{ a, b IEvaluable }
@@ -905,7 +884,6 @@ func (node *AbsentCoalesceOperatorNode) Evaluate(
 	return node.b.Evaluate(state)
 }
 
-// ================================================================
 // a ?? b evaluates to b only when a is absent or empty. Example: '$foo ?? 0'
 // when the current record has no field $foo, or when $foo is empty..
 type EmptyCoalesceOperatorNode struct{ a, b IEvaluable }
@@ -924,12 +902,10 @@ func (node *EmptyCoalesceOperatorNode) Evaluate(
 	atype := aout.Type()
 	if atype == mlrval.MT_ABSENT || atype == mlrval.MT_VOID || (atype == mlrval.MT_STRING && aout.String() == "") {
 		return node.b.Evaluate(state)
-	} else {
-		return aout
 	}
+	return aout
 }
 
-// ================================================================
 type StandardTernaryOperatorNode struct{ a, b, c IEvaluable }
 
 func BuildStandardTernaryOperatorNode(a, b, c IEvaluable) *StandardTernaryOperatorNode {
@@ -948,12 +924,10 @@ func (node *StandardTernaryOperatorNode) Evaluate(
 	// Short-circuit: defer evaluation unless needed
 	if boolValue {
 		return node.b.Evaluate(state)
-	} else {
-		return node.c.Evaluate(state)
 	}
+	return node.c.Evaluate(state)
 }
 
-// ================================================================
 // The function-manager logic is designed to make it easy to implement a large
 // number of functions/operators with a small number of keystrokes. The general
 // paradigm is evaluate the arguments, then invoke the function/operator.
