@@ -1,8 +1,6 @@
-// ================================================================
 // This handles anything on the right-hand sides of assignment statements.
 // (Also, computed field names on the left-hand sides of assignment
 // statements.)
-// ================================================================
 
 package cst
 
@@ -16,7 +14,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildEvaluableNode(astNode *dsl.ASTNode) (IEvaluable, error) {
 
 	if astNode.Children == nil {
@@ -84,7 +81,6 @@ func (root *RootNode) BuildEvaluableNode(astNode *dsl.ASTNode) (IEvaluable, erro
 	)
 }
 
-// ----------------------------------------------------------------
 type IndirectFieldValueNode struct {
 	fieldNameEvaluable IEvaluable
 }
@@ -125,7 +121,7 @@ func (node *IndirectFieldValueNode) Evaluate(
 	if err != nil {
 		// Key isn't int or string.
 		// TODO: needs error-return in the API
-		fmt.Fprintln(os.Stderr, err)
+		fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 		os.Exit(1)
 	}
 	if value == nil {
@@ -134,7 +130,6 @@ func (node *IndirectFieldValueNode) Evaluate(
 	return value
 }
 
-// ----------------------------------------------------------------
 type IndirectOosvarValueNode struct {
 	oosvarNameEvaluable IEvaluable
 }
