@@ -1,7 +1,5 @@
-// ================================================================
 // Support for higher-order functions in Miller: select, apply, fold, reduce,
 // sort, any, and every.
-// ================================================================
 
 package cst
 
@@ -194,7 +192,6 @@ func isFunctionOrDie(mlrval *mlrval.Mlrval, hofName string) {
 	}
 }
 
-// ================================================================
 // SELECT HOF
 
 func SelectHOF(
@@ -206,9 +203,8 @@ func SelectHOF(
 		return selectArray(input1, input2, state)
 	} else if input1.IsMap() {
 		return selectMap(input1, input2, state)
-	} else {
-		return mlrval.FromNotCollectionError("select", input1)
 	}
+	return mlrval.FromNotCollectionError("select", input1)
 }
 
 func selectArray(
@@ -285,7 +281,6 @@ func selectMap(
 	return mlrval.FromMap(outputMap)
 }
 
-// ================================================================
 // APPLY HOF
 
 func ApplyHOF(
@@ -297,9 +292,8 @@ func ApplyHOF(
 		return applyArray(input1, input2, state)
 	} else if input1.IsMap() {
 		return applyMap(input1, input2, state)
-	} else {
-		return mlrval.FromNotCollectionError("apply", input1)
 	}
+	return mlrval.FromNotCollectionError("apply", input1)
 }
 
 func applyArray(
@@ -356,7 +350,6 @@ func applyMap(
 	return mlrval.FromMap(outputMap)
 }
 
-// ================================================================
 // REDUCE HOF
 
 func ReduceHOF(
@@ -368,9 +361,8 @@ func ReduceHOF(
 		return reduceArray(input1, input2, state)
 	} else if input1.IsMap() {
 		return reduceMap(input1, input2, state)
-	} else {
-		return mlrval.FromNotCollectionError("reduce", input1)
 	}
+	return mlrval.FromNotCollectionError("reduce", input1)
 }
 
 func reduceArray(
@@ -435,7 +427,6 @@ func reduceMap(
 	return mlrval.FromMap(accumulator)
 }
 
-// ================================================================
 // FOLD HOF
 
 func FoldHOF(
@@ -448,9 +439,8 @@ func FoldHOF(
 		return foldArray(input1, input2, input3, state)
 	} else if input1.IsMap() {
 		return foldMap(input1, input2, input3, state)
-	} else {
-		return mlrval.FromNotCollectionError("fold", input1)
 	}
+	return mlrval.FromNotCollectionError("fold", input1)
 }
 
 func foldArray(
@@ -514,7 +504,6 @@ func foldMap(
 	return mlrval.FromMap(accumulator)
 }
 
-// ================================================================
 // SORT HOF
 
 func SortHOF(
@@ -527,40 +516,35 @@ func SortHOF(
 			return sortA(inputs[0], "")
 		} else if inputs[0].IsMap() {
 			return sortM(inputs[0], "")
-		} else {
-			return mlrval.FromNotCollectionError("sort", inputs[0])
 		}
+		return mlrval.FromNotCollectionError("sort", inputs[0])
 
 	} else if inputs[1].IsStringOrVoid() {
 		if inputs[0].IsArray() {
 			return sortA(inputs[0], inputs[1].String())
 		} else if inputs[0].IsMap() {
 			return sortM(inputs[0], inputs[1].String())
-		} else {
-			return mlrval.FromNotCollectionError("sort", inputs[0])
 		}
+		return mlrval.FromNotCollectionError("sort", inputs[0])
 
 	} else if inputs[1].IsFunction() {
 		if inputs[0].IsArray() {
 			return sortAF(inputs[0], inputs[1], state)
 		} else if inputs[0].IsMap() {
 			return sortMF(inputs[0], inputs[1], state)
-		} else {
-			return mlrval.FromNotCollectionError("sort", inputs[0])
 		}
+		return mlrval.FromNotCollectionError("sort", inputs[0])
 
-	} else {
-		fmt.Fprintf(os.Stderr, "mlr: sort: second argument must be a string or function; got %s.\n",
-			inputs[1].GetTypeName(),
-		)
-		os.Exit(1)
 	}
+	fmt.Fprintf(os.Stderr, "mlr: sort: second argument must be a string or function; got %s.\n",
+		inputs[1].GetTypeName(),
+	)
+	os.Exit(1)
 	// Not reached
 	lib.InternalCodingErrorIf(true)
 	return nil
 }
 
-// ----------------------------------------------------------------
 // Helpers for sort with string flags in place of callback UDF.
 
 type tSortType int
@@ -711,7 +695,7 @@ func sortM(
 
 	// Make a new map with entries in the new sort order.
 	outmap := mlrval.NewMlrmap()
-	for i := int64(0); i < n; i++ {
+	for i := range n {
 		entry := entries[i]
 		outmap.PutCopy(entry.Key, entry.Value)
 	}
@@ -727,9 +711,8 @@ func sortMNumerical(array []mlrval.MlrmapEntryForArray, reverse bool, byMapValue
 				nb, errb := strconv.ParseFloat(array[j].Key, 64)
 				if erra == nil && errb == nil {
 					return na < nb
-				} else {
-					return array[i].Key < array[j].Key
 				}
+				return array[i].Key < array[j].Key
 			})
 		} else {
 			sort.Slice(array, func(i, j int) bool {
@@ -737,9 +720,8 @@ func sortMNumerical(array []mlrval.MlrmapEntryForArray, reverse bool, byMapValue
 				nb, errb := strconv.ParseFloat(array[j].Key, 64)
 				if erra == nil && errb == nil {
 					return na > nb
-				} else {
-					return array[i].Key > array[j].Key
 				}
+				return array[i].Key > array[j].Key
 			})
 		}
 	} else {
@@ -921,7 +903,6 @@ func sortMF(
 	return mlrval.FromMap(sortedMap)
 }
 
-// ================================================================
 // ANY HOF
 
 func AnyHOF(
@@ -933,9 +914,8 @@ func AnyHOF(
 		return anyArray(input1, input2, state)
 	} else if input1.IsMap() {
 		return anyMap(input1, input2, state)
-	} else {
-		return mlrval.FromNotCollectionError("any", input1)
 	}
+	return mlrval.FromNotCollectionError("any", input1)
 }
 
 func anyArray(
@@ -1013,7 +993,6 @@ func anyMap(
 	return mlrval.FromBool(boolAny)
 }
 
-// ================================================================
 // EVERY HOF
 
 func EveryHOF(
@@ -1025,9 +1004,8 @@ func EveryHOF(
 		return everyArray(input1, input2, state)
 	} else if input1.IsMap() {
 		return everyMap(input1, input2, state)
-	} else {
-		return mlrval.FromNotCollectionError("every", input1)
 	}
+	return mlrval.FromNotCollectionError("every", input1)
 }
 
 func everyArray(
