@@ -1,6 +1,4 @@
-// ================================================================
 // CST build/execute for AST leaf nodes
-// ================================================================
 
 package cst
 
@@ -14,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/runtime"
 )
 
-// ----------------------------------------------------------------
 func (root *RootNode) BuildLeafNode(
 	astNode *dsl.ASTNode,
 ) (IEvaluable, error) {
@@ -83,7 +80,6 @@ func (root *RootNode) BuildLeafNode(
 	return nil, fmt.Errorf("at CST BuildLeafNode: unhandled AST node %s", string(astNode.Type))
 }
 
-// ----------------------------------------------------------------
 type DirectFieldRvalueNode struct {
 	fieldName string
 }
@@ -107,12 +103,10 @@ func (node *DirectFieldRvalueNode) Evaluate(
 	value := state.Inrec.Get(node.fieldName)
 	if value == nil {
 		return mlrval.ABSENT.StrictModeCheck(state.StrictMode, "$"+node.fieldName)
-	} else {
-		return value
 	}
+	return value
 }
 
-// ----------------------------------------------------------------
 type FullSrecRvalueNode struct {
 }
 
@@ -129,12 +123,10 @@ func (node *FullSrecRvalueNode) Evaluate(
 	// to access the inrec, and that would get past the validator.
 	if state.Inrec == nil {
 		return mlrval.ABSENT.StrictModeCheck(state.StrictMode, "$*")
-	} else {
-		return mlrval.FromMap(state.Inrec)
 	}
+	return mlrval.FromMap(state.Inrec)
 }
 
-// ----------------------------------------------------------------
 type DirectOosvarRvalueNode struct {
 	variableName string
 }
@@ -150,12 +142,10 @@ func (node *DirectOosvarRvalueNode) Evaluate(
 	value := state.Oosvars.Get(node.variableName)
 	if value == nil {
 		return mlrval.ABSENT.StrictModeCheck(state.StrictMode, "@"+node.variableName)
-	} else {
-		return value
 	}
+	return value
 }
 
-// ----------------------------------------------------------------
 type FullOosvarRvalueNode struct {
 }
 
@@ -168,7 +158,6 @@ func (node *FullOosvarRvalueNode) Evaluate(
 	return mlrval.FromMap(state.Oosvars)
 }
 
-// ----------------------------------------------------------------
 // TODO: rename this node-type.
 // RHSes can be:
 // * Local variables, like `x` in `x = 3`
@@ -209,7 +198,6 @@ func (node *LocalVariableNode) Evaluate(
 	return mlrval.ABSENT.StrictModeCheck(state.StrictMode, "local variable "+node.stackVariable.GetName())
 }
 
-// ----------------------------------------------------------------
 // During the BNF parse all string literals -- "foo" or "(..)_(...)" regexes
 // etc -- are marked as dsl.NodeTypeStringLiteral. However, a CST-build
 // pre-pass relabels second argument to sub/gsub etc -- any known regex
@@ -233,7 +221,6 @@ func (node *RegexLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ----------------------------------------------------------------
 // StringLiteralNode is for any string literal that doesn't have any "\0" ..
 // "\9" in it.
 type StringLiteralNode struct {
@@ -307,7 +294,6 @@ func (node *RegexCaptureReplacementNode) Evaluate(
 	)
 }
 
-// ----------------------------------------------------------------
 type IntLiteralNode struct {
 	literal *mlrval.Mlrval
 }
@@ -325,7 +311,6 @@ func (node *IntLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ----------------------------------------------------------------
 type FloatLiteralNode struct {
 	literal *mlrval.Mlrval
 }
@@ -343,7 +328,6 @@ func (node *FloatLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ----------------------------------------------------------------
 type BoolLiteralNode struct {
 	literal *mlrval.Mlrval
 }
@@ -359,7 +343,6 @@ func (node *BoolLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ----------------------------------------------------------------
 type NullLiteralNode struct {
 	literal *mlrval.Mlrval
 }
@@ -375,7 +358,6 @@ func (node *NullLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ----------------------------------------------------------------
 // Used for testing purposes; not used by the main DSL.
 
 type MlrvalLiteralNode struct {
@@ -393,7 +375,6 @@ func (node *MlrvalLiteralNode) Evaluate(
 	return node.literal
 }
 
-// ================================================================
 func (root *RootNode) BuildContextVariableNode(astNode *dsl.ASTNode) (IEvaluable, error) {
 	lib.InternalCodingErrorIf(astNode.Token == nil)
 	sval := string(astNode.Token.Lit)
@@ -433,7 +414,6 @@ func (root *RootNode) BuildContextVariableNode(astNode *dsl.ASTNode) (IEvaluable
 	return nil, fmt.Errorf("at CST BuildContextVariableNode: unhandled context variable %s", sval)
 }
 
-// ----------------------------------------------------------------
 type FILENAMENode struct {
 }
 
@@ -446,7 +426,6 @@ func (node *FILENAMENode) Evaluate(
 	return mlrval.FromString(state.Context.FILENAME)
 }
 
-// ----------------------------------------------------------------
 type FILENUMNode struct {
 }
 
@@ -459,7 +438,6 @@ func (node *FILENUMNode) Evaluate(
 	return mlrval.FromInt(state.Context.FILENUM)
 }
 
-// ----------------------------------------------------------------
 type NFNode struct {
 }
 
@@ -472,7 +450,6 @@ func (node *NFNode) Evaluate(
 	return mlrval.FromInt(state.Inrec.FieldCount)
 }
 
-// ----------------------------------------------------------------
 type NRNode struct {
 }
 
@@ -485,7 +462,6 @@ func (node *NRNode) Evaluate(
 	return mlrval.FromInt(state.Context.NR)
 }
 
-// ----------------------------------------------------------------
 type FNRNode struct {
 }
 
@@ -498,7 +474,6 @@ func (node *FNRNode) Evaluate(
 	return mlrval.FromInt(state.Context.FNR)
 }
 
-// ----------------------------------------------------------------
 type IRSNode struct {
 }
 
@@ -511,7 +486,6 @@ func (node *IRSNode) Evaluate(
 	return mlrval.FromString(state.Options.ReaderOptions.IRS)
 }
 
-// ----------------------------------------------------------------
 type IFSNode struct {
 }
 
@@ -524,7 +498,6 @@ func (node *IFSNode) Evaluate(
 	return mlrval.FromString(state.Options.ReaderOptions.IFS)
 }
 
-// ----------------------------------------------------------------
 type IPSNode struct {
 }
 
@@ -537,7 +510,6 @@ func (node *IPSNode) Evaluate(
 	return mlrval.FromString(state.Options.ReaderOptions.IPS)
 }
 
-// ----------------------------------------------------------------
 type ORSNode struct {
 }
 
@@ -550,7 +522,6 @@ func (node *ORSNode) Evaluate(
 	return mlrval.FromString(state.Options.WriterOptions.ORS)
 }
 
-// ----------------------------------------------------------------
 type OFSNode struct {
 }
 
@@ -563,7 +534,6 @@ func (node *OFSNode) Evaluate(
 	return mlrval.FromString(state.Options.WriterOptions.OFS)
 }
 
-// ----------------------------------------------------------------
 type OPSNode struct {
 }
 
@@ -576,7 +546,6 @@ func (node *OPSNode) Evaluate(
 	return mlrval.FromString(state.Options.WriterOptions.OPS)
 }
 
-// ----------------------------------------------------------------
 type FLATSEPNode struct {
 }
 
@@ -589,7 +558,6 @@ func (node *FLATSEPNode) Evaluate(
 	return mlrval.FromString(state.Options.WriterOptions.FLATSEP)
 }
 
-// ================================================================
 func (root *RootNode) BuildConstantNode(astNode *dsl.ASTNode) (IEvaluable, error) {
 	lib.InternalCodingErrorIf(astNode.Token == nil)
 	sval := string(astNode.Token.Lit)
@@ -606,7 +574,6 @@ func (root *RootNode) BuildConstantNode(astNode *dsl.ASTNode) (IEvaluable, error
 	return nil, fmt.Errorf("at CST BuildContextVariableNode: unhandled context variable %s", sval)
 }
 
-// ----------------------------------------------------------------
 type MathPINode struct {
 }
 
@@ -619,7 +586,6 @@ func (node *MathPINode) Evaluate(
 	return mlrval.FromFloat(math.Pi)
 }
 
-// ----------------------------------------------------------------
 type MathENode struct {
 }
 
@@ -632,7 +598,6 @@ func (node *MathENode) Evaluate(
 	return mlrval.FromFloat(math.E)
 }
 
-// ================================================================
 type LiteralOneNode struct {
 }
 
@@ -650,7 +615,6 @@ func (node *LiteralOneNode) Evaluate(
 	return mlrval.FromInt(1)
 }
 
-// ================================================================
 type LiteralEmptyStringNode struct {
 }
 
@@ -670,7 +634,6 @@ func (node *LiteralEmptyStringNode) Evaluate(
 	return mlrval.FromString("")
 }
 
-// ----------------------------------------------------------------
 // The panic token is a special token which causes a panic when evaluated.
 // This is for testing that AND/OR short-circuiting is implemented correctly:
 // output = input1 || panic should NOT panic the process when input1 is true.
