@@ -1,12 +1,10 @@
-// ================================================================
 // Top-level entry point for building a CST from an AST at parse time, and for
 // executing the CST at runtime.
-// ================================================================
 
 package cst
 
 import (
-	"container/list"
+	"errors"
 	"fmt"
 	"os"
 	"strings"
@@ -29,16 +27,16 @@ func NewEmptyRoot(
 	dslInstanceType DSLInstanceType, // mlr put, mlr filter, or mlr repl
 ) *RootNode {
 	return &RootNode{
-		beginBlocks:                   make([]*StatementBlockNode, 0),
+		beginBlocks:                   []*StatementBlockNode{},
 		mainBlock:                     NewStatementBlockNode(),
 		replImmediateBlock:            NewStatementBlockNode(),
-		endBlocks:                     make([]*StatementBlockNode, 0),
+		endBlocks:                     []*StatementBlockNode{},
 		udfManager:                    NewUDFManager(),
 		udsManager:                    NewUDSManager(),
 		allowUDFUDSRedefinitions:      false,
-		unresolvedFunctionCallsites:   list.New(),
-		unresolvedSubroutineCallsites: list.New(),
-		outputHandlerManagers:         list.New(),
+		unresolvedFunctionCallsites:   []*UDFCallsite{},
+		unresolvedSubroutineCallsites: []*UDSCallsite{},
+		outputHandlerManagers:         []output.OutputHandlerManager{},
 		recordWriterOptions:           recordWriterOptions,
 		dslInstanceType:               dslInstanceType,
 	}
@@ -58,8 +56,6 @@ func (root *RootNode) WithStrictMode(strictMode bool) *RootNode {
 	return root
 }
 
-// ----------------------------------------------------------------
-
 // ASTBuildVisitorFunc is a callback, used by RootNode's Build method, which
 // CST-builder callsites can use to visit parse-to-AST result of multi-string
 // DSL inputs. Nominal use: mlr put -v, mlr put -d, etc.
@@ -76,9 +72,6 @@ func (root *RootNode) Build(
 	doWarnings bool,
 	astBuildVisitorFunc ASTBuildVisitorFunc,
 ) (hadWarnings bool, err error) {
-	hadWarnings = false
-	err = nil
-
 	for _, dslString := range dslStrings {
 		astRootNode, err := buildASTFromStringWithMessage(dslString)
 		if err != nil {
@@ -116,9 +109,8 @@ func buildASTFromStringWithMessage(dslString string) (*dsl.AST, error) {
 		// At present it's overly parser-internal, and confusing. :(
 		fmt.Fprintln(os.Stderr, "mlr: cannot parse DSL expression.")
 		return nil, err
-	} else {
-		return astRootNode, nil
 	}
+	return astRootNode, nil
 }
 
 func buildASTFromString(dslString string) (*dsl.AST, error) {
@@ -145,8 +137,6 @@ func buildASTFromString(dslString string) (*dsl.AST, error) {
 	return astRootNode, nil
 }
 
-// ----------------------------------------------------------------
-
 // If the user has multiple put -f / put -e pieces, we can AST-parse each
 // separately and build them. However we cannot resolve UDF/UDS references
 // until after they're all ingested -- e.g. first piece calls a function which
@@ -159,11 +149,8 @@ func (root *RootNode) IngestAST(
 	isReplImmediate bool,
 	doWarnings bool,
 ) (hadWarnings bool, err error) {
-	hadWarnings = false
-	err = nil
-
 	if ast.RootNode == nil {
-		return hadWarnings, fmt.Errorf("cannot build CST from nil AST root")
+		return hadWarnings, errors.New("cannot build CST from nil AST root")
 	}
 
 	// Check for things that are syntax errors but not done in the AST for
@@ -213,7 +200,6 @@ func (root *RootNode) Resolve() error {
 	return nil
 }
 
-// ----------------------------------------------------------------
 // regexProtectPrePass rewrites string-literal nodes in regex position (e.g.
 // second arg to gsub) to have regex node type. This is so we can have "\t" be
 // a tab character for string literals generally, but remain backslash-t for
@@ -251,7 +237,7 @@ func (root *RootNode) regexProtectPrePass(ast *dsl.AST) {
 
 func (root *RootNode) regexProtectPrePassAux(astNode *dsl.ASTNode) {
 
-	if astNode.Children == nil || len(astNode.Children) == 0 {
+	if len(astNode.Children) == 0 {
 		return
 	}
 
@@ -283,7 +269,6 @@ func (root *RootNode) regexProtectPrePassAux(astNode *dsl.ASTNode) {
 
 }
 
-// ----------------------------------------------------------------
 // This builds the CST almost entirely. The only afterwork is that user-defined
 // functions may be called before they are defined, so a follow-up pass will
 // need to resolve those callsites.
@@ -363,11 +348,11 @@ func (root *RootNode) buildMainPass(ast *dsl.AST, isReplImmediate bool) error {
 // This is invoked within the buildMainPass call tree whenever a function is
 // called before it's defined.
 func (root *RootNode) rememberUnresolvedFunctionCallsite(udfCallsite *UDFCallsite) {
-	root.unresolvedFunctionCallsites.PushBack(udfCallsite)
+	root.unresolvedFunctionCallsites = append(root.unresolvedFunctionCallsites, udfCallsite)
 }
 
 func (root *RootNode) rememberUnresolvedSubroutineCallsite(udsCallsite *UDSCallsite) {
-	root.unresolvedSubroutineCallsites.PushBack(udsCallsite)
+	root.unresolvedSubroutineCallsites = append(root.unresolvedSubroutineCallsites, udsCallsite)
 }
 
 // After-pass after buildMainPass returns, in case a function was called before
@@ -380,10 +365,9 @@ func (root *RootNode) rememberUnresolvedSubroutineCallsite(udsCallsite *UDSCalls
 // So, our error message should reflect all those options.
 
 func (root *RootNode) resolveFunctionCallsites() error {
-	for root.unresolvedFunctionCallsites.Len() > 0 {
-		unresolvedFunctionCallsite := root.unresolvedFunctionCallsites.Remove(
-			root.unresolvedFunctionCallsites.Front(),
-		).(*UDFCallsite)
+	for len(root.unresolvedFunctionCallsites) > 0 {
+		unresolvedFunctionCallsite := root.unresolvedFunctionCallsites[0]
+		root.unresolvedFunctionCallsites = root.unresolvedFunctionCallsites[1:]
 
 		functionName := unresolvedFunctionCallsite.udf.signature.funcOrSubrName
 		callsiteArity := unresolvedFunctionCallsite.udf.signature.arity
@@ -404,10 +388,9 @@ func (root *RootNode) resolveFunctionCallsites() error {
 }
 
 func (root *RootNode) resolveSubroutineCallsites() error {
-	for root.unresolvedSubroutineCallsites.Len() > 0 {
-		unresolvedSubroutineCallsite := root.unresolvedSubroutineCallsites.Remove(
-			root.unresolvedSubroutineCallsites.Front(),
-		).(*UDSCallsite)
+	for len(root.unresolvedSubroutineCallsites) > 0 {
+		unresolvedSubroutineCallsite := root.unresolvedSubroutineCallsites[0]
+		root.unresolvedSubroutineCallsites = root.unresolvedSubroutineCallsites[1:]
 
 		subroutineName := unresolvedSubroutineCallsite.uds.signature.funcOrSubrName
 		callsiteArity := unresolvedSubroutineCallsite.uds.signature.arity
@@ -417,7 +400,7 @@ func (root *RootNode) resolveSubroutineCallsites() error {
 			return err
 		}
 		if uds == nil {
-			return fmt.Errorf("mlr: subroutine name not found: " + subroutineName)
+			return errors.New("subroutine name not found: " + subroutineName)
 		}
 
 		unresolvedSubroutineCallsite.uds = uds
@@ -425,7 +408,6 @@ func (root *RootNode) resolveSubroutineCallsites() error {
 	return nil
 }
 
-// ----------------------------------------------------------------
 // Various 'tee > $hostname . ".dat", $*' statements will have
 // OutputHandlerManager instances to track file-descriptors for all unique
 // values of $hostname in the input stream.
@@ -437,12 +419,11 @@ func (root *RootNode) resolveSubroutineCallsites() error {
 func (root *RootNode) RegisterOutputHandlerManager(
 	outputHandlerManager output.OutputHandlerManager,
 ) {
-	root.outputHandlerManagers.PushBack(outputHandlerManager)
+	root.outputHandlerManagers = append(root.outputHandlerManagers, outputHandlerManager)
 }
 
 func (root *RootNode) ProcessEndOfStream() {
-	for entry := root.outputHandlerManagers.Front(); entry != nil; entry = entry.Next() {
-		outputHandlerManager := entry.Value.(output.OutputHandlerManager)
+	for _, outputHandlerManager := range root.outputHandlerManagers {
 		errs := outputHandlerManager.Close()
 		if len(errs) != 0 {
 			for _, err := range errs {
@@ -483,7 +464,6 @@ func (root *RootNode) ExecuteEndBlocks(state *runtime.State) error {
 	return nil
 }
 
-// ----------------------------------------------------------------
 // These are for the Miller REPL.
 
 // If a DSL string was parsed into an AST and ingested in 'immediate' mode and
@@ -500,8 +480,8 @@ func (root *RootNode) ExecuteREPLImmediate(state *runtime.State) (outrec *mlrval
 // This is the 'and then discarded' part of that.
 func (root *RootNode) ResetForREPL() {
 	root.replImmediateBlock = NewStatementBlockNode()
-	root.unresolvedFunctionCallsites = list.New()
-	root.unresolvedSubroutineCallsites = list.New()
+	root.unresolvedFunctionCallsites = []*UDFCallsite{}
+	root.unresolvedSubroutineCallsites = []*UDSCallsite{}
 }
 
 // This is for the REPL's context-printer command.
@@ -513,15 +493,15 @@ func (root *RootNode) ShowBlockReport() {
 
 // This is for the REPL's resetblocks command.
 func (root *RootNode) ResetBeginBlocksForREPL() {
-	root.beginBlocks = make([]*StatementBlockNode, 0)
+	root.beginBlocks = []*StatementBlockNode{}
 }
 
 // This is for the REPL's resetblocks command.
 func (root *RootNode) ResetMainBlockForREPL() {
-	root.mainBlock.executables = make([]IExecutable, 0)
+	root.mainBlock.executables = []IExecutable{}
 }
 
 // This is for the REPL's resetblocks command.
 func (root *RootNode) ResetEndBlocksForREPL() {
-	root.endBlocks = make([]*StatementBlockNode, 0)
+	root.endBlocks = []*StatementBlockNode{}
 }
