@@ -1,6 +1,4 @@
-// ================================================================
 // Support for user-defined subroutines
-// ================================================================
 
 package cst
 
@@ -14,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 type UDS struct {
 	signature      *Signature
 	subroutineBody *StatementBlockNode
@@ -41,7 +38,6 @@ func NewUnresolvedUDS(
 	return uds
 }
 
-// ----------------------------------------------------------------
 type UDSCallsite struct {
 	argumentNodes []IEvaluable
 	uds           *UDS
@@ -158,7 +154,6 @@ func (site *UDSCallsite) Execute(state *runtime.State) (*BlockExitPayload, error
 	return blockExitPayload, nil
 }
 
-// ----------------------------------------------------------------
 type UDSManager struct {
 	subroutines map[string]*UDS
 }
@@ -169,14 +164,14 @@ func NewUDSManager() *UDSManager {
 	}
 }
 
-func (manager *UDSManager) LookUp(subroutineName string, callsiteArity int) (*UDS, error) {
-	uds := manager.subroutines[subroutineName]
+func (mgr *UDSManager) LookUp(subroutineName string, callsiteArity int) (*UDS, error) {
+	uds := mgr.subroutines[subroutineName]
 	if uds == nil {
 		return nil, nil
 	}
 	if uds.signature.arity != callsiteArity {
 		return nil, fmt.Errorf(
-			"mlr: subroutine %s invoked with %d argument%s; expected %d",
+			"subroutine %s invoked with %d argument%s; expected %d",
 			subroutineName,
 			callsiteArity,
 			lib.Plural(callsiteArity),
@@ -186,16 +181,15 @@ func (manager *UDSManager) LookUp(subroutineName string, callsiteArity int) (*UD
 	return uds, nil
 }
 
-func (manager *UDSManager) Install(uds *UDS) {
-	manager.subroutines[uds.signature.funcOrSubrName] = uds
+func (mgr *UDSManager) Install(uds *UDS) {
+	mgr.subroutines[uds.signature.funcOrSubrName] = uds
 }
 
-func (manager *UDSManager) ExistsByName(name string) bool {
-	_, ok := manager.subroutines[name]
+func (mgr *UDSManager) ExistsByName(name string) bool {
+	_, ok := mgr.subroutines[name]
 	return ok
 }
 
-// ----------------------------------------------------------------
 // Example AST for UDS definition and callsite:
 
 // DSL EXPRESSION:
@@ -244,7 +238,7 @@ func (root *RootNode) BuildAndInstallUDS(astNode *dsl.ASTNode) error {
 	if !root.allowUDFUDSRedefinitions {
 		if root.udsManager.ExistsByName(subroutineName) {
 			return fmt.Errorf(
-				`mlr: subroutine named "%s" has already been defined`,
+				`subroutine named "%s" has already been defined`,
 				subroutineName,
 			)
 		}
