@@ -1,7 +1,6 @@
 package input
 
 import (
-	"container/list"
 	"fmt"
 	"io"
 	"strconv"
@@ -15,7 +14,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 type RecordReaderCSV struct {
 	readerOptions       *cli.TReaderOptions
 	recordsPerBatch     int64 // distinct from readerOptions.RecordsPerBatch for join/repl
@@ -56,7 +54,7 @@ func NewRecordReaderCSV(
 func (reader *RecordReaderCSV) Read(
 	filenames []string,
 	context types.Context,
-	readerChannel chan<- *list.List, // list of *types.RecordAndContext
+	readerChannel chan<- []*types.RecordAndContext, // list of *types.RecordAndContext
 	errorChannel chan error,
 	downstreamDoneChannel <-chan bool, // for mlr head
 ) {
@@ -96,7 +94,7 @@ func (reader *RecordReaderCSV) processHandle(
 	handle io.Reader,
 	filename string,
 	context *types.Context,
-	readerChannel chan<- *list.List, // list of *types.RecordAndContext
+	readerChannel chan<- []*types.RecordAndContext, // list of *types.RecordAndContext
 	errorChannel chan error,
 	downstreamDoneChannel <-chan bool, // for mlr head
 ) {
@@ -121,13 +119,13 @@ func (reader *RecordReaderCSV) processHandle(
 		}
 	}
 
-	csvRecordsChannel := make(chan *list.List, recordsPerBatch)
+	csvRecordsChannel := make(chan [][]string, recordsPerBatch)
 	go channelizedCSVRecordScanner(csvReader, csvRecordsChannel, downstreamDoneChannel, errorChannel,
 		recordsPerBatch)
 
 	for {
 		recordsAndContexts, eof := reader.getRecordBatch(csvRecordsChannel, errorChannel, context)
-		if recordsAndContexts.Len() > 0 {
+		if len(recordsAndContexts) > 0 {
 			readerChannel <- recordsAndContexts
 		}
 		if eof {
@@ -139,7 +137,7 @@ func (reader *RecordReaderCSV) processHandle(
 // TODO: comment
 func channelizedCSVRecordScanner(
 	csvReader *csv.Reader,
-	csvRecordsChannel chan<- *list.List,
+	csvRecordsChannel chan<- [][]string,
 	downstreamDoneChannel <-chan bool, // for mlr head
 	errorChannel chan error,
 	recordsPerBatch int64,
@@ -147,7 +145,7 @@ func channelizedCSVRecordScanner(
 	i := int64(0)
 	done := false
 
-	csvRecords := list.New()
+	csvRecords := make([][]string, 0, recordsPerBatch)
 
 	for {
 		i++
@@ -163,7 +161,7 @@ func channelizedCSVRecordScanner(
 			break
 		}
 
-		csvRecords.PushBack(csvRecord)
+		csvRecords = append(csvRecords, csvRecord)
 
 		// See if downstream processors will be ignoring further data (e.g. mlr
 		// head).  If so, stop reading. This makes 'mlr head hugefile' exit
@@ -180,7 +178,7 @@ func channelizedCSVRecordScanner(
 				break
 			}
 			csvRecordsChannel <- csvRecords
-			csvRecords = list.New()
+			csvRecords = make([][]string, 0, recordsPerBatch)
 		}
 
 		if done {
@@ -193,14 +191,14 @@ func channelizedCSVRecordScanner(
 
 // TODO: comment copiously we're trying to handle slow/fast/short/long reads: tail -f, smallfile, bigfile.
 func (reader *RecordReaderCSV) getRecordBatch(
-	csvRecordsChannel <-chan *list.List,
+	csvRecordsChannel <-chan [][]string,
 	errorChannel chan error,
 	context *types.Context,
 ) (
-	recordsAndContexts *list.List,
+	recordsAndContexts []*types.RecordAndContext,
 	eof bool,
 ) {
-	recordsAndContexts = list.New()
+	recordsAndContexts = []*types.RecordAndContext{}
 	dedupeFieldNames := reader.readerOptions.DedupeFieldNames
 
 	csvRecords, more := <-csvRecordsChannel
@@ -208,11 +206,10 @@ func (reader *RecordReaderCSV) getRecordBatch(
 		return recordsAndContexts, true
 	}
 
-	for e := csvRecords.Front(); e != nil; e = e.Next() {
-		csvRecord := e.Value.([]string)
+	for _, csvRecord := range csvRecords {
 
 		if reader.needHeader {
-			isData := reader.maybeConsumeComment(csvRecord, context, recordsAndContexts)
+			isData := reader.maybeConsumeComment(csvRecord, context, &recordsAndContexts)
 			if !isData {
 				continue
 			}
@@ -223,7 +220,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 			continue
 		}
 
-		isData := reader.maybeConsumeComment(csvRecord, context, recordsAndContexts)
+		isData := reader.maybeConsumeComment(csvRecord, context, &recordsAndContexts)
 		if !isData {
 			continue
 		}
@@ -232,7 +229,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 		if reader.header == nil { // implicit CSV header
 			n := len(csvRecord)
 			reader.header = make([]string, n)
-			for i := 0; i < n; i++ {
+			for i := range n {
 				reader.header[i] = strconv.Itoa(i + 1)
 			}
 		}
@@ -243,7 +240,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 		nd := int64(len(csvRecord))
 
 		if nh == nd {
-			for i := int64(0); i < nh; i++ {
+			for i := range nh {
 				key := reader.header[i]
 				value := mlrval.FromDeferredType(csvRecord[i])
 				_, err := record.PutReferenceMaybeDedupe(key, value, dedupeFieldNames)
@@ -256,7 +253,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 		} else {
 			if !reader.readerOptions.AllowRaggedCSVInput {
 				err := fmt.Errorf(
-					"mlr: CSV header/data length mismatch %d != %d at filename %s row %d",
+					"CSV header/data length mismatch %d != %d at filename %s row %d",
 					nh, nd, reader.filename, reader.rowNumber,
 				)
 				errorChannel <- err
@@ -291,7 +288,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 
 		context.UpdateForInputRecord()
 
-		recordsAndContexts.PushBack(types.NewRecordAndContext(record, context))
+		recordsAndContexts = append(recordsAndContexts, types.NewRecordAndContext(record, context))
 	}
 
 	return recordsAndContexts, false
@@ -302,7 +299,7 @@ func (reader *RecordReaderCSV) getRecordBatch(
 func (reader *RecordReaderCSV) maybeConsumeComment(
 	csvRecord []string,
 	context *types.Context,
-	recordsAndContexts *list.List, // list of *types.RecordAndContext
+	recordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) bool {
 	if reader.readerOptions.CommentHandling == cli.CommentsAreData {
 		// Nothing is to be construed as a comment
@@ -333,7 +330,7 @@ func (reader *RecordReaderCSV) maybeConsumeComment(
 
 		// Contract with our fork of the go-csv CSV Reader, and, our own constructor.
 		lib.InternalCodingErrorIf(len(csvRecord) != 1)
-		recordsAndContexts.PushBack(types.NewOutputString(csvRecord[0], context))
+		*recordsAndContexts = append(*recordsAndContexts, types.NewOutputString(csvRecord[0], context))
 
 	} else /* reader.readerOptions.CommentHandling == cli.SkipComments */ {
 		// discard entirely
@@ -341,7 +338,6 @@ func (reader *RecordReaderCSV) maybeConsumeComment(
 	return false
 }
 
-// ----------------------------------------------------------------
 // BOM-stripping
 //
 // Some CSVs start with a "byte-order mark" which is the 3-byte sequence
