@@ -1,7 +1,6 @@
 package input
 
 import (
-	"container/list"
 	"fmt"
 	"io"
 	"regexp"
@@ -37,24 +36,23 @@ func NewRecordReaderPPRINT(
 		}
 		return reader, nil
 
-	} else {
-		// Use the CSVLite record-reader, which is implemented in another file,
-		// with multiple spaces instead of commas
-		reader := &RecordReaderCSVLite{
-			readerOptions:   readerOptions,
-			recordsPerBatch: recordsPerBatch,
-			fieldSplitter:   newFieldSplitter(readerOptions),
-
-			useVoidRep: true,
-			voidRep:    "-",
-		}
-		if reader.readerOptions.UseImplicitHeader {
-			reader.recordBatchGetter = getRecordBatchImplicitCSVHeader
-		} else {
-			reader.recordBatchGetter = getRecordBatchExplicitCSVHeader
-		}
-		return reader, nil
 	}
+	// Use the CSVLite record-reader, which is implemented in another file,
+	// with multiple spaces instead of commas
+	reader := &RecordReaderCSVLite{
+		readerOptions:   readerOptions,
+		recordsPerBatch: recordsPerBatch,
+		fieldSplitter:   newFieldSplitter(readerOptions),
+
+		useVoidRep: true,
+		voidRep:    "-",
+	}
+	if reader.readerOptions.UseImplicitHeader {
+		reader.recordBatchGetter = getRecordBatchImplicitCSVHeader
+	} else {
+		reader.recordBatchGetter = getRecordBatchExplicitCSVHeader
+	}
+	return reader, nil
 }
 
 type RecordReaderPprintBarredOrMarkdown struct {
@@ -73,19 +71,19 @@ type RecordReaderPprintBarredOrMarkdown struct {
 // implicit-PPRINT-header record-batch getter.
 type recordBatchGetterPprint func(
 	reader *RecordReaderPprintBarredOrMarkdown,
-	linesChannel <-chan *list.List,
+	linesChannel <-chan []string,
 	filename string,
 	context *types.Context,
 	errorChannel chan error,
 ) (
-	recordsAndContexts *list.List,
+	recordsAndContexts []*types.RecordAndContext,
 	eof bool,
 )
 
 func (reader *RecordReaderPprintBarredOrMarkdown) Read(
 	filenames []string,
 	context types.Context,
-	readerChannel chan<- *list.List, // list of *types.RecordAndContext
+	readerChannel chan<- []*types.RecordAndContext, // list of *types.RecordAndContext
 	errorChannel chan error,
 	downstreamDoneChannel <-chan bool, // for mlr head
 ) {
@@ -139,7 +137,7 @@ func (reader *RecordReaderPprintBarredOrMarkdown) processHandle(
 	handle io.Reader,
 	filename string,
 	context *types.Context,
-	readerChannel chan<- *list.List, // list of *types.RecordAndContext
+	readerChannel chan<- []*types.RecordAndContext, // list of *types.RecordAndContext
 	errorChannel chan error,
 	downstreamDoneChannel <-chan bool, // for mlr head
 ) {
@@ -149,12 +147,12 @@ func (reader *RecordReaderPprintBarredOrMarkdown) processHandle(
 
 	recordsPerBatch := reader.recordsPerBatch
 	lineReader := NewLineReader(handle, reader.readerOptions.IRS)
-	linesChannel := make(chan *list.List, recordsPerBatch)
+	linesChannel := make(chan []string, recordsPerBatch)
 	go channelizedLineReader(lineReader, linesChannel, downstreamDoneChannel, recordsPerBatch)
 
 	for {
 		recordsAndContexts, eof := reader.recordBatchGetter(reader, linesChannel, filename, context, errorChannel)
-		if recordsAndContexts.Len() > 0 {
+		if len(recordsAndContexts) > 0 {
 			readerChannel <- recordsAndContexts
 		}
 		if eof {
@@ -165,15 +163,15 @@ func (reader *RecordReaderPprintBarredOrMarkdown) processHandle(
 
 func getRecordBatchExplicitPprintHeader(
 	reader *RecordReaderPprintBarredOrMarkdown,
-	linesChannel <-chan *list.List,
+	linesChannel <-chan []string,
 	filename string,
 	context *types.Context,
 	errorChannel chan error,
 ) (
-	recordsAndContexts *list.List,
+	recordsAndContexts []*types.RecordAndContext,
 	eof bool,
 ) {
-	recordsAndContexts = list.New()
+	recordsAndContexts = []*types.RecordAndContext{}
 	dedupeFieldNames := reader.readerOptions.DedupeFieldNames
 
 	lines, more := <-linesChannel
@@ -181,8 +179,7 @@ func getRecordBatchExplicitPprintHeader(
 		return recordsAndContexts, true
 	}
 
-	for e := lines.Front(); e != nil; e = e.Next() {
-		line := e.Value.(string)
+	for _, line := range lines {
 
 		reader.inputLineNumber++
 
@@ -191,7 +188,7 @@ func getRecordBatchExplicitPprintHeader(
 		if reader.readerOptions.CommentHandling != cli.CommentsAreData {
 			if strings.HasPrefix(line, reader.readerOptions.CommentString) {
 				if reader.readerOptions.CommentHandling == cli.PassComments {
-					recordsAndContexts.PushBack(types.NewOutputString(line+"\n", context))
+					recordsAndContexts = append(recordsAndContexts, types.NewOutputString(line+"\n", context))
 					continue
 				} else if reader.readerOptions.CommentHandling == cli.SkipComments {
 					continue
@@ -240,7 +237,7 @@ func getRecordBatchExplicitPprintHeader(
 		} else {
 			if !reader.readerOptions.AllowRaggedCSVInput && len(reader.headerStrings) != len(fields) {
 				err := fmt.Errorf(
-					"mlr: PPRINT-barred header/data length mismatch %d != %d at filename %s line %d",
+					"PPRINT-barred header/data length mismatch %d != %d at filename %s line %d",
 					len(reader.headerStrings), len(fields), filename, reader.inputLineNumber,
 				)
 				errorChannel <- err
@@ -292,7 +289,7 @@ func getRecordBatchExplicitPprintHeader(
 			}
 
 			context.UpdateForInputRecord()
-			recordsAndContexts.PushBack(types.NewRecordAndContext(record, context))
+			recordsAndContexts = append(recordsAndContexts, types.NewRecordAndContext(record, context))
 
 		}
 	}
@@ -302,15 +299,15 @@ func getRecordBatchExplicitPprintHeader(
 
 func getRecordBatchImplicitPprintHeader(
 	reader *RecordReaderPprintBarredOrMarkdown,
-	linesChannel <-chan *list.List,
+	linesChannel <-chan []string,
 	filename string,
 	context *types.Context,
 	errorChannel chan error,
 ) (
-	recordsAndContexts *list.List,
+	recordsAndContexts []*types.RecordAndContext,
 	eof bool,
 ) {
-	recordsAndContexts = list.New()
+	recordsAndContexts = []*types.RecordAndContext{}
 	dedupeFieldNames := reader.readerOptions.DedupeFieldNames
 
 	lines, more := <-linesChannel
@@ -318,8 +315,7 @@ func getRecordBatchImplicitPprintHeader(
 		return recordsAndContexts, true
 	}
 
-	for e := lines.Front(); e != nil; e = e.Next() {
-		line := e.Value.(string)
+	for _, line := range lines {
 
 		reader.inputLineNumber++
 
@@ -328,7 +324,7 @@ func getRecordBatchImplicitPprintHeader(
 		if reader.readerOptions.CommentHandling != cli.CommentsAreData {
 			if strings.HasPrefix(line, reader.readerOptions.CommentString) {
 				if reader.readerOptions.CommentHandling == cli.PassComments {
-					recordsAndContexts.PushBack(types.NewOutputString(line+"\n", context))
+					recordsAndContexts = append(recordsAndContexts, types.NewOutputString(line+"\n", context))
 					continue
 				} else if reader.readerOptions.CommentHandling == cli.SkipComments {
 					continue
@@ -371,13 +367,13 @@ func getRecordBatchImplicitPprintHeader(
 		if reader.headerStrings == nil {
 			n := len(fields)
 			reader.headerStrings = make([]string, n)
-			for i := 0; i < n; i++ {
+			for i := range n {
 				reader.headerStrings[i] = strconv.Itoa(i + 1)
 			}
 		} else {
 			if !reader.readerOptions.AllowRaggedCSVInput && len(reader.headerStrings) != len(fields) {
 				err := fmt.Errorf(
-					"mlr: CSV header/data length mismatch %d != %d at filename %s line %d",
+					"CSV header/data length mismatch %d != %d at filename %s line %d",
 					len(reader.headerStrings), len(fields), filename, reader.inputLineNumber,
 				)
 				errorChannel <- err
@@ -436,7 +432,7 @@ func getRecordBatchImplicitPprintHeader(
 		}
 
 		context.UpdateForInputRecord()
-		recordsAndContexts.PushBack(types.NewRecordAndContext(record, context))
+		recordsAndContexts = append(recordsAndContexts, types.NewRecordAndContext(record, context))
 	}
 
 	return recordsAndContexts, false
