@@ -3,6 +3,7 @@ package mlrval
 import (
 	"bytes"
 	"fmt"
+	"slices"
 	"strconv"
 
 	"github.com/johnkerl/miller/v6/pkg/lib"
@@ -21,9 +22,8 @@ func (mlrmap *Mlrmap) Get(key string) *Mlrval {
 	pe := mlrmap.findEntry(key)
 	if pe == nil {
 		return nil
-	} else {
-		return pe.Value
 	}
+	return pe.Value
 }
 
 // PutReference copies the key but not the value. This is not safe for DSL use,
@@ -162,29 +162,28 @@ func (mlrmap *Mlrmap) PutReferenceAfter(
 		mlrmap.FieldCount++
 		return pf
 
-	} else {
-		// Before: ... pe pg ...
-		// After:  ... pe pf pg ...
-		//
-		// New entry is neither the new head (pe != nil) nor the new tail
-		// (pe.Next != nil, otherwise we'd be in the if-branch above).
-
-		pf := newMlrmapEntry(key, value)
-		pg := pe.Next
-
-		pe.Next = pf
-		pf.Next = pg
-		pf.Prev = pe
-		if pg != nil {
-			pg.Prev = pf
-		}
-
-		if mlrmap.keysToEntries != nil {
-			mlrmap.keysToEntries[key] = pf
-		}
-		mlrmap.FieldCount++
-		return pf
 	}
+	// Before: ... pe pg ...
+	// After:  ... pe pf pg ...
+	//
+	// New entry is neither the new head (pe != nil) nor the new tail
+	// (pe.Next != nil, otherwise we'd be in the if-branch above).
+
+	pf := newMlrmapEntry(key, value)
+	pg := pe.Next
+
+	pe.Next = pf
+	pf.Next = pg
+	pf.Prev = pe
+	if pg != nil {
+		pg.Prev = pf
+	}
+
+	if mlrmap.keysToEntries != nil {
+		mlrmap.keysToEntries[key] = pf
+	}
+	mlrmap.FieldCount++
+	return pf
 }
 
 // findEntry is the basic hash-map accessor for Has, Put, Get, Remove, etc.
@@ -194,14 +193,13 @@ func (mlrmap *Mlrmap) PutReferenceAfter(
 func (mlrmap *Mlrmap) findEntry(key string) *MlrmapEntry {
 	if mlrmap.keysToEntries != nil {
 		return mlrmap.keysToEntries[key]
-	} else {
-		for pe := mlrmap.Head; pe != nil; pe = pe.Next {
-			if pe.Key == key {
-				return pe
-			}
-		}
-		return nil
 	}
+	for pe := mlrmap.Head; pe != nil; pe = pe.Next {
+		if pe.Key == key {
+			return pe
+		}
+	}
+	return nil
 }
 
 // findEntryByPositionalIndex is for '$[1]' etc. in the DSL.
@@ -244,19 +242,16 @@ func (mlrmap *Mlrmap) PutCopyWithMlrvalIndex(key *Mlrval, value *Mlrval) error {
 	if key.IsStringOrInt() {
 		mlrmap.PutCopy(key.String(), value)
 		return nil
-	} else {
-		return fmt.Errorf(
-			"mlr: record/map indices must be string, int, or array thereof; got %s", key.GetTypeName(),
-		)
 	}
+	return fmt.Errorf(
+		"record/map indices must be string, int, or array thereof; got %s", key.GetTypeName(),
+	)
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) PrependCopy(key string, value *Mlrval) {
 	mlrmap.PrependReference(key, value.Copy())
 }
 
-// ----------------------------------------------------------------
 // Merges that into mlrmap.
 func (mlrmap *Mlrmap) Merge(other *Mlrmap) {
 	for pe := other.Head; pe != nil; pe = pe.Next {
@@ -264,7 +259,6 @@ func (mlrmap *Mlrmap) Merge(other *Mlrmap) {
 	}
 }
 
-// ----------------------------------------------------------------
 // Exposed for the 'nest' verb
 func (mlrmap *Mlrmap) GetEntry(key string) *MlrmapEntry {
 	return mlrmap.findEntry(key)
@@ -284,7 +278,7 @@ func (mlrmap *Mlrmap) GetKeys() []string {
 // specified are to be passed in as a map from string to bool, as Go
 // doesn't have hash-sets.
 func (mlrmap *Mlrmap) GetKeysExcept(exceptions map[string]bool) []string {
-	keys := make([]string, 0)
+	keys := []string{}
 	for pe := mlrmap.Head; pe != nil; pe = pe.Next {
 		if _, present := exceptions[pe.Key]; !present {
 			keys = append(keys, pe.Key)
@@ -293,7 +287,6 @@ func (mlrmap *Mlrmap) GetKeysExcept(exceptions map[string]bool) []string {
 	return keys
 }
 
-// ----------------------------------------------------------------
 // TODO: put error-return into this API
 func (mlrmap *Mlrmap) PutNameWithPositionalIndex(position int64, name *Mlrval) {
 	positionalEntry := mlrmap.findEntryByPositionalIndex(position)
@@ -340,9 +333,8 @@ func (mlrmap *Mlrmap) GetWithPositionalIndex(position int64) *Mlrval {
 func (mlrmap *Mlrmap) GetWithMlrvalIndex(index *Mlrval) (*Mlrval, error) {
 	if index.IsArray() {
 		return mlrmap.getWithMlrvalArrayIndex(index)
-	} else {
-		return mlrmap.getWithMlrvalSingleIndex(index)
 	}
+	return mlrmap.getWithMlrvalSingleIndex(index)
 }
 
 // This lets the user do '$y = $x[ ["a", "b", "c"] ]' in lieu of
@@ -360,7 +352,7 @@ func (mlrmap *Mlrmap) getWithMlrvalArrayIndex(index *Mlrval) (*Mlrval, error) {
 		}
 		if i < n-1 {
 			if !next.IsMap() {
-				return nil, fmt.Errorf("mlr: cannot multi-index non-map")
+				return nil, fmt.Errorf("cannot multi-index non-map")
 			}
 			current = next.intf.(*Mlrmap)
 		} else {
@@ -376,11 +368,10 @@ func (mlrmap *Mlrmap) getWithMlrvalSingleIndex(index *Mlrval) (*Mlrval, error) {
 		return mlrmap.Get(index.printrep), nil
 	} else if index.IsInt() {
 		return mlrmap.Get(index.String()), nil
-	} else {
-		return nil, fmt.Errorf(
-			"record/map indices must be string, int, or array thereof; got %s", index.GetTypeName(),
-		)
 	}
+	return nil, fmt.Errorf(
+		"record/map indices must be string, int, or array thereof; got %s", index.GetTypeName(),
+	)
 }
 
 // For '$[[1]]' etc. in the DSL.
@@ -401,7 +392,6 @@ func (mlrmap *Mlrmap) GetNameAtPositionalIndex(position int64) (string, bool) {
 	return mapEntry.Key, true
 }
 
-// ----------------------------------------------------------------
 // Copies the key and value (deep-copying in case the value is array/map).
 // This is safe for DSL use. See also PutReference.
 
@@ -423,7 +413,6 @@ func (mlrmap *Mlrmap) RemoveWithPositionalIndex(position int64) {
 	}
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) Equals(other *Mlrmap) bool {
 	if mlrmap.FieldCount != other.FieldCount {
 		return false
@@ -465,7 +454,6 @@ func (mlrmap *Mlrmap) Clear() {
 	}
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) Copy() *Mlrmap {
 	other := NewMlrmapMaybeHashed(mlrmap.isHashed())
 	for pe := mlrmap.Head; pe != nil; pe = pe.Next {
@@ -479,10 +467,9 @@ func (mlrmap *Mlrmap) Remove(key string) bool {
 	pe := mlrmap.findEntry(key)
 	if pe == nil {
 		return false
-	} else {
-		mlrmap.Unlink(pe)
-		return true
 	}
+	mlrmap.Unlink(pe)
+	return true
 }
 
 func (mlrmap *Mlrmap) MoveToHead(key string) {
@@ -501,7 +488,6 @@ func (mlrmap *Mlrmap) MoveToTail(key string) {
 	}
 }
 
-// ----------------------------------------------------------------
 // E.g. '$name[1]["foo"] = "bar"' or '$*["foo"][1] = "bar"'
 // In the former case the indices are ["name", 1, "foo"] and in the latter case
 // the indices are ["foo", 1]. See also indexed-lvalues.md.
@@ -518,7 +504,6 @@ func (mlrmap *Mlrmap) RemoveIndexed(indices []*Mlrval) error {
 	return removeIndexedOnMap(mlrmap, indices)
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) GetKeysJoined() string {
 	var buffer bytes.Buffer
 	i := 0
@@ -546,7 +531,6 @@ func (mlrmap *Mlrmap) GetValuesJoined() string {
 	return buffer.String()
 }
 
-// ----------------------------------------------------------------
 // For group-by in several transformers.  If the record is 'a=x,b=y,c=3,d=4,e=5' and
 // selectedFieldNames is 'a,b,c' then values are 'x,y,3'. This is returned as a
 // comma-joined string.  The boolean ok is false if not all selected field
@@ -662,7 +646,6 @@ func (mlrmap *Mlrmap) HasSelectedKeys(selectedFieldNames []string) bool {
 	return true
 }
 
-// ----------------------------------------------------------------
 // For mlr nest implode across records.
 func (mlrmap *Mlrmap) GetKeysJoinedExcept(px *MlrmapEntry) string {
 	var buffer bytes.Buffer
@@ -699,7 +682,6 @@ func (mlrmap *Mlrmap) GetValuesJoinedExcept(px *MlrmapEntry) string {
 	return buffer.String()
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) Rename(oldKey string, newKey string) bool {
 	entry := mlrmap.findEntry(oldKey)
 	if entry == nil {
@@ -729,7 +711,6 @@ func (mlrmap *Mlrmap) Rename(oldKey string, newKey string) bool {
 	return true
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) Label(newNames []string) {
 	other := NewMlrmapAsRecord()
 
@@ -768,11 +749,10 @@ func (mlrmap *Mlrmap) Label(newNames []string) {
 	*mlrmap = *other
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) SortByKey() {
 	keys := mlrmap.GetKeys()
 
-	lib.SortStrings(keys)
+	slices.Sort(keys)
 
 	other := NewMlrmapAsRecord()
 
@@ -784,11 +764,10 @@ func (mlrmap *Mlrmap) SortByKey() {
 	*mlrmap = *other
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) SortByKeyRecursively() {
 	keys := mlrmap.GetKeys()
 
-	lib.SortStrings(keys)
+	slices.Sort(keys)
 
 	other := NewMlrmapAsRecord()
 
@@ -804,7 +783,6 @@ func (mlrmap *Mlrmap) SortByKeyRecursively() {
 	*mlrmap = *other
 }
 
-// ----------------------------------------------------------------
 // Only checks to see if the first entry is a map. For emit/emitp.
 func (mlrmap *Mlrmap) IsNested() bool {
 	if mlrmap.Head == nil {
@@ -812,12 +790,10 @@ func (mlrmap *Mlrmap) IsNested() bool {
 	} else if mlrmap.Head.Value.GetMap() == nil {
 		//TODO: check IsArrayOrMap()
 		return false
-	} else {
-		return true
 	}
+	return true
 }
 
-// ================================================================
 // PRIVATE METHODS
 
 func (mlrmap *Mlrmap) Unlink(pe *MlrmapEntry) {
@@ -881,19 +857,15 @@ func (mlrmap *Mlrmap) linkAtTail(pe *MlrmapEntry) {
 	mlrmap.FieldCount++
 }
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) pop() *MlrmapEntry {
 	if mlrmap.Head == nil {
 		return nil
-	} else {
-		pe := mlrmap.Head
-		mlrmap.Unlink(pe)
-		return pe
 	}
+	pe := mlrmap.Head
+	mlrmap.Unlink(pe)
+	return pe
 }
 
-// ----------------------------------------------------------------
-
 // ToPairsArray is used for sorting maps by key/value/etc, e.g. the sortmf DSL function.
 func (mlrmap *Mlrmap) ToPairsArray() []MlrmapPair {
 	pairsArray := make([]MlrmapPair, mlrmap.FieldCount)
@@ -917,8 +889,6 @@ func MlrmapFromPairsArray(pairsArray []MlrmapPair) *Mlrmap {
 	return mlrmap
 }
 
-// ----------------------------------------------------------------
-
 // GetFirstPair returns the first key-value pair as its own map.  If the map is
 // empty (i.e. there is no first pair) it returns nil.
 func (mlrmap *Mlrmap) GetFirstPair() *Mlrmap {
@@ -929,7 +899,3 @@ func (mlrmap *Mlrmap) GetFirstPair() *Mlrmap {
 	pair.PutCopy(mlrmap.Head.Key, mlrmap.Head.Value)
 	return pair
 }
-
-func (mlrmap *Mlrmap) IsSinglePair() bool {
-	return mlrmap.FieldCount == 1
-}
