@@ -1,6 +1,4 @@
-// ================================================================
 // See mlrval_json.go for details. This is the unmarshal/marshal solely for Mlrmap.
-// ================================================================
 
 package mlrval
 
@@ -11,7 +9,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
-// ----------------------------------------------------------------
 func (mlrmap *Mlrmap) MarshalJSON(
 	jsonFormatting TJSONFormatting,
 	outputIsStdout bool,
@@ -51,10 +48,9 @@ func (mlrmap *Mlrmap) marshalJSONAux(
 		return mlrmap.marshalJSONAuxMultiline(jsonFormatting, elementNestingDepth, outputIsStdout)
 	} else if jsonFormatting == JSON_SINGLE_LINE {
 		return mlrmap.marshalJSONAuxSingleLine(jsonFormatting, elementNestingDepth, outputIsStdout)
-	} else {
-		lib.InternalCodingErrorIf(true)
-		return "", nil // not reached
 	}
+	lib.InternalCodingErrorIf(true)
+	return "", nil // not reached
 }
 
 func (mlrmap *Mlrmap) marshalJSONAuxMultiline(
@@ -75,7 +71,7 @@ func (mlrmap *Mlrmap) marshalJSONAuxMultiline(
 	for pe := mlrmap.Head; pe != nil; pe = pe.Next {
 		// Write the key which is necessarily string-valued in Miller, and in
 		// JSON for that matter :)
-		for i := 0; i < elementNestingDepth; i++ {
+		for range elementNestingDepth {
 			buffer.WriteString(JSON_INDENT_STRING)
 		}
 		encoded := string(millerJSONEncodeString(pe.Key))
@@ -146,7 +142,6 @@ func (mlrmap *Mlrmap) marshalJSONAuxSingleLine(
 	return buffer.String(), nil
 }
 
-// ----------------------------------------------------------------
 // JSON-stringifies a single field of a record
 func (entry *MlrmapEntry) JSONStringifyInPlace(
 	jsonFormatting TJSONFormatting,
@@ -159,7 +154,6 @@ func (entry *MlrmapEntry) JSONStringifyInPlace(
 	}
 }
 
-// ----------------------------------------------------------------
 // JSON-parses a single field of a record
 func (entry *MlrmapEntry) JSONParseInPlace() {
 	input := entry.Value.String()
