@@ -1,24 +1,10 @@
-// ================================================================
 // Constants/singletons of various types
-// ================================================================
 
 package mlrval
 
-// MlrvalFromPending is designed solely for the JSON API, for something
-// intended to be mutated after construction once its type is (later) known.
-// Whereas ERROR, ABSENT, etc are all singletons, this one
-// must be mutable and therefore non-singleton.
-
-func MlrvalFromPending() Mlrval {
-	return Mlrval{
-		mvtype:   MT_PENDING,
-		printrep: "(bug-if-you-see-this:case-3)", // INVALID_PRINTREP,
-	}
-}
-
 // These are made singletons as part of a copy-reduction effort.  They're not
 // marked const (I haven't figured out the right way to get that to compile;
-// just using `const` isn't enough) but the gentelpersons' agreement is that
+// just using `const` isn't enough) but the gentlepersons' agreement is that
 // the caller should never modify these.
 
 var TRUE = &Mlrval{
