@@ -6,7 +6,7 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/scan"
 )
 
-// TODO: comment no infer-bool from data files. Always false in this path.
+// Note: we do not infer bools from data files; always false in this path.
 
 // It's essential that we use mv.Type() not mv.mvtype since types are
 // JIT-computed on first access for most data-file values. See type.go for more
@@ -44,14 +44,12 @@ func SetInferrerStringOnly() {
 	packageLevelInferrer = inferString
 }
 
-// ----------------------------------------------------------------
-
 func inferNormally(mv *Mlrval) *Mlrval {
 	scanType := scan.FindScanType(mv.printrep)
 	return normalInferrerTable[scanType](mv)
 }
 
-// xxx temp
+// inferWithOctalAsInt uses the leading-zero-as-int inferrer table (mlr -O).
 func inferWithOctalAsInt(mv *Mlrval) *Mlrval {
 	scanType := scan.FindScanType(mv.printrep)
 	return leadingZeroAsIntInferrerTable[scanType](mv)
@@ -72,8 +70,6 @@ func inferString(mv *Mlrval) *Mlrval {
 	return mv.SetFromString(mv.printrep)
 }
 
-// ----------------------------------------------------------------
-
 // Important: synchronize this with the type-ordering in the scan package.
 var normalInferrerTable []tInferrer = []tInferrer{
 	inferString,
@@ -98,43 +94,40 @@ var leadingZeroAsIntInferrerTable []tInferrer = []tInferrer{
 	inferMaybeFloat,
 }
 
-// TODO: comment
+// inferDecimalInt parses a base-10 integer or keeps the value as a string.
 func inferDecimalInt(mv *Mlrval) *Mlrval {
 	intval, err := strconv.ParseInt(mv.printrep, 10, 64)
 	if err == nil {
 		return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-	} else {
-		return mv.SetFromString(mv.printrep)
 	}
+	return mv.SetFromString(mv.printrep)
 }
 
-// TODO: comment
+// inferLeadingZeroDecimalIntAsInt parses base-10 integers when leading zeros are allowed.
 func inferLeadingZeroDecimalIntAsInt(mv *Mlrval) *Mlrval {
 	intval, err := strconv.ParseInt(mv.printrep, 10, 64)
 	if err == nil {
 		return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-	} else {
-		return mv.SetFromString(mv.printrep)
 	}
+	return mv.SetFromString(mv.printrep)
 }
 
-// TODO: comment
+// inferOctalInt parses explicit 0o-prefixed octal integers.
 // E.g. explicit 0o377, not 0377
 func inferOctalInt(mv *Mlrval) *Mlrval {
 	return inferBaseInt(mv, 8)
 }
 
-// TODO: comment
+// inferFromLeadingZeroOctalIntAsInt parses 0-prefixed octal integers.
 func inferFromLeadingZeroOctalIntAsInt(mv *Mlrval) *Mlrval {
 	intval, err := strconv.ParseInt(mv.printrep, 8, 64)
 	if err == nil {
 		return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-	} else {
-		return mv.SetFromString(mv.printrep)
 	}
+	return mv.SetFromString(mv.printrep)
 }
 
-// TODO: comment
+// inferHexInt parses 0x-prefixed hex integers with two's-complement handling.
 func inferHexInt(mv *Mlrval) *Mlrval {
 	var input string
 	var negate bool
@@ -169,40 +162,36 @@ func inferHexInt(mv *Mlrval) *Mlrval {
 		}
 		if err == nil {
 			return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-		} else {
-			return mv.SetFromString(mv.printrep)
 		}
+		return mv.SetFromString(mv.printrep)
+	}
+	intval, err := strconv.ParseInt(input, 16, 64)
+	if negate {
+		intval = -intval
+	}
+	if err == nil {
+		return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
 	} else {
-		intval, err := strconv.ParseInt(input, 16, 64)
-		if negate {
-			intval = -intval
-		}
-		if err == nil {
-			return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-		} else {
-			return mv.SetFromString(mv.printrep)
-		}
+		return mv.SetFromString(mv.printrep)
 	}
 
 }
 
-// TODO: comment
+// inferBinaryInt parses 0b-prefixed binary integers.
 func inferBinaryInt(mv *Mlrval) *Mlrval {
 	return inferBaseInt(mv, 2)
 }
 
-// TODO: comment
+// inferMaybeFloat parses floating-point values or keeps the value as a string.
 func inferMaybeFloat(mv *Mlrval) *Mlrval {
 	floatval, err := strconv.ParseFloat(mv.printrep, 64)
 	if err == nil {
 		return mv.SetFromPrevalidatedFloatString(mv.printrep, floatval)
-	} else {
-		return mv.SetFromString(mv.printrep)
 	}
+	return mv.SetFromString(mv.printrep)
 }
 
-// TODO: comment
-// Shared code for 0o/0b integers
+// inferBaseInt is shared code for parsing 0o/0b integers.
 func inferBaseInt(mv *Mlrval, base int) *Mlrval {
 	var input string
 	var negate bool
@@ -223,7 +212,6 @@ func inferBaseInt(mv *Mlrval, base int) *Mlrval {
 			intval = -intval
 		}
 		return mv.SetFromPrevalidatedIntString(mv.printrep, intval)
-	} else {
-		return mv.SetFromString(mv.printrep)
 	}
+	return mv.SetFromString(mv.printrep)
 }
