@@ -39,9 +39,8 @@ func (mv *Mlrval) String() string {
 func (mv *Mlrval) OriginalString() string {
 	if mv.printrepValid {
 		return mv.printrep
-	} else {
-		return mv.String()
 	}
+	return mv.String()
 }
 
 // StringMaybeQuoted Returns strings double-quoted; all else not.
@@ -49,9 +48,8 @@ func (mv *Mlrval) StringMaybeQuoted() string {
 	output := mv.String()
 	if mv.mvtype == MT_VOID || mv.mvtype == MT_STRING {
 		return `"` + output + `"`
-	} else {
-		return output
 	}
+	return output
 }
 
 // See mlrval.go for more about JIT-formatting of string backings
@@ -97,7 +95,7 @@ func (mv *Mlrval) setPrintRep() {
 			bytes, err := mv.MarshalJSON(JSON_MULTILINE, false)
 			// maybe just InternalCodingErrorIf(err != nil)
 			if err != nil {
-				fmt.Fprintln(os.Stderr, err)
+				fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 				os.Exit(1)
 			}
 			mv.printrep = string(bytes)
@@ -106,7 +104,7 @@ func (mv *Mlrval) setPrintRep() {
 			bytes, err := mv.MarshalJSON(JSON_MULTILINE, false)
 			// maybe just InternalCodingErrorIf(err != nil)
 			if err != nil {
-				fmt.Fprintln(os.Stderr, err)
+				fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 				os.Exit(1)
 			}
 			mv.printrep = string(bytes)
@@ -135,9 +133,9 @@ func (mv *Mlrval) StringifyValuesRecursively() {
 }
 
 func (mv *Mlrval) ShowSizes() {
-	fmt.Printf("TOTAL            %p %d\n", mv, reflect.TypeOf(*mv).Size())
+	fmt.Printf("TOTAL            %p %d\n", mv, reflect.TypeFor[Mlrval]().Size())
 	//fmt.Printf("mv.intf          %p %d\n", &mv.intf, reflect.TypeOf(mv.intf).Size())
-	fmt.Printf("mv.printrep      %p %d\n", &mv.printrep, reflect.TypeOf(mv.printrep).Size())
-	fmt.Printf("mv.printrepValid %p %d\n", &mv.printrepValid, reflect.TypeOf(mv.printrepValid).Size())
-	fmt.Printf("mv.mvtype        %p %d\n", &mv.mvtype, reflect.TypeOf(mv.mvtype).Size())
+	fmt.Printf("mv.printrep      %p %d\n", &mv.printrep, reflect.TypeFor[string]().Size())
+	fmt.Printf("mv.printrepValid %p %d\n", &mv.printrepValid, reflect.TypeFor[bool]().Size())
+	fmt.Printf("mv.mvtype        %p %d\n", &mv.mvtype, reflect.TypeFor[MVType]().Size())
 }
