@@ -18,6 +18,10 @@ func Create(writerOptions *cli.TWriterOptions) (IRecordWriter, error) {
 		return NewRecordWriterJSON(writerOptions)
 	case "jsonl":
 		return NewRecordWriterJSONLines(writerOptions)
+	case "yaml":
+		return NewRecordWriterYAML(writerOptions)
+	case "dcf":
+		return NewRecordWriterDCF(writerOptions)
 	case "md":
 		return NewRecordWriterMarkdown(writerOptions)
 	case "markdown":
