@@ -2,7 +2,6 @@ package output
 
 import (
 	"bufio"
-	"container/list"
 	"fmt"
 	"strings"
 	"unicode/utf8"
@@ -16,24 +15,23 @@ import (
 type RecordWriterPPRINT struct {
 	writerOptions *cli.TWriterOptions
 	// Input:
-	records *list.List
+	records []*mlrval.Mlrmap
 
 	// State:
 	lastJoinedHeader *string
-	batch            *list.List
+	batch            []*mlrval.Mlrmap
 }
 
 func NewRecordWriterPPRINT(writerOptions *cli.TWriterOptions) (*RecordWriterPPRINT, error) {
 	return &RecordWriterPPRINT{
 		writerOptions: writerOptions,
-		records:       list.New(),
+		records:       []*mlrval.Mlrmap{},
 
 		lastJoinedHeader: nil,
-		batch:            list.New(),
+		batch:            []*mlrval.Mlrmap{},
 	}, nil
 }
 
-// ----------------------------------------------------------------
 func (writer *RecordWriterPPRINT) Write(
 	outrec *mlrval.Mlrmap,
 	_ *types.Context,
@@ -51,7 +49,7 @@ func (writer *RecordWriterPPRINT) Write(
 			// First output record:
 			// * New batch
 			// * No old batch to print
-			writer.batch.PushBack(outrec)
+			writer.batch = append(writer.batch, outrec)
 			temp := strings.Join(outrec.GetKeys(), ",")
 			writer.lastJoinedHeader = &temp
 		} else {
@@ -70,17 +68,16 @@ func (writer *RecordWriterPPRINT) Write(
 					bufferedOutputStream.WriteString(writer.writerOptions.ORS)
 				}
 				// Start a new batch
-				writer.batch = list.New()
-				writer.batch.PushBack(outrec)
+				writer.batch = []*mlrval.Mlrmap{outrec}
 				writer.lastJoinedHeader = &joinedHeader
 			} else {
 				// Continue the batch
-				writer.batch.PushBack(outrec)
+				writer.batch = append(writer.batch, outrec)
 			}
 		}
 
 	} else { // End of record stream
-		if writer.batch.Front() != nil {
+		if len(writer.batch) > 0 {
 			writer.writeHeterogenousList(writer.batch, writer.writerOptions.BarredPprintOutput,
 				bufferedOutputStream, outputIsStdout)
 		}
@@ -89,10 +86,9 @@ func (writer *RecordWriterPPRINT) Write(
 	return nil
 }
 
-// ----------------------------------------------------------------
 // Returns false if there was nothing but empty record(s), e.g. 'mlr gap -n 10'.
 func (writer *RecordWriterPPRINT) writeHeterogenousList(
-	records *list.List,
+	records []*mlrval.Mlrmap,
 	barred bool,
 	bufferedOutputStream *bufio.Writer,
 	outputIsStdout bool,
@@ -100,8 +96,7 @@ func (writer *RecordWriterPPRINT) writeHeterogenousList(
 	maxWidths := make(map[string]int)
 	var maxNR int64 = 0
 
-	for e := records.Front(); e != nil; e = e.Next() {
-		outrec := e.Value.(*mlrval.Mlrmap)
+	for _, outrec := range records {
 		nr := outrec.FieldCount
 		if maxNR < nr {
 			maxNR = nr
@@ -120,24 +115,22 @@ func (writer *RecordWriterPPRINT) writeHeterogenousList(
 
 	if maxNR == 0 {
 		return false
-	} else {
-		// Column name may be longer/shorter than all data values in the column
-		for key, oldMaxWidth := range maxWidths {
-			width := utf8.RuneCountInString(key)
-			if width > oldMaxWidth {
-				maxWidths[key] = width
-			}
-		}
-		if barred {
-			writer.writeHeterogenousListBarred(records, maxWidths, bufferedOutputStream, outputIsStdout)
-		} else {
-			writer.writeHeterogenousListNonBarred(records, maxWidths, bufferedOutputStream, outputIsStdout)
-		}
-		return true
 	}
+	// Column name may be longer/shorter than all data values in the column
+	for key, oldMaxWidth := range maxWidths {
+		width := utf8.RuneCountInString(key)
+		if width > oldMaxWidth {
+			maxWidths[key] = width
+		}
+	}
+	if barred {
+		writer.writeHeterogenousListBarred(records, maxWidths, bufferedOutputStream, outputIsStdout)
+	} else {
+		writer.writeHeterogenousListNonBarred(records, maxWidths, bufferedOutputStream, outputIsStdout)
+	}
+	return true
 }
 
-// ----------------------------------------------------------------
 // Example:
 //
 // a   b   i  x                    y
@@ -148,15 +141,14 @@ func (writer *RecordWriterPPRINT) writeHeterogenousList(
 // wye pan 5  0.5732889198020006   0.8636244699032729
 
 func (writer *RecordWriterPPRINT) writeHeterogenousListNonBarred(
-	records *list.List,
+	records []*mlrval.Mlrmap,
 	maxWidths map[string]int,
 	bufferedOutputStream *bufio.Writer,
 	outputIsStdout bool,
 ) {
 
 	onFirst := true
-	for e := records.Front(); e != nil; e = e.Next() {
-		outrec := e.Value.(*mlrval.Mlrmap)
+	for _, outrec := range records {
 
 		// Print header line
 		if onFirst && !writer.writerOptions.HeaderlessOutput {
@@ -224,7 +216,6 @@ func (writer *RecordWriterPPRINT) writeHeterogenousListNonBarred(
 	}
 }
 
-// ----------------------------------------------------------------
 // Example:
 //
 // +-----+-----+----+----------------------+---------------------+
@@ -238,7 +229,7 @@ func (writer *RecordWriterPPRINT) writeHeterogenousListNonBarred(
 // +-----+-----+----+----------------------+---------------------+
 
 func (writer *RecordWriterPPRINT) writeHeterogenousListBarred(
-	records *list.List,
+	records []*mlrval.Mlrmap,
 	maxWidths map[string]int,
 	bufferedOutputStream *bufio.Writer,
 	outputIsStdout bool,
@@ -257,8 +248,7 @@ func (writer *RecordWriterPPRINT) writeHeterogenousListBarred(
 	verticalEnd := ofs + "|"
 
 	onFirst := true
-	for e := records.Front(); e != nil; e = e.Next() {
-		outrec := e.Value.(*mlrval.Mlrmap)
+	for i, outrec := range records {
 
 		// Print header line
 		if onFirst && !writer.writerOptions.HeaderlessOutput {
@@ -322,7 +312,7 @@ func (writer *RecordWriterPPRINT) writeHeterogenousListBarred(
 			}
 		}
 
-		if e.Next() == nil {
+		if i == len(records)-1 {
 			bufferedOutputStream.WriteString(horizontalStart)
 			for pe := outrec.Head; pe != nil; pe = pe.Next {
 				bufferedOutputStream.WriteString(horizontalBars[pe.Key])
@@ -349,7 +339,7 @@ func (writer *RecordWriterPPRINT) writePadding(
 	textWidth := utf8.RuneCountInString(text)
 	padWidth := fieldWidth - textWidth
 	ofs := writer.writerOptions.OFS
-	for i := 0; i < padWidth; i++ {
+	for range padWidth {
 		bufferedOutputStream.WriteString(ofs)
 	}
 }
