@@ -2,7 +2,6 @@ package transformers
 
 import (
 	"bytes"
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -19,7 +18,6 @@ const barDefaultLo = 0.0
 const barDefaultHi = 100.0
 const barDefaultWidth = int64(40)
 
-// ----------------------------------------------------------------
 const verbNameBar = "bar"
 
 var BarSetup = TransformerSetup{
@@ -56,7 +54,7 @@ func transformerBarParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -64,6 +62,7 @@ func transformerBarParseCLI(
 	argi++
 
 	// Parse local flags
+	var err error
 	var fieldNames []string = nil
 	lo := barDefaultLo
 	hi := barDefaultHi
@@ -85,42 +84,61 @@ func transformerBarParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerBarUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			fieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			fieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--lo" {
-			lo = cli.VerbGetFloatArgOrDie(verb, opt, args, &argi, argc)
+			lo, err = cli.VerbGetFloatArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-w" {
-			width = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			width, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "--hi" {
-			hi = cli.VerbGetFloatArgOrDie(verb, opt, args, &argi, argc)
+			hi, err = cli.VerbGetFloatArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-c" {
-			fillString = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			fillString, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-x" {
-			oobString = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			oobString, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-b" {
-			blankString = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			blankString, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--auto" {
 			doAuto = true
 
 		} else {
-			transformerBarUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if fieldNames == nil {
-		transformerBarUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-f field names required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerBar(
@@ -134,14 +152,12 @@ func transformerBarParseCLI(
 		blankString,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerBar struct {
 	fieldNames         []string
 	lo                 float64
@@ -151,12 +167,11 @@ type TransformerBar struct {
 	oobString          string
 	blankString        string
 	bars               []string
-	recordsForAutoMode *list.List
+	recordsForAutoMode []*types.RecordAndContext
 
 	recordTransformerFunc RecordTransformerFunc
 }
 
-// ----------------------------------------------------------------
 func NewTransformerBar(
 	fieldNames []string,
 	lo float64,
@@ -194,7 +209,7 @@ func NewTransformerBar(
 
 	if doAuto {
 		tr.recordTransformerFunc = tr.processAuto
-		tr.recordsForAutoMode = list.New()
+		tr.recordsForAutoMode = []*types.RecordAndContext{}
 	} else {
 		tr.recordTransformerFunc = tr.processNoAuto
 		tr.recordsForAutoMode = nil
@@ -203,11 +218,9 @@ func NewTransformerBar(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerBar) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -215,10 +228,9 @@ func (tr *TransformerBar) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerBar) processNoAuto(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -234,31 +246,24 @@ func (tr *TransformerBar) processNoAuto(
 			if !ok {
 				continue
 			}
-			idx := int(float64(tr.width) * (floatValue - tr.lo) / (tr.hi - tr.lo))
-			if idx < 0 {
-				idx = 0
-			}
-			if idx > tr.width {
-				idx = tr.width
-			}
+			idx := min(max(int(float64(tr.width)*(floatValue-tr.lo)/(tr.hi-tr.lo)), 0), tr.width)
 			inrec.PutReference(fieldName, mlrval.FromString(tr.bars[idx]))
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerBar) processAuto(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
-		tr.recordsForAutoMode.PushBack(inrecAndContext.Copy())
+		tr.recordsForAutoMode = append(tr.recordsForAutoMode, inrecAndContext.Copy())
 		return
 	}
 
@@ -271,9 +276,8 @@ func (tr *TransformerBar) processAuto(
 
 		// The first pass computes lo and hi from the data
 		onFirst := true
-		for e := tr.recordsForAutoMode.Front(); e != nil; e = e.Next() {
-			recordAndContexts := e.Value.(*types.RecordAndContext)
-			record := recordAndContexts.Record
+		for _, recordAndContext := range tr.recordsForAutoMode {
+			record := recordAndContext.Record
 			mvalue := record.Get(fieldName)
 			if mvalue == nil {
 				continue
@@ -301,8 +305,7 @@ func (tr *TransformerBar) processAuto(
 		slo := fmt.Sprintf("%g", lo)
 		shi := fmt.Sprintf("%g", hi)
 
-		for e := tr.recordsForAutoMode.Front(); e != nil; e = e.Next() {
-			recordAndContext := e.Value.(*types.RecordAndContext)
+		for _, recordAndContext := range tr.recordsForAutoMode {
 			record := recordAndContext.Record
 			mvalue := record.Get(fieldName)
 			if mvalue == nil {
@@ -313,13 +316,7 @@ func (tr *TransformerBar) processAuto(
 				continue
 			}
 
-			idx := int((float64(tr.width) * (floatValue - lo) / (hi - lo)))
-			if idx < 0 {
-				idx = 0
-			}
-			if idx > tr.width {
-				idx = tr.width
-			}
+			idx := min(max(int((float64(tr.width)*(floatValue-lo)/(hi-lo))), 0), tr.width)
 
 			var buffer bytes.Buffer
 			buffer.WriteString("[")
@@ -333,10 +330,7 @@ func (tr *TransformerBar) processAuto(
 		}
 	}
 
-	for e := tr.recordsForAutoMode.Front(); e != nil; e = e.Next() {
-		recordAndContext := e.Value.(*types.RecordAndContext)
-		outputRecordsAndContexts.PushBack(recordAndContext)
-	}
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, tr.recordsForAutoMode...)
 
-	outputRecordsAndContexts.PushBack(inrecAndContext) // Emit the end-of-stream marker
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // Emit the end-of-stream marker
 }
