@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameBootstrap = "bootstrap"
 
 var BootstrapSetup = TransformerSetup{
@@ -43,13 +41,14 @@ func transformerBootstrapParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
 	verb := args[argi]
 	argi++
 
+	var err error
 	nout := int64(-1)
 
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
@@ -64,57 +63,55 @@ func transformerBootstrapParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerBootstrapUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			nout = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			nout, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerBootstrapUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerBootstrap(nout)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerBootstrap struct {
-	recordsAndContexts *list.List
+	recordsAndContexts []*types.RecordAndContext
 	nout               int64
 }
 
 func NewTransformerBootstrap(nout int64) (*TransformerBootstrap, error) {
 	tr := &TransformerBootstrap{
-		recordsAndContexts: list.New(),
+		recordsAndContexts: []*types.RecordAndContext{},
 		nout:               nout,
 	}
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerBootstrap) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	HandleDefaultDownstreamDone(inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 	// Not end of input stream: retain the record, and emit nothing until end of stream.
 	if !inrecAndContext.EndOfStream {
-		tr.recordsAndContexts.PushBack(inrecAndContext)
+		tr.recordsAndContexts = append(tr.recordsAndContexts, inrecAndContext)
 		return
 	}
 
@@ -141,8 +138,7 @@ func (tr *TransformerBootstrap) Transform(
 	//
 	// For that reason, this transformer must copy all output.
 
-	// TODO: Go list Len() maxes at 2^31. We should track this ourselves in an int.
-	nin := int64(tr.recordsAndContexts.Len())
+	nin := int64(len(tr.recordsAndContexts))
 	nout := tr.nout
 	if nout == -1 {
 		nout = nin
@@ -150,20 +146,12 @@ func (tr *TransformerBootstrap) Transform(
 
 	if nout == 0 {
 		// Emit the stream-terminating null record
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		return
 	}
 
 	// Make an array of pointers into the input list.
-	recordArray := make([]*types.RecordAndContext, nin)
-	for i := int64(0); i < nin; i++ {
-		head := tr.recordsAndContexts.Front()
-		if head == nil {
-			break
-		}
-		recordArray[i] = head.Value.(*types.RecordAndContext)
-		tr.recordsAndContexts.Remove(head)
-	}
+	recordArray := tr.recordsAndContexts
 
 	// Do the sample-with-replacment, reading from random indices in the input
 	// array and emitting output.
@@ -171,9 +159,9 @@ func (tr *TransformerBootstrap) Transform(
 		index := lib.RandRange(0, nin)
 		recordAndContext := recordArray[index]
 		// Already emitted once; copy
-		outputRecordsAndContexts.PushBack(recordAndContext.Copy())
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, recordAndContext.Copy())
 	}
 
 	// Emit the stream-terminating null record
-	outputRecordsAndContexts.PushBack(inrecAndContext)
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 }
