@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -12,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameCount = "count"
 
 var CountSetup = TransformerSetup{
@@ -42,7 +40,7 @@ func transformerCountParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -53,6 +51,7 @@ func transformerCountParseCLI(
 	showCountsOnly := false
 	outputFieldName := "count"
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -65,26 +64,31 @@ func transformerCountParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerCountUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-n" {
 			showCountsOnly = true
 
 		} else if opt == "-o" {
-			outputFieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			outputFieldName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerCountUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerCount(
@@ -93,14 +97,12 @@ func transformerCountParseCLI(
 		outputFieldName,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerCount struct {
 	// input
 	groupByFieldNames []string
@@ -117,8 +119,8 @@ type TransformerCount struct {
 	// * Map keys are strings "foo,bar" and "baz,quux".
 	// * groupedCounts maps "foo,bar" to 1 and "baz,quux" to 1.
 	// * groupByValues maps "foo,bar" to ["foo", "bar"] and "baz,quux" to ["baz", "quux"].
-	groupedCounts  *lib.OrderedMap
-	groupingValues *lib.OrderedMap
+	groupedCounts  *lib.OrderedMap[int64]
+	groupingValues *lib.OrderedMap[[]*mlrval.Mlrval]
 }
 
 func NewTransformerCount(
@@ -133,8 +135,8 @@ func NewTransformerCount(
 		outputFieldName:   outputFieldName,
 
 		ungroupedCount: 0,
-		groupedCounts:  lib.NewOrderedMap(),
-		groupingValues: lib.NewOrderedMap(),
+		groupedCounts:  lib.NewOrderedMap[int64](),
+		groupingValues: lib.NewOrderedMap[[]*mlrval.Mlrval](),
 	}
 
 	if groupByFieldNames == nil {
@@ -146,11 +148,9 @@ func NewTransformerCount(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerCount) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -158,10 +158,9 @@ func (tr *TransformerCount) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerCount) countUngrouped(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -170,16 +169,15 @@ func (tr *TransformerCount) countUngrouped(
 	} else {
 		newrec := mlrval.NewMlrmapAsRecord()
 		newrec.PutCopy(tr.outputFieldName, mlrval.FromInt(tr.ungroupedCount))
-		outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerCount) countGrouped(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -200,7 +198,7 @@ func (tr *TransformerCount) countGrouped(
 		} else {
 			tr.groupedCounts.Put(
 				groupingKey,
-				tr.groupedCounts.Get(groupingKey).(int64)+1,
+				tr.groupedCounts.Get(groupingKey)+1,
 			)
 		}
 
@@ -210,7 +208,7 @@ func (tr *TransformerCount) countGrouped(
 			newrec.PutCopy(tr.outputFieldName, mlrval.FromInt(tr.groupedCounts.FieldCount))
 
 			outrecAndContext := types.NewRecordAndContext(newrec, &inrecAndContext.Context)
-			outputRecordsAndContexts.PushBack(outrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 
 		} else {
 			for outer := tr.groupedCounts.Head; outer != nil; outer = outer.Next {
@@ -224,21 +222,21 @@ func (tr *TransformerCount) countGrouped(
 				// * Grouping values for key is ["foo", "bar"]
 				// Here we populate a record with "a=foo,b=bar".
 
-				groupingValuesForKey := tr.groupingValues.Get(groupingKey).([]*mlrval.Mlrval)
+				groupingValuesForKey := tr.groupingValues.Get(groupingKey)
 				i := 0
 				for _, groupingValueForKey := range groupingValuesForKey {
 					newrec.PutCopy(tr.groupByFieldNames[i], groupingValueForKey)
 					i++
 				}
 
-				countForGroup := outer.Value.(int64)
+				countForGroup := outer.Value
 				newrec.PutCopy(tr.outputFieldName, mlrval.FromInt(countForGroup))
 
 				outrecAndContext := types.NewRecordAndContext(newrec, &inrecAndContext.Context)
-				outputRecordsAndContexts.PushBack(outrecAndContext)
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
