@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -12,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameCountSimilar = "count-similar"
 
 var CountSimilarSetup = TransformerSetup{
@@ -40,7 +38,7 @@ func transformerCountSimilarParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -50,6 +48,7 @@ func transformerCountSimilarParseCLI(
 	var groupByFieldNames []string = nil
 	counterFieldName := "count"
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -62,28 +61,32 @@ func transformerCountSimilarParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerCountSimilarUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-o" {
-			counterFieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			counterFieldName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerCountSimilarUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if groupByFieldNames == nil {
-		transformerCountSimilarUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-g field names required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerCountSimilar(
@@ -91,24 +94,21 @@ func transformerCountSimilarParseCLI(
 		counterFieldName,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerCountSimilar struct {
 	// Input:
 	groupByFieldNames []string
 	counterFieldName  string
 
 	// State:
-	recordListsByGroup *lib.OrderedMap // map from string to *list.List
+	recordListsByGroup *lib.OrderedMap[*[]*types.RecordAndContext] // map from string to records
 }
 
-// ----------------------------------------------------------------
 func NewTransformerCountSimilar(
 	groupByFieldNames []string,
 	counterFieldName string,
@@ -116,16 +116,14 @@ func NewTransformerCountSimilar(
 	tr := &TransformerCountSimilar{
 		groupByFieldNames:  groupByFieldNames,
 		counterFieldName:   counterFieldName,
-		recordListsByGroup: lib.NewOrderedMap(),
+		recordListsByGroup: lib.NewOrderedMap[*[]*types.RecordAndContext](),
 	}
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerCountSimilar) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -138,29 +136,28 @@ func (tr *TransformerCountSimilar) Transform(
 			return
 		}
 
-		irecordListForGroup := tr.recordListsByGroup.Get(groupingKey)
-		if irecordListForGroup == nil { // first time
-			irecordListForGroup = list.New()
-			tr.recordListsByGroup.Put(groupingKey, irecordListForGroup)
+		recordListForGroup := tr.recordListsByGroup.Get(groupingKey)
+		if recordListForGroup == nil { // first time
+			records := []*types.RecordAndContext{}
+			recordListForGroup = &records
+			tr.recordListsByGroup.Put(groupingKey, recordListForGroup)
 		}
-		recordListForGroup := irecordListForGroup.(*list.List)
 
-		recordListForGroup.PushBack(inrecAndContext)
+		*recordListForGroup = append(*recordListForGroup, inrecAndContext)
 	} else {
 
 		for outer := tr.recordListsByGroup.Head; outer != nil; outer = outer.Next {
-			recordListForGroup := outer.Value.(*list.List)
+			recordListForGroup := outer.Value
 			// TODO: make 64-bit friendly
-			groupSize := recordListForGroup.Len()
+			groupSize := len(*recordListForGroup)
 			mgroupSize := mlrval.FromInt(int64(groupSize))
-			for inner := recordListForGroup.Front(); inner != nil; inner = inner.Next() {
-				recordAndContext := inner.Value.(*types.RecordAndContext)
+			for _, recordAndContext := range *recordListForGroup {
 				recordAndContext.Record.PutCopy(tr.counterFieldName, mgroupSize)
 
-				outputRecordsAndContexts.PushBack(recordAndContext)
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, recordAndContext)
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // Emit the stream-terminating null record
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // Emit the stream-terminating null record
 	}
 }
