@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -10,7 +9,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameDecimate = "decimate"
 
 var DecimateSetup = TransformerSetup{
@@ -39,13 +37,14 @@ func transformerDecimateParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
 	verb := args[argi]
 	argi++
 
+	var err error
 	decimateCount := int64(10)
 	atStart := false
 	atEnd := false
@@ -63,13 +62,15 @@ func transformerDecimateParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerDecimateUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			decimateCount = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			decimateCount, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			if decimateCount <= 0 {
-				transformerDecimateUsage(os.Stderr)
-				os.Exit(1)
+				return nil, cli.VerbErrorf(verb, "-n must be positive")
 			}
 
 		} else if opt == "-b" {
@@ -79,17 +80,19 @@ func transformerDecimateParseCLI(
 			atEnd = true
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerDecimateUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerDecimate(
@@ -99,14 +102,12 @@ func transformerDecimateParseCLI(
 		groupByFieldNames,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerDecimate struct {
 	decimateCount     int64
 	remainderToKeep   int64
@@ -115,7 +116,6 @@ type TransformerDecimate struct {
 	countsByGroup map[string]int64
 }
 
-// ----------------------------------------------------------------
 func NewTransformerDecimate(
 	decimateCount int64,
 	atStart bool,
@@ -138,11 +138,9 @@ func NewTransformerDecimate(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerDecimate) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -163,13 +161,13 @@ func (tr *TransformerDecimate) Transform(
 
 		remainder := countForGroup % tr.decimateCount
 		if remainder == tr.remainderToKeep {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 
 		countForGroup++
 		tr.countsByGroup[groupingKey] = countForGroup
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // Emit the stream-terminating null record
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // Emit the stream-terminating null record
 	}
 }
