@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameFormatValues = "format-values"
 
 const defaultFormatValuesStringFormat = "%s"
@@ -25,7 +23,6 @@ var FormatValuesSetup = TransformerSetup{
 	IgnoresInput: false,
 }
 
-// ----------------------------------------------------------------
 func transformerFormatValuesUsage(
 	o *os.File,
 ) {
@@ -66,7 +63,7 @@ func transformerFormatValuesParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -78,6 +75,7 @@ func transformerFormatValuesParseCLI(
 	floatFormat := defaultFormatValuesFloatFormat
 	coerceIntToFloat := false
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -90,26 +88,34 @@ func transformerFormatValuesParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerFormatValuesUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-s" {
-			stringFormat = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			stringFormat, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-i" {
-			intFormat = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			intFormat, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-f" {
-			floatFormat = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			floatFormat, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-n" {
 			coerceIntToFloat = true
 
 		} else {
-			transformerFormatValuesUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerFormatValues(
@@ -119,14 +125,12 @@ func transformerFormatValuesParseCLI(
 		coerceIntToFloat,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerFormatValues struct {
 	stringFormatter  mlrval.IFormatter
 	intFormatter     mlrval.IFormatter
@@ -164,17 +168,15 @@ func NewTransformerFormatValues(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerFormatValues) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	HandleDefaultDownstreamDone(inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 	if inrecAndContext.EndOfStream {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 		return
 	}
 
@@ -199,5 +201,5 @@ func (tr *TransformerFormatValues) Transform(
 		}
 	}
 
-	outputRecordsAndContexts.PushBack(inrecAndContext)
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 }
