@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"errors"
 	"fmt"
 	"os"
@@ -14,7 +13,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameFraction = "fraction"
 
 var FractionSetup = TransformerSetup{
@@ -57,7 +55,7 @@ func transformerFractionParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -70,6 +68,7 @@ func transformerFractionParseCLI(
 	doPercents := false
 	doCumu := false
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -82,13 +81,19 @@ func transformerFractionParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerFractionUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			fractionFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			fractionFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-p" {
 			doPercents = true
@@ -97,19 +102,17 @@ func transformerFractionParseCLI(
 			doCumu = true
 
 		} else {
-			transformerFractionUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if fractionFieldNames == nil {
-		transformerFractionUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-f field names required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerFraction(
@@ -119,20 +122,18 @@ func transformerFractionParseCLI(
 		doCumu,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerFraction struct {
 	fractionFieldNames []string
 	groupByFieldNames  []string
 	doCumu             bool
 
-	recordsAndContexts *list.List
+	recordsAndContexts []*types.RecordAndContext
 	// Two-level map: Group-by field names are the first keyset;
 	// fraction field names are keys into the second.
 	sums  map[string]map[string]*mlrval.Mlrval
@@ -143,7 +144,6 @@ type TransformerFraction struct {
 	zero                  *mlrval.Mlrval
 }
 
-// ----------------------------------------------------------------
 func NewTransformerFraction(
 	fractionFieldNames []string,
 	groupByFieldNames []string,
@@ -151,7 +151,7 @@ func NewTransformerFraction(
 	doCumu bool,
 ) (*TransformerFraction, error) {
 
-	recordsAndContexts := list.New()
+	recordsAndContexts := []*types.RecordAndContext{}
 	sums := make(map[string]map[string]*mlrval.Mlrval)
 	cumus := make(map[string]map[string]*mlrval.Mlrval)
 
@@ -188,11 +188,9 @@ func NewTransformerFraction(
 	}, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerFraction) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -201,7 +199,7 @@ func (tr *TransformerFraction) Transform(
 		inrec := inrecAndContext.Record
 
 		// Append records into a single output list (so that this verb is order-preserving).
-		tr.recordsAndContexts.PushBack(inrecAndContext)
+		tr.recordsAndContexts = append(tr.recordsAndContexts, inrecAndContext)
 
 		// Accumulate sums of fraction-field values grouped by group-by field names
 		groupingKey, hasAll := inrec.GetSelectedValuesJoined(tr.groupByFieldNames)
@@ -234,13 +232,7 @@ func (tr *TransformerFraction) Transform(
 		// Iterate over the retained records, decorating them with fraction fields.
 		endOfStreamContext := inrecAndContext.Context
 
-		for {
-			element := tr.recordsAndContexts.Front()
-			if element == nil {
-				break
-			}
-			tr.recordsAndContexts.Remove(element)
-			recordAndContext := element.Value.(*types.RecordAndContext)
+		for _, recordAndContext := range tr.recordsAndContexts {
 			outrec := recordAndContext.Record
 
 			groupingKey, hasAll := outrec.GetSelectedValuesJoined(tr.groupByFieldNames)
@@ -292,8 +284,9 @@ func (tr *TransformerFraction) Transform(
 				}
 			}
 
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &endOfStreamContext))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &endOfStreamContext))
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		tr.recordsAndContexts = tr.recordsAndContexts[:0]
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
