@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"regexp"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameGrep = "grep"
 
 var GrepSetup = TransformerSetup{
@@ -53,7 +51,7 @@ func transformerGrepParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -76,7 +74,7 @@ func transformerGrepParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerGrepUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-i" {
 			ignoreCase = true
@@ -88,15 +86,13 @@ func transformerGrepParseCLI(
 			valuesOnly = true
 
 		} else {
-			transformerGrepUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	// Get the regex from the command line
 	if argi >= argc {
-		transformerGrepUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "pattern required")
 	}
 	pattern := args[argi]
 	argi++
@@ -108,14 +104,12 @@ func transformerGrepParseCLI(
 	// TODO: maybe CompilePOSIX
 	regexp, err := regexp.Compile(pattern)
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "%s %s: couldn't compile regex \"%s\"\n",
-			"mlr", verb, pattern)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "invalid regex \"%s\": %w", pattern, err)
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerGrep(
@@ -124,14 +118,12 @@ func transformerGrepParseCLI(
 		valuesOnly,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerGrep struct {
 	regexp     *regexp.Regexp
 	invert     bool
@@ -151,11 +143,9 @@ func NewTransformerGrep(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerGrep) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -171,14 +161,14 @@ func (tr *TransformerGrep) Transform(
 		matches := tr.regexp.MatchString(inrecAsString)
 		if tr.invert {
 			if !matches {
-				outputRecordsAndContexts.PushBack(inrecAndContext)
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			}
 		} else {
 			if matches {
-				outputRecordsAndContexts.PushBack(inrecAndContext)
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			}
 		}
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
