@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameGroupLike = "group-like"
 
 var GroupLikeSetup = TransformerSetup{
@@ -36,7 +34,7 @@ func transformerGroupLikeParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -54,48 +52,42 @@ func transformerGroupLikeParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerGroupLikeUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
-		} else {
-			transformerGroupLikeUsage(os.Stderr)
-			os.Exit(1)
 		}
+		return nil, cli.VerbErrorf(verbNameGroupLike, "option \"%s\" not recognized", opt)
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerGroupLike()
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerGroupLike struct {
-	// map from string to *list.List
-	recordListsByGroup *lib.OrderedMap
+	// map from string to record slices
+	recordListsByGroup *lib.OrderedMap[*[]*types.RecordAndContext]
 }
 
 func NewTransformerGroupLike() (*TransformerGroupLike, error) {
 
 	tr := &TransformerGroupLike{
-		recordListsByGroup: lib.NewOrderedMap(),
+		recordListsByGroup: lib.NewOrderedMap[*[]*types.RecordAndContext](),
 	}
 
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerGroupLike) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -107,19 +99,17 @@ func (tr *TransformerGroupLike) Transform(
 
 		recordListForGroup := tr.recordListsByGroup.Get(groupingKey)
 		if recordListForGroup == nil { // first time
-			recordListForGroup = list.New()
+			records := []*types.RecordAndContext{}
+			recordListForGroup = &records
 			tr.recordListsByGroup.Put(groupingKey, recordListForGroup)
 		}
 
-		recordListForGroup.(*list.List).PushBack(inrecAndContext)
+		*recordListForGroup = append(*recordListForGroup, inrecAndContext)
 
 	} else {
 		for outer := tr.recordListsByGroup.Head; outer != nil; outer = outer.Next {
-			recordListForGroup := outer.Value.(*list.List)
-			for inner := recordListForGroup.Front(); inner != nil; inner = inner.Next() {
-				outputRecordsAndContexts.PushBack(inner.Value.(*types.RecordAndContext))
-			}
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, *outer.Value...)
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
