@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -14,7 +13,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameJoin = "join"
 
 var JoinSetup = TransformerSetup{
@@ -24,7 +22,6 @@ var JoinSetup = TransformerSetup{
 	IgnoresInput: false,
 }
 
-// ----------------------------------------------------------------
 // Most transformers have option-variables as individual locals within the
 // transformerXYZParseCLI function, which are passed as individual arguments to
 // the NewTransformerXYZ function. For join, things are a bit more complex
@@ -73,7 +70,6 @@ func newJoinOptions() *tJoinOptions {
 	}
 }
 
-// ----------------------------------------------------------------
 func transformerJoinUsage(
 	o *os.File,
 ) {
@@ -134,14 +130,13 @@ func transformerJoinUsage(
 	fmt.Fprintf(o, "including examples.\n")
 }
 
-// ----------------------------------------------------------------
 func transformerJoinParseCLI(
 	pargi *int,
 	argc int,
 	args []string,
 	mainOptions *cli.TOptions, // Options for the right-files
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -156,6 +151,7 @@ func transformerJoinParseCLI(
 		opts.joinFlagOptions = *mainOptions // struct copy
 	}
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -168,36 +164,63 @@ func transformerJoinParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerJoinUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "--prepipe" {
-			opts.prepipe = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			opts.prepipe, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			opts.prepipeIsRaw = false
 
 		} else if opt == "--prepipex" {
-			opts.prepipe = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			opts.prepipe, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			opts.prepipeIsRaw = true
 
 		} else if opt == "-f" {
-			opts.leftFileName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			opts.leftFileName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-j" {
-			opts.outputJoinFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			opts.outputJoinFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-l" {
-			opts.leftJoinFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			opts.leftJoinFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--lk" || opt == "--left-keep-field-names" {
-			opts.leftKeepFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			opts.leftKeepFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-r" {
-			opts.rightJoinFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			opts.rightJoinFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--lp" {
-			opts.leftPrefix = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			opts.leftPrefix, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--rp" {
-			opts.rightPrefix = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			opts.rightPrefix, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--np" {
 			opts.emitPairables = false
@@ -224,8 +247,7 @@ func transformerJoinParseCLI(
 				// Nothing else to handle here.
 				argi = largi
 			} else {
-				transformerJoinUsage(os.Stderr)
-				os.Exit(1)
+				return nil, cli.VerbErrorf(verb, "input format option not recognized")
 			}
 		}
 	}
@@ -233,25 +255,15 @@ func transformerJoinParseCLI(
 	cli.FinalizeReaderOptions(&opts.joinFlagOptions.ReaderOptions)
 
 	if opts.leftFileName == "" {
-		fmt.Fprintf(os.Stderr, "%s %s: need left file name\n", "mlr", verb)
-		transformerJoinUsage(os.Stderr)
-		os.Exit(1)
-		return nil
+		return nil, cli.VerbErrorf(verb, "need left file name")
 	}
 
 	if !opts.emitPairables && !opts.emitLeftUnpairables && !opts.emitRightUnpairables {
-		fmt.Fprintf(os.Stderr, "%s %s: all emit flags are unset; no output is possible.\n",
-			"mlr", verb)
-		transformerJoinUsage(os.Stderr)
-		os.Exit(1)
-		return nil
+		return nil, cli.VerbErrorf(verb, "all emit flags are unset; no output is possible")
 	}
 
 	if opts.outputJoinFieldNames == nil {
-		fmt.Fprintf(os.Stderr, "%s %s: need output field names\n", "mlr", verb)
-		transformerJoinUsage(os.Stderr)
-		os.Exit(1)
-		return nil
+		return nil, cli.VerbErrorf(verb, "need output field names")
 	}
 
 	if opts.leftJoinFieldNames == nil {
@@ -265,27 +277,22 @@ func transformerJoinParseCLI(
 	rlen := len(opts.rightJoinFieldNames)
 	olen := len(opts.outputJoinFieldNames)
 	if llen != rlen || llen != olen {
-		fmt.Fprintf(os.Stderr,
-			"%s %s: must have equal left,right,output field-name lists; got lengths %d,%d,%d.\n",
-			"mlr", verb, llen, rlen, olen)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "left, right, and output field lists must have same length")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerJoin(opts)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerJoin struct {
 	opts *tJoinOptions
 
@@ -295,8 +302,8 @@ type TransformerJoin struct {
 
 	// For unsorted/half-streaming input
 	ingested                         bool
-	leftBucketsByJoinFieldValues     *lib.OrderedMap
-	leftUnpairableRecordsAndContexts *list.List
+	leftBucketsByJoinFieldValues     *lib.OrderedMap[*utils.JoinBucket]
+	leftUnpairableRecordsAndContexts []*types.RecordAndContext
 
 	// For sorted/doubly-streaming input
 	joinBucketKeeper *utils.JoinBucketKeeper
@@ -304,7 +311,6 @@ type TransformerJoin struct {
 	recordTransformerFunc RecordTransformerFunc
 }
 
-// ----------------------------------------------------------------
 func NewTransformerJoin(
 	opts *tJoinOptions,
 ) (*TransformerJoin, error) {
@@ -333,8 +339,8 @@ func NewTransformerJoin(
 	if opts.allowUnsortedInput {
 		// Half-streaming (default) case: ingest entire left file first.
 
-		tr.leftUnpairableRecordsAndContexts = list.New()
-		tr.leftBucketsByJoinFieldValues = lib.NewOrderedMap()
+		tr.leftUnpairableRecordsAndContexts = []*types.RecordAndContext{}
+		tr.leftBucketsByJoinFieldValues = lib.NewOrderedMap[*utils.JoinBucket]()
 		tr.recordTransformerFunc = tr.transformHalfStreaming
 
 	} else {
@@ -357,11 +363,9 @@ func NewTransformerJoin(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerJoin) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -370,12 +374,11 @@ func (tr *TransformerJoin) Transform(
 		inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 // This is for the half-streaming case. We ingest the entire left file,
 // matching each right record against those.
 func (tr *TransformerJoin) transformHalfStreaming(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -395,13 +398,12 @@ func (tr *TransformerJoin) transformHalfStreaming(
 			tr.opts.rightJoinFieldNames,
 		)
 		if hasAllJoinKeys {
-			iLeftBucket := tr.leftBucketsByJoinFieldValues.Get(groupingKey)
-			if iLeftBucket == nil {
+			leftBucket := tr.leftBucketsByJoinFieldValues.Get(groupingKey)
+			if leftBucket == nil {
 				if tr.opts.emitRightUnpairables {
-					outputRecordsAndContexts.PushBack(inrecAndContext)
+					*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 				}
 			} else {
-				leftBucket := iLeftBucket.(*utils.JoinBucket)
 				leftBucket.WasPaired = true
 				if tr.opts.emitPairables {
 					tr.formAndEmitPairs(
@@ -412,7 +414,7 @@ func (tr *TransformerJoin) transformHalfStreaming(
 				}
 			}
 		} else if tr.opts.emitRightUnpairables {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 
 	} else { // end of record stream
@@ -420,14 +422,13 @@ func (tr *TransformerJoin) transformHalfStreaming(
 			tr.emitLeftUnpairedBuckets(outputRecordsAndContexts)
 			tr.emitLeftUnpairables(outputRecordsAndContexts)
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerJoin) transformDoublyStreaming(
 	rightRecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -452,7 +453,7 @@ func (tr *TransformerJoin) transformDoublyStreaming(
 		lefts := keeper.JoinBucket.RecordsAndContexts // keystroke-saver
 
 		if !isPaired && tr.opts.emitRightUnpairables {
-			outputRecordsAndContexts.PushBack(rightRecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, rightRecAndContext)
 		}
 
 		if isPaired && tr.opts.emitPairables && lefts != nil {
@@ -466,11 +467,10 @@ func (tr *TransformerJoin) transformDoublyStreaming(
 			keeper.OutputAndReleaseLeftUnpaireds(outputRecordsAndContexts)
 		}
 
-		outputRecordsAndContexts.PushBack(rightRecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, rightRecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 // This is for the half-streaming case. We ingest the entire left file,
 // matching each right record against those.
 //
@@ -483,9 +483,9 @@ func (tr *TransformerJoin) ingestLeftFile() {
 	// Instantiate the record-reader
 	// TODO: perhaps increase recordsPerBatch, and/or refactor
 	recordReader, err := input.Create(readerOpts, 1)
-	if recordReader == nil {
-		fmt.Fprintf(os.Stderr, "mlr join: %v\n", err)
-		os.Exit(1)
+	if err != nil {
+		// TODO: propagate error to caller
+		return
 	}
 
 	// Set the initial context for the left-file.
@@ -496,7 +496,7 @@ func (tr *TransformerJoin) ingestLeftFile() {
 	initialContext.UpdateForStartOfFile(tr.opts.leftFileName)
 
 	// Set up channels for the record-reader.
-	readerChannel := make(chan *list.List, 2) // list of *types.RecordAndContext
+	readerChannel := make(chan []*types.RecordAndContext, 2) // list of *types.RecordAndContext
 	errorChannel := make(chan error, 1)
 	downstreamDoneChannel := make(chan bool, 1)
 
@@ -514,13 +514,14 @@ func (tr *TransformerJoin) ingestLeftFile() {
 		select {
 
 		case err := <-errorChannel:
-			fmt.Fprintln(os.Stderr, "mlr", ": ", err)
-			os.Exit(1)
+			// TODO: propagate error to caller
+			_ = err
+			return
 
 		case leftrecsAndContexts := <-readerChannel:
 			// TODO: temp for batch-reader refactor
-			lib.InternalCodingErrorIf(leftrecsAndContexts.Len() != 1)
-			leftrecAndContext := leftrecsAndContexts.Front().Value.(*types.RecordAndContext)
+			lib.InternalCodingErrorIf(len(leftrecsAndContexts) != 1)
+			leftrecAndContext := leftrecsAndContexts[0]
 			leftrecAndContext.Record = utils.KeepLeftFieldNames(leftrecAndContext.Record, tr.leftKeepFieldNameSet)
 
 			if leftrecAndContext.EndOfStream {
@@ -537,36 +538,33 @@ func (tr *TransformerJoin) ingestLeftFile() {
 				tr.opts.leftJoinFieldNames,
 			)
 			if ok {
-				iBucket := tr.leftBucketsByJoinFieldValues.Get(groupingKey)
-				if iBucket == nil { // New key-field-value: new bucket and hash-map entry
+				bucket := tr.leftBucketsByJoinFieldValues.Get(groupingKey)
+				if bucket == nil { // New key-field-value: new bucket and hash-map entry
 					bucket := utils.NewJoinBucket(leftFieldValues)
-					bucket.RecordsAndContexts.PushBack(leftrecAndContext)
+					bucket.RecordsAndContexts = append(bucket.RecordsAndContexts, leftrecAndContext)
 					tr.leftBucketsByJoinFieldValues.Put(groupingKey, bucket)
 				} else { // Previously seen key-field-value: append record to bucket
-					bucket := iBucket.(*utils.JoinBucket)
-					bucket.RecordsAndContexts.PushBack(leftrecAndContext)
+					bucket.RecordsAndContexts = append(bucket.RecordsAndContexts, leftrecAndContext)
 				}
 			} else {
-				tr.leftUnpairableRecordsAndContexts.PushBack(leftrecAndContext)
+				tr.leftUnpairableRecordsAndContexts = append(tr.leftUnpairableRecordsAndContexts, leftrecAndContext)
 			}
 		}
 	}
 }
 
-// ----------------------------------------------------------------
 // This helper method is used by the half-streaming/unsorted join, as well as
 // the doubly-streaming/sorted join.
 
 func (tr *TransformerJoin) formAndEmitPairs(
-	leftRecordsAndContexts *list.List,
+	leftRecordsAndContexts []*types.RecordAndContext,
 	rightRecordAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	////fmt.Println("-- pairs start") // VERBOSE
 	// Loop over each to-be-paired-with record from the left file.
-	for pe := leftRecordsAndContexts.Front(); pe != nil; pe = pe.Next() {
+	for _, leftRecordAndContext := range leftRecordsAndContexts {
 		////fmt.Println("-- pairs pe") // VERBOSE
-		leftRecordAndContext := pe.Value.(*types.RecordAndContext)
 		leftrec := leftRecordAndContext.Record
 		rightrec := rightRecordAndContext.Record
 
@@ -575,7 +573,7 @@ func (tr *TransformerJoin) formAndEmitPairs(
 
 		// Add the joined-on fields to the new output record
 		n := len(tr.opts.leftJoinFieldNames)
-		for i := 0; i < n; i++ {
+		for i := range n {
 			// These arrays are already guaranteed same-length by CLI parser
 			leftJoinFieldName := tr.opts.leftJoinFieldNames[i]
 			outputJoinFieldName := tr.opts.outputJoinFieldNames[i]
@@ -610,12 +608,11 @@ func (tr *TransformerJoin) formAndEmitPairs(
 		outrecAndContext := types.NewRecordAndContext(outrec, &context)
 
 		// Emit the new joined record on the downstream channel
-		outputRecordsAndContexts.PushBack(outrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 	}
 	////fmt.Println("-- pairs end") // VERBOSE
 }
 
-// ----------------------------------------------------------------
 // There are two kinds of left non-pair records: (a) those lacking the
 // specified join-keys -- can't possibly pair with anything on the right; (b)
 // those having the join-keys but not matching with a record on the right.
@@ -626,25 +623,18 @@ func (tr *TransformerJoin) formAndEmitPairs(
 // in the second category.
 
 func (tr *TransformerJoin) emitLeftUnpairables(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
-	// Loop over each to-be-paired-with record from the left file.
-	for pe := tr.leftUnpairableRecordsAndContexts.Front(); pe != nil; pe = pe.Next() {
-		leftRecordAndContext := pe.Value.(*types.RecordAndContext)
-		outputRecordsAndContexts.PushBack(leftRecordAndContext)
-	}
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, tr.leftUnpairableRecordsAndContexts...)
 }
 
 func (tr *TransformerJoin) emitLeftUnpairedBuckets(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	for pe := tr.leftBucketsByJoinFieldValues.Head; pe != nil; pe = pe.Next {
-		bucket := pe.Value.(*utils.JoinBucket)
+		bucket := pe.Value
 		if !bucket.WasPaired {
-			for pf := bucket.RecordsAndContexts.Front(); pf != nil; pf = pf.Next() {
-				recordAndContext := pf.Value.(*types.RecordAndContext)
-				outputRecordsAndContexts.PushBack(recordAndContext)
-			}
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, bucket.RecordsAndContexts...)
 		}
 	}
 }
