@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"sort"
@@ -13,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameMostFrequent = "most-frequent"
 const verbNameLeastFrequent = "least-frequent"
 
@@ -72,7 +70,7 @@ func transformerMostFrequentParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 	return transformerMostOrLeastFrequentParseCLI(pargi, argc, args, true, transformerMostFrequentUsage, doConstruct)
 }
 
@@ -82,7 +80,7 @@ func transformerLeastFrequentParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 	return transformerMostOrLeastFrequentParseCLI(pargi, argc, args, false, transformerLeastFrequentUsage, doConstruct)
 }
 
@@ -93,7 +91,7 @@ func transformerMostOrLeastFrequentParseCLI(
 	descending bool,
 	usageFunc TransformerUsageFunc,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -106,6 +104,7 @@ func transformerMostOrLeastFrequentParseCLI(
 	showCounts := true
 	outputFieldName := mostLeastFrequentDefaultOutputFieldName
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -118,35 +117,41 @@ func transformerMostOrLeastFrequentParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			usageFunc(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-n" {
-			maxOutputLength = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			maxOutputLength, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-b" {
 			showCounts = false
 
 		} else if opt == "-o" {
-			outputFieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			outputFieldName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			usageFunc(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if groupByFieldNames == nil {
-		usageFunc(os.Stderr)
-		os.Exit(1)
-		return nil
+		return nil, cli.VerbErrorf(verb, "-f field names required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerMostOrLeastFrequent(
@@ -157,21 +162,19 @@ func transformerMostOrLeastFrequentParseCLI(
 		descending,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerMostOrLeastFrequent struct {
 	groupByFieldNames []string
 	maxOutputLength   int64
 	showCounts        bool
 	outputFieldName   string
 	descending        bool
-	countsByGroup     *lib.OrderedMap // map[string]int
+	countsByGroup     *lib.OrderedMap[int64] // map[string]int
 	valuesForGroup    map[string][]*mlrval.Mlrval
 }
 
@@ -180,7 +183,6 @@ type tMostOrLeastFrequentSortPair struct {
 	groupingKey string
 }
 
-// ----------------------------------------------------------------
 func NewTransformerMostOrLeastFrequent(
 	groupByFieldNames []string,
 	maxOutputLength int64,
@@ -194,18 +196,16 @@ func NewTransformerMostOrLeastFrequent(
 		showCounts:        showCounts,
 		outputFieldName:   outputFieldName,
 		descending:        descending,
-		countsByGroup:     lib.NewOrderedMap(),
+		countsByGroup:     lib.NewOrderedMap[int64](),
 		valuesForGroup:    make(map[string][]*mlrval.Mlrval),
 	}
 
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerMostOrLeastFrequent) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -217,11 +217,11 @@ func (tr *TransformerMostOrLeastFrequent) Transform(
 			return
 		}
 
-		iCount := tr.countsByGroup.Get(groupingKey)
-		if iCount == nil {
+		iCount, ok := tr.countsByGroup.GetWithCheck(groupingKey)
+		if !ok {
 			tr.countsByGroup.Put(groupingKey, int64(1))
 		} else {
-			tr.countsByGroup.Put(groupingKey, iCount.(int64)+1)
+			tr.countsByGroup.Put(groupingKey, iCount+1)
 		}
 		if tr.valuesForGroup[groupingKey] == nil {
 			selectedValues, _ := inrec.GetSelectedValues(tr.groupByFieldNames)
@@ -240,7 +240,7 @@ func (tr *TransformerMostOrLeastFrequent) Transform(
 		i := 0
 		for pe := tr.countsByGroup.Head; pe != nil; pe = pe.Next {
 			groupingKey := pe.Key
-			count := pe.Value.(int64)
+			count := pe.Value
 			sortPairs[i].groupingKey = groupingKey
 			sortPairs[i].count = count
 			i++
@@ -263,10 +263,7 @@ func (tr *TransformerMostOrLeastFrequent) Transform(
 		}
 
 		// Emit top n
-		outputLength := inputLength
-		if inputLength > tr.maxOutputLength {
-			outputLength = tr.maxOutputLength
-		}
+		outputLength := min(inputLength, tr.maxOutputLength)
 		for i := int64(0); i < outputLength; i++ {
 			outrec := mlrval.NewMlrmapAsRecord()
 			groupByFieldValues := tr.valuesForGroup[sortPairs[i].groupingKey]
@@ -280,9 +277,9 @@ func (tr *TransformerMostOrLeastFrequent) Transform(
 			if tr.showCounts {
 				outrec.PutReference(tr.outputFieldName, mlrval.FromInt(sortPairs[i].count))
 			}
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // End-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // End-of-stream marker
 	}
 }
