@@ -2,7 +2,6 @@ package transformers
 
 import (
 	"bytes"
-	"container/list"
 	"fmt"
 	"os"
 	"regexp"
@@ -15,7 +14,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameNest = "nest"
 
 var NestSetup = TransformerSetup{
@@ -38,6 +36,8 @@ func transformerNestUsage(
 	fmt.Fprintf(o, "  --values,--pairs      One is required.\n")
 	fmt.Fprintf(o, "  --across-records,--across-fields One is required.\n")
 	fmt.Fprintf(o, "  -f {field name}       Required.\n")
+	fmt.Fprintf(o, "  -r {field names}      Like -f but treat arguments as a regular expression. Match all\n")
+	fmt.Fprintf(o, "                        field names and operate on each in record order. Example: `-r '^[xy]$`'.\n")
 	fmt.Fprintf(o, "  --nested-fs {string}  Defaults to \";\". Field separator for nested values.\n")
 	fmt.Fprintf(o, "  --nested-ps {string}  Defaults to \":\". Pair separator for nested key-value pairs.\n")
 	fmt.Fprintf(o, "  --evar {string}       Shorthand for --explode --values --across-records --nested-fs {string}\n")
@@ -94,7 +94,7 @@ func transformerNestParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -103,6 +103,7 @@ func transformerNestParseCLI(
 
 	// Parse local flags
 	fieldName := ""
+	doRegexes := false
 	nestedFS := ";"
 	nestedPS := ":"
 	doExplode := true
@@ -126,10 +127,22 @@ func transformerNestParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerNestUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			fieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			fieldName = s
+
+		} else if opt == "-r" {
+			doRegexes = true
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			fieldName = s
 
 		} else if opt == "--explode" || opt == "-e" {
 			doExplode = true
@@ -153,12 +166,24 @@ func transformerNestParseCLI(
 			doAcrossFieldsSpecified = true
 
 		} else if opt == "--nested-fs" || opt == "-S" {
-			nestedFS = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			nestedFS = s
 		} else if opt == "--nested-ps" || opt == "-P" {
-			nestedPS = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			nestedPS = s
 
 		} else if opt == "--evar" {
-			evfs = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			evfs = s
 			doExplode = true
 			doExplodeSpecified = true
 			doPairs = false
@@ -167,7 +192,11 @@ func transformerNestParseCLI(
 			doAcrossFieldsSpecified = true
 
 		} else if opt == "--ivar" {
-			ivfs = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			s, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			ivfs = s
 			doExplode = false
 			doExplodeSpecified = true
 			doPairs = false
@@ -177,7 +206,7 @@ func transformerNestParseCLI(
 
 		} else {
 			transformerNestUsage(os.Stderr)
-			os.Exit(1)
+			return nil, fmt.Errorf("%s %s: option \"%s\" not recognized", "mlr", verb, opt)
 		}
 	}
 
@@ -196,32 +225,36 @@ func transformerNestParseCLI(
 
 	if fieldName == "" {
 		transformerNestUsage(os.Stderr)
-		os.Exit(1)
+		return nil, fmt.Errorf("%s %s: -f or -r is required", "mlr", verb)
 	}
 	if !doExplodeSpecified {
 		transformerNestUsage(os.Stderr)
-		os.Exit(1)
+		return nil, fmt.Errorf("%s %s: --explode or --implode is required", "mlr", verb)
 	}
 	if !doPairsSpecified {
 		transformerNestUsage(os.Stderr)
-		os.Exit(1)
+		return nil, fmt.Errorf("%s %s: --values or --pairs is required", "mlr", verb)
 	}
 	if !doAcrossFieldsSpecified {
 		transformerNestUsage(os.Stderr)
-		os.Exit(1)
+		return nil, fmt.Errorf("%s %s: --across-records or --across-fields is required", "mlr", verb)
 	}
 	if doPairs && !doExplode {
 		transformerNestUsage(os.Stderr)
-		os.Exit(1)
+		return nil, fmt.Errorf("%s %s: --implode with --pairs doesn't make sense", "mlr", verb)
+	}
+	if doRegexes && !doExplode {
+		return nil, fmt.Errorf("mlr nest: -r is only supported with --explode, not --implode")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerNest(
 		fieldName,
+		doRegexes,
 		nestedFS,
 		nestedPS,
 		doExplode,
@@ -229,31 +262,32 @@ func transformerNestParseCLI(
 		doAcrossFields,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerNest struct {
 	fieldName string
 	nestedFS  string
 	nestedPS  string
 
-	// For implode across fields
+	doRegexes  bool
+	fieldRegex *regexp.Regexp // when doRegexes, for matching field names
+
+	// For implode across fields (when !doRegexes)
 	regex *regexp.Regexp
 
 	// For implode across records
-	otherKeysToOtherValuesToBuckets *lib.OrderedMap
+	otherKeysToOtherValuesToBuckets *lib.OrderedMap[*lib.OrderedMap[*tNestBucket]]
 
 	recordTransformerFunc RecordTransformerFunc
 }
 
-// ----------------------------------------------------------------
 func NewTransformerNest(
 	fieldName string,
+	doRegexes bool,
 	nestedFS string,
 	nestedPS string,
 	doExplode bool,
@@ -263,25 +297,41 @@ func NewTransformerNest(
 
 	tr := &TransformerNest{
 		fieldName: fieldName,
+		doRegexes: doRegexes,
 		nestedFS:  cli.SeparatorFromArg(nestedFS), // "pipe" -> "|", etc
 		nestedPS:  cli.SeparatorFromArg(nestedPS),
 	}
 
-	// For implode across fields
-	regexString := "^" + fieldName + "_[0-9]+$"
-	regex, err := lib.CompileMillerRegex(regexString)
-	if err != nil {
-		fmt.Fprintf(
-			os.Stderr,
-			"%s %s: cannot compile regex [%s]\n",
-			"mlr", verbNameNest, regexString,
-		)
-		os.Exit(1)
+	// For implode across fields: regex to match exploded form (e.g. x_1, x_2)
+	if doRegexes {
+		fieldRegex, err := lib.CompileMillerRegex(fieldName)
+		if err != nil {
+			fmt.Fprintf(
+				os.Stderr,
+				"%s %s: cannot compile regex [%s]\n",
+				"mlr", verbNameNest, fieldName,
+			)
+			os.Exit(1)
+		}
+		tr.fieldRegex = fieldRegex
+		// implode uses fieldRegex directly when doRegexes
+		tr.regex = fieldRegex
+	} else {
+		regexString := "^" + fieldName + "_[0-9]+$"
+		regex, err := lib.CompileMillerRegex(regexString)
+		if err != nil {
+			fmt.Fprintf(
+				os.Stderr,
+				"%s %s: cannot compile regex [%s]\n",
+				"mlr", verbNameNest, regexString,
+			)
+			os.Exit(1)
+		}
+		tr.regex = regex
 	}
-	tr.regex = regex
 
 	// For implode across records
-	tr.otherKeysToOtherValuesToBuckets = lib.NewOrderedMap()
+	tr.otherKeysToOtherValuesToBuckets = lib.NewOrderedMap[*lib.OrderedMap[*tNestBucket]]()
 
 	if doExplode {
 		if doPairs {
@@ -313,11 +363,9 @@ func NewTransformerNest(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerNest) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -325,131 +373,173 @@ func (tr *TransformerNest) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
+// getMatchingFieldNames returns field names matching tr.fieldRegex in record order.
+// When !tr.doRegexes, returns [tr.fieldName] if present, else [].
+func (tr *TransformerNest) getMatchingFieldNames(inrec *mlrval.Mlrmap) []string {
+	if !tr.doRegexes {
+		if inrec.Get(tr.fieldName) != nil {
+			return []string{tr.fieldName}
+		}
+		return nil
+	}
+	var names []string
+	for pe := inrec.Head; pe != nil; pe = pe.Next {
+		if tr.fieldRegex.MatchString(pe.Key) {
+			names = append(names, pe.Key)
+		}
+	}
+	return names
+}
+
 func (tr *TransformerNest) explodeValuesAcrossFields(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
 
 		inrec := inrecAndContext.Record
-		originalEntry := inrec.GetEntry(tr.fieldName)
-		if originalEntry == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+		fieldNames := tr.getMatchingFieldNames(inrec)
+		if len(fieldNames) == 0 {
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 
-		recordEntry := originalEntry
-		mvalue := originalEntry.Value
-		svalue := mvalue.String()
+		for _, fieldName := range fieldNames {
+			originalEntry := inrec.GetEntry(fieldName)
+			if originalEntry == nil {
+				continue
+			}
 
-		// Not lib.SplitString so 'x=' will map to 'x_1=', rather than no field at all
-		pieces := strings.Split(svalue, tr.nestedFS)
-		i := 1
-		for _, piece := range pieces {
-			key := tr.fieldName + "_" + strconv.Itoa(i)
-			value := mlrval.FromString(piece)
-			recordEntry = inrec.PutReferenceAfter(recordEntry, key, value)
-			i++
+			recordEntry := originalEntry
+			mvalue := originalEntry.Value
+			svalue := mvalue.String()
+
+			// Not lib.SplitString so 'x=' will map to 'x_1=', rather than no field at all
+			pieces := strings.Split(svalue, tr.nestedFS)
+			i := 1
+			for _, piece := range pieces {
+				key := fieldName + "_" + strconv.Itoa(i)
+				value := mlrval.FromString(piece)
+				recordEntry = inrec.PutReferenceAfter(recordEntry, key, value)
+				i++
+			}
+
+			inrec.Unlink(originalEntry)
 		}
-
-		inrec.Unlink(originalEntry)
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerNest) explodeValuesAcrossRecords(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
 		inrec := inrecAndContext.Record
-		mvalue := inrec.Get(tr.fieldName)
+		fieldNames := tr.getMatchingFieldNames(inrec)
+		if len(fieldNames) == 0 {
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
+			return
+		}
+		fieldName := fieldNames[0]
+
+		mvalue := inrec.Get(fieldName)
 		if mvalue == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 		svalue := mvalue.String()
 
 		// Not lib.SplitString so 'x=' will map to 'x=', rather than no field at all
-		pieces := strings.Split(svalue, tr.nestedFS)
-		for _, piece := range pieces {
+		pieces := strings.SplitSeq(svalue, tr.nestedFS)
+		for piece := range pieces {
 			outrec := inrec.Copy()
-			outrec.PutReference(tr.fieldName, mlrval.FromString(piece))
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+			outrec.PutReference(fieldName, mlrval.FromString(piece))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerNest) explodePairsAcrossFields(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
 
 		inrec := inrecAndContext.Record
-		originalEntry := inrec.GetEntry(tr.fieldName)
-		if originalEntry == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+		fieldNames := tr.getMatchingFieldNames(inrec)
+		if len(fieldNames) == 0 {
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 
-		mvalue := originalEntry.Value
-		svalue := mvalue.String()
-
-		recordEntry := originalEntry
-		pieces := lib.SplitString(svalue, tr.nestedFS)
-		for _, piece := range pieces {
-			pair := strings.SplitN(piece, tr.nestedPS, 2)
-			if len(pair) == 2 { // there is a pair
-				recordEntry = inrec.PutReferenceAfter(
-					recordEntry,
-					pair[0],
-					mlrval.FromString(pair[1]),
-				)
-			} else { // there is not a pair
-				recordEntry = inrec.PutReferenceAfter(
-					recordEntry,
-					tr.fieldName,
-					mlrval.FromString(piece),
-				)
+		for _, fieldName := range fieldNames {
+			originalEntry := inrec.GetEntry(fieldName)
+			if originalEntry == nil {
+				continue
 			}
-		}
 
-		inrec.Unlink(originalEntry)
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+			mvalue := originalEntry.Value
+			svalue := mvalue.String()
+
+			recordEntry := originalEntry
+			pieces := lib.SplitString(svalue, tr.nestedFS)
+			for _, piece := range pieces {
+				pair := strings.SplitN(piece, tr.nestedPS, 2)
+				if len(pair) == 2 { // there is a pair
+					recordEntry = inrec.PutReferenceAfter(
+						recordEntry,
+						pair[0],
+						mlrval.FromString(pair[1]),
+					)
+				} else { // there is not a pair
+					recordEntry = inrec.PutReferenceAfter(
+						recordEntry,
+						fieldName,
+						mlrval.FromString(piece),
+					)
+				}
+			}
+
+			inrec.Unlink(originalEntry)
+		}
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerNest) explodePairsAcrossRecords(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
 		inrec := inrecAndContext.Record
-		mvalue := inrec.Get(tr.fieldName)
+		fieldNames := tr.getMatchingFieldNames(inrec)
+		if len(fieldNames) == 0 {
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
+			return
+		}
+		fieldName := fieldNames[0]
+
+		mvalue := inrec.Get(fieldName)
 		if mvalue == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 
@@ -458,7 +548,7 @@ func (tr *TransformerNest) explodePairsAcrossRecords(
 		for _, piece := range pieces {
 			outrec := inrec.Copy()
 
-			originalEntry := outrec.GetEntry(tr.fieldName)
+			originalEntry := outrec.GetEntry(fieldName)
 
 			// Put the new field where the old one was -- unless there's already a field with the new
 			// name, in which case replace its value.
@@ -466,22 +556,21 @@ func (tr *TransformerNest) explodePairsAcrossRecords(
 			if len(pair) == 2 { // there is a pair
 				outrec.PutReferenceAfter(originalEntry, pair[0], mlrval.FromString(pair[1]))
 			} else { // there is not a pair
-				outrec.PutReferenceAfter(originalEntry, tr.fieldName, mlrval.FromString(piece))
+				outrec.PutReferenceAfter(originalEntry, fieldName, mlrval.FromString(piece))
 			}
 
 			outrec.Unlink(originalEntry)
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerNest) implodeValuesAcrossFields(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -520,17 +609,16 @@ func (tr *TransformerNest) implodeValuesAcrossFields(
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerNest) implodeValueAcrossRecords(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -539,7 +627,7 @@ func (tr *TransformerNest) implodeValueAcrossRecords(
 
 		originalEntry := inrec.GetEntry(tr.fieldName)
 		if originalEntry == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 
@@ -547,42 +635,39 @@ func (tr *TransformerNest) implodeValueAcrossRecords(
 
 		// Don't unset tr.fieldName in the record, so we can implode in-place at the end.
 		otherKeysJoined := inrec.GetKeysJoinedExcept(originalEntry)
-		var otherValuesToBuckets *lib.OrderedMap = nil
+		var otherValuesToBuckets *lib.OrderedMap[*tNestBucket] = nil
 		iOtherValuesToBuckets := tr.otherKeysToOtherValuesToBuckets.Get(otherKeysJoined)
 		if iOtherValuesToBuckets == nil {
-			otherValuesToBuckets = lib.NewOrderedMap()
+			otherValuesToBuckets = lib.NewOrderedMap[*tNestBucket]()
 			tr.otherKeysToOtherValuesToBuckets.Put(otherKeysJoined, otherValuesToBuckets)
 		} else {
-			otherValuesToBuckets = iOtherValuesToBuckets.(*lib.OrderedMap)
+			otherValuesToBuckets = iOtherValuesToBuckets
 		}
 
 		otherValuesJoined := inrec.GetValuesJoinedExcept(originalEntry)
 		var bucket *tNestBucket = nil
-		iBucket := otherValuesToBuckets.Get(otherValuesJoined)
-		if iBucket == nil {
+		bucket = otherValuesToBuckets.Get(otherValuesJoined)
+		if bucket == nil {
 			bucket = newNestBucket(inrec)
 			otherValuesToBuckets.Put(otherValuesJoined, bucket)
-		} else {
-			bucket = iBucket.(*tNestBucket)
 		}
 
 		pair := mlrval.NewMlrmapAsRecord()
 		pair.PutReference(tr.fieldName, fieldValueCopy)
-		bucket.pairs.PushBack(pair)
+		bucket.pairs = append(bucket.pairs, pair)
 
 	} else { // end of input stream
 
 		for pe := tr.otherKeysToOtherValuesToBuckets.Head; pe != nil; pe = pe.Next {
-			otherValuesToBuckets := pe.Value.(*lib.OrderedMap)
+			otherValuesToBuckets := pe.Value
 			for pf := otherValuesToBuckets.Head; pf != nil; pf = pf.Next {
 				var buffer bytes.Buffer
-				bucket := pf.Value.(*tNestBucket)
+				bucket := pf.Value
 				outrec := bucket.representative
 				bucket.representative = nil // ownership transfer
 
 				i := 0
-				for pg := bucket.pairs.Front(); pg != nil; pg = pg.Next() {
-					pr := pg.Value.(*mlrval.Mlrmap)
+				for _, pr := range bucket.pairs {
 					if i > 0 {
 						buffer.WriteString(tr.nestedFS)
 					}
@@ -592,22 +677,22 @@ func (tr *TransformerNest) implodeValueAcrossRecords(
 
 				// tr.fieldName was already present so we'll overwrite it in-place here.
 				outrec.PutReference(tr.fieldName, mlrval.FromString(buffer.String()))
-				outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
 type tNestBucket struct {
 	representative *mlrval.Mlrmap
-	pairs          *list.List
+	pairs          []*mlrval.Mlrmap
 }
 
 func newNestBucket(representative *mlrval.Mlrmap) *tNestBucket {
 	return &tNestBucket{
 		representative: representative,
-		pairs:          list.New(),
+		pairs:          []*mlrval.Mlrmap{},
 	}
 }
