@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameRemoveEmptyColumns = "remove-empty-columns"
 
 var RemoveEmptyColumnsSetup = TransformerSetup{
@@ -36,7 +34,7 @@ func transformerRemoveEmptyColumnsParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -54,54 +52,48 @@ func transformerRemoveEmptyColumnsParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerRemoveEmptyColumnsUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
-		} else {
-			transformerRemoveEmptyColumnsUsage(os.Stderr)
-			os.Exit(1)
 		}
+		return nil, cli.VerbErrorf(verbNameRemoveEmptyColumns, "option \"%s\" not recognized", opt)
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerRemoveEmptyColumns()
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerRemoveEmptyColumns struct {
-	recordsAndContexts      *list.List
+	recordsAndContexts      []*types.RecordAndContext
 	namesWithNonEmptyValues map[string]bool
 }
 
 func NewTransformerRemoveEmptyColumns() (*TransformerRemoveEmptyColumns, error) {
 	tr := &TransformerRemoveEmptyColumns{
-		recordsAndContexts:      list.New(),
+		recordsAndContexts:      []*types.RecordAndContext{},
 		namesWithNonEmptyValues: make(map[string]bool),
 	}
 	return tr, nil
 }
 
-// ---------------------------------------------------------------
-
 func (tr *TransformerRemoveEmptyColumns) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	HandleDefaultDownstreamDone(inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 	if !inrecAndContext.EndOfStream {
 		inrec := inrecAndContext.Record
-		tr.recordsAndContexts.PushBack(inrecAndContext)
+		tr.recordsAndContexts = append(tr.recordsAndContexts, inrecAndContext)
 
 		for pe := inrec.Head; pe != nil; pe = pe.Next {
 			if !pe.Value.IsVoid() {
@@ -111,8 +103,7 @@ func (tr *TransformerRemoveEmptyColumns) Transform(
 
 	} else { // end of record stream
 
-		for e := tr.recordsAndContexts.Front(); e != nil; e = e.Next() {
-			outrecAndContext := e.Value.(*types.RecordAndContext)
+		for _, outrecAndContext := range tr.recordsAndContexts {
 			outrec := outrecAndContext.Record
 
 			newrec := mlrval.NewMlrmapAsRecord()
@@ -125,9 +116,9 @@ func (tr *TransformerRemoveEmptyColumns) Transform(
 				}
 			}
 
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &outrecAndContext.Context))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &outrecAndContext.Context))
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // Emit the stream-terminating null record
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // Emit the stream-terminating null record
 	}
 }
