@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -18,7 +17,6 @@ const (
 	repeatCountFromFieldName
 )
 
-// ----------------------------------------------------------------
 const verbNameRepeat = "repeat"
 
 var RepeatSetup = TransformerSetup{
@@ -65,7 +63,7 @@ func transformerRepeatParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	repeatCountSource := repeatCountSourceUnspecified
 	repeatCount := int64(0)
@@ -76,6 +74,7 @@ func transformerRepeatParseCLI(
 	verb := args[argi]
 	argi++
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -88,30 +87,34 @@ func transformerRepeatParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerRepeatUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			repeatCount = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			repeatCount, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			repeatCountSource = repeatCountFromInt
 
 		} else if opt == "-f" {
-			repeatCountFieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			repeatCountFieldName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			repeatCountSource = repeatCountFromFieldName
 
 		} else {
-			transformerRepeatUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if repeatCountSource == repeatCountSourceUnspecified {
-		transformerRepeatUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-n or -f is required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerRepeat(
@@ -120,21 +123,18 @@ func transformerRepeatParseCLI(
 		repeatCountFieldName,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerRepeat struct {
 	repeatCount           int64
 	repeatCountFieldName  string
 	recordTransformerFunc RecordTransformerFunc
 }
 
-// ----------------------------------------------------------------
 func NewTransformerRepeat(
 	repeatCountSource tRepeatCountSource,
 	repeatCount int64,
@@ -155,11 +155,9 @@ func NewTransformerRepeat(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerRepeat) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -167,29 +165,27 @@ func (tr *TransformerRepeat) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerRepeat) repeatByCount(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	if !inrecAndContext.EndOfStream {
 		for i := int64(0); i < tr.repeatCount; i++ {
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(
 				inrecAndContext.Record.Copy(),
 				&inrecAndContext.Context,
 			))
 		}
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerRepeat) repeatByFieldName(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -203,13 +199,13 @@ func (tr *TransformerRepeat) repeatByFieldName(
 			return
 		}
 		for i := 0; i < int(repeatCount); i++ {
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(
 				inrecAndContext.Record.Copy(),
 				&inrecAndContext.Context,
 			))
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
