@@ -1,6 +1,5 @@
 package transformers
 
-// ================================================================
 // WIDE:
 //          time           X          Y           Z
 // 1  2009-01-01  0.65473572  2.4520609 -1.46570942
@@ -28,7 +27,6 @@ package transformers
 // 15 2009-01-05     Z  0.09719105
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"regexp"
@@ -40,7 +38,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameReshape = "reshape"
 
 var ReshapeSetup = TransformerSetup{
@@ -123,7 +120,7 @@ func transformerReshapeParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -136,6 +133,7 @@ func transformerReshapeParseCLI(
 	var outputFieldNames []string = nil
 	var splitOutFieldNames []string = nil
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -148,24 +146,35 @@ func transformerReshapeParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerReshapeUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-i" {
-			inputFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			inputFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-r" {
-			inputFieldRegexString := cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			inputFieldRegexString, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			if inputFieldRegexStrings == nil {
-				inputFieldRegexStrings = make([]string, 0)
+				inputFieldRegexStrings = []string{}
 			}
 			inputFieldRegexStrings = append(inputFieldRegexStrings, inputFieldRegexString)
 		} else if opt == "-o" {
-			outputFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			outputFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-s" {
-			splitOutFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			splitOutFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerReshapeUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
@@ -177,25 +186,21 @@ func transformerReshapeParseCLI(
 	if splitOutFieldNames == nil {
 		// wide to long
 		if inputFieldNames == nil && inputFieldRegexStrings == nil {
-			transformerReshapeUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "-i or -r is required for wide-to-long")
 		}
 
 		if outputFieldNames == nil {
-			transformerReshapeUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "-o is required for wide-to-long")
 		}
 		if len(outputFieldNames) != 2 {
-			transformerReshapeUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "-o must have exactly 2 field names for wide-to-long")
 		}
 		outputKeyFieldName = outputFieldNames[0]
 		outputValueFieldName = outputFieldNames[1]
 	} else {
 		// long to wide
 		if len(splitOutFieldNames) != 2 {
-			transformerReshapeUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "-s must have exactly 2 field names for long-to-wide")
 		}
 		splitOutKeyFieldName = splitOutFieldNames[0]
 		splitOutValueFieldName = splitOutFieldNames[1]
@@ -203,7 +208,7 @@ func transformerReshapeParseCLI(
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerReshape(
@@ -215,14 +220,12 @@ func transformerReshapeParseCLI(
 		splitOutValueFieldName,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerReshape struct {
 	// for wide-to-long:
 	inputFieldNames      []string
@@ -233,12 +236,11 @@ type TransformerReshape struct {
 	// for long-to-wide:
 	splitOutKeyFieldName            string
 	splitOutValueFieldName          string
-	otherKeysToOtherValuesToBuckets *lib.OrderedMap
+	otherKeysToOtherValuesToBuckets *lib.OrderedMap[*lib.OrderedMap[*tReshapeBucket]]
 
 	recordTransformerFunc RecordTransformerFunc
 }
 
-// ----------------------------------------------------------------
 func NewTransformerReshape(
 	inputFieldNames []string,
 	inputFieldRegexStrings []string,
@@ -255,7 +257,7 @@ func NewTransformerReshape(
 
 		splitOutKeyFieldName:            splitOutKeyFieldName,
 		splitOutValueFieldName:          splitOutValueFieldName,
-		otherKeysToOtherValuesToBuckets: lib.NewOrderedMap(),
+		otherKeysToOtherValuesToBuckets: lib.NewOrderedMap[*lib.OrderedMap[*tReshapeBucket]](),
 	}
 
 	if inputFieldRegexStrings != nil {
@@ -288,11 +290,9 @@ func NewTransformerReshape(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerReshape) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -300,10 +300,9 @@ func (tr *TransformerReshape) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerReshape) wideToLongNoRegex(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -324,25 +323,24 @@ func (tr *TransformerReshape) wideToLongNoRegex(
 		}
 
 		if pairs.IsEmpty() {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		} else {
 			for pf := pairs.Head; pf != nil; pf = pf.Next {
 				outrec := inrec.Copy()
 				outrec.PutReference(tr.outputKeyFieldName, mlrval.FromString(pf.Key))
 				outrec.PutReference(tr.outputValueFieldName, pf.Value)
-				outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 			}
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerReshape) wideToLongRegex(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -366,25 +364,24 @@ func (tr *TransformerReshape) wideToLongRegex(
 		}
 
 		if pairs.IsEmpty() {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		} else {
 			for pf := pairs.Head; pf != nil; pf = pf.Next {
 				outrec := inrec.Copy()
 				outrec.PutReference(tr.outputKeyFieldName, mlrval.FromString(pf.Key))
 				outrec.PutReference(tr.outputValueFieldName, pf.Value)
-				outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 			}
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerReshape) longToWide(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -394,7 +391,7 @@ func (tr *TransformerReshape) longToWide(
 		splitOutKeyFieldValue := inrec.Get(tr.splitOutKeyFieldName)
 		splitOutValueFieldValue := inrec.Get(tr.splitOutValueFieldName)
 		if splitOutKeyFieldValue == nil || splitOutValueFieldValue == nil {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 			return
 		}
 
@@ -403,24 +400,22 @@ func (tr *TransformerReshape) longToWide(
 
 		// Don't unset tr.fieldName in the record, so we can implode in-place at the end.
 		otherKeysJoined := inrec.GetKeysJoined()
-		var otherValuesToBuckets *lib.OrderedMap = nil
+		var otherValuesToBuckets *lib.OrderedMap[*tReshapeBucket] = nil
 
 		iOtherValuesToBuckets := tr.otherKeysToOtherValuesToBuckets.Get(otherKeysJoined)
 		if iOtherValuesToBuckets == nil {
-			otherValuesToBuckets = lib.NewOrderedMap()
+			otherValuesToBuckets = lib.NewOrderedMap[*tReshapeBucket]()
 			tr.otherKeysToOtherValuesToBuckets.Put(otherKeysJoined, otherValuesToBuckets)
 		} else {
-			otherValuesToBuckets = iOtherValuesToBuckets.(*lib.OrderedMap)
+			otherValuesToBuckets = iOtherValuesToBuckets
 		}
 
 		otherValuesJoined := inrec.GetValuesJoined()
 		var bucket *tReshapeBucket = nil
-		iBucket := otherValuesToBuckets.Get(otherValuesJoined)
-		if iBucket == nil {
+		bucket = otherValuesToBuckets.Get(otherValuesJoined)
+		if bucket == nil {
 			bucket = newReshapeBucket(inrec)
 			otherValuesToBuckets.Put(otherValuesJoined, bucket)
-		} else {
-			bucket = iBucket.(*tReshapeBucket)
 		}
 
 		bucket.pairs.PutCopy(splitOutKeyFieldValue.String(), splitOutValueFieldValue)
@@ -428,9 +423,9 @@ func (tr *TransformerReshape) longToWide(
 	} else {
 
 		for pe := tr.otherKeysToOtherValuesToBuckets.Head; pe != nil; pe = pe.Next {
-			otherValuesToBuckets := pe.Value.(*lib.OrderedMap)
+			otherValuesToBuckets := pe.Value
 			for pf := otherValuesToBuckets.Head; pf != nil; pf = pf.Next {
-				bucket := pf.Value.(*tReshapeBucket)
+				bucket := pf.Value
 				outrec := bucket.representative
 				bucket.representative = nil // ownership transfer
 
@@ -438,11 +433,11 @@ func (tr *TransformerReshape) longToWide(
 					outrec.PutReference(pg.Key, pg.Value)
 				}
 
-				outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, &inrecAndContext.Context))
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, &inrecAndContext.Context))
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 	}
 }
 
