@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameSample = "sample"
 
 var SampleSetup = TransformerSetup{
@@ -41,7 +39,7 @@ func transformerSampleParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -51,6 +49,7 @@ func transformerSampleParseCLI(
 	sampleCount := int64(-1)
 	var groupByFieldNames []string = nil
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -63,28 +62,32 @@ func transformerSampleParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerSampleUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-k" {
-			sampleCount = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			sampleCount, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerSampleUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if sampleCount < 0 {
-		transformerSampleUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "sample count must be non-negative")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerSample(
@@ -92,14 +95,12 @@ func transformerSampleParseCLI(
 		groupByFieldNames,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type sampleBucketType struct {
 	nalloc             int64
 	nused              int64
@@ -109,7 +110,7 @@ type sampleBucketType struct {
 type TransformerSample struct {
 	groupByFieldNames []string
 	sampleCount       int64
-	bucketsByGroup    *lib.OrderedMap
+	bucketsByGroup    *lib.OrderedMap[*sampleBucketType]
 }
 
 func NewTransformerSample(
@@ -119,16 +120,14 @@ func NewTransformerSample(
 	tr := &TransformerSample{
 		sampleCount:       sampleCount,
 		groupByFieldNames: groupByFieldNames,
-		bucketsByGroup:    lib.NewOrderedMap(),
+		bucketsByGroup:    lib.NewOrderedMap[*sampleBucketType](),
 	}
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerSample) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -143,25 +142,24 @@ func (tr *TransformerSample) Transform(
 				sampleBucket = newSampleBucket(tr.sampleCount)
 				tr.bucketsByGroup.Put(groupingKey, sampleBucket)
 			}
-			sampleBucket.(*sampleBucketType).handleRecord(inrecAndContext, inrecAndContext.Context.NR)
+			sampleBucket.handleRecord(inrecAndContext, inrecAndContext.Context.NR)
 		} // else, specified keys aren't present in this record, so ignore it
 
 	} else { // end of record stream
 
 		for pe := tr.bucketsByGroup.Head; pe != nil; pe = pe.Next {
-			sampleBucket := pe.Value.(*sampleBucketType)
+			sampleBucket := pe.Value
 			for i := int64(0); i < sampleBucket.nused; i++ {
-				outputRecordsAndContexts.PushBack(sampleBucket.recordsAndContexts[i])
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, sampleBucket.recordsAndContexts[i])
 
 			}
 		}
 
 		// Emit the stream-terminating null record
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
 
-// ----------------------------------------------------------------
 func newSampleBucket(sampleCount int64) *sampleBucketType {
 	return &sampleBucketType{
 		nalloc:             sampleCount,
@@ -170,7 +168,6 @@ func newSampleBucket(sampleCount int64) *sampleBucketType {
 	}
 }
 
-// ----------------------------------------------------------------
 // This is the reservoir-sampling algorithm.  Here we retain an input record
 // (if retained in the sample) or let it be GC'ed (if not retained in the
 // sample).
