@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameSec2GMT = "sec2gmt"
 
 var Sec2GMTSetup = TransformerSetup{
@@ -45,7 +43,7 @@ func transformerSec2GMTParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -66,7 +64,7 @@ func transformerSec2GMTParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerSec2GMTUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-1" {
 			numDecimalPlaces = 1
@@ -95,21 +93,19 @@ func transformerSec2GMTParseCLI(
 			preDivide = 1.0e9
 
 		} else {
-			transformerSec2GMTUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verbNameSec2GMT, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if argi >= argc {
-		transformerSec2GMTUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verbNameSec2GMT, "field names required")
 	}
 	fieldNames := args[argi]
 	argi++
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerSec2GMT(
@@ -118,14 +114,12 @@ func transformerSec2GMTParseCLI(
 		numDecimalPlaces,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerSec2GMT struct {
 	fieldNameList    []string
 	preDivide        float64
@@ -145,11 +139,9 @@ func NewTransformerSec2GMT(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerSec2GMT) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -169,9 +161,9 @@ func (tr *TransformerSec2GMT) Transform(
 				}
 			}
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else { // End of record stream
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
