@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameSec2GMTDate = "sec2gmtdate"
 
 var Sec2GMTDateSetup = TransformerSetup{
@@ -39,7 +37,7 @@ func transformerSec2GMTDateParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -57,38 +55,33 @@ func transformerSec2GMTDateParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerSec2GMTDateUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
-		} else {
-			transformerSec2GMTDateUsage(os.Stderr)
-			os.Exit(1)
 		}
+		return nil, cli.VerbErrorf(verbNameSec2GMTDate, "option \"%s\" not recognized", opt)
 	}
 
 	if argi >= argc {
-		transformerSec2GMTDateUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verbNameSec2GMTDate, "field names required")
 	}
 	fieldNames := args[argi]
 	argi++
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerSec2GMTDate(
 		fieldNames,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerSec2GMTDate struct {
 	fieldNameList []string
 }
@@ -102,11 +95,9 @@ func NewTransformerSec2GMTDate(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerSec2GMTDate) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -119,9 +110,9 @@ func (tr *TransformerSec2GMTDate) Transform(
 				inrec.PutReference(fieldName, bifs.BIF_sec2gmtdate(value))
 			}
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else { // End of record stream
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
