@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameShuffle = "shuffle"
 
 var ShuffleSetup = TransformerSetup{
@@ -39,7 +37,7 @@ func transformerShuffleParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -57,68 +55,61 @@ func transformerShuffleParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerShuffleUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
-		} else {
-			transformerShuffleUsage(os.Stderr)
-			os.Exit(1)
 		}
+		return nil, cli.VerbErrorf(verbNameShuffle, "option \"%s\" not recognized", opt)
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerShuffle()
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerShuffle struct {
-	recordsAndContexts *list.List
+	recordsAndContexts []*types.RecordAndContext
 }
 
 func NewTransformerShuffle() (*TransformerShuffle, error) {
 
 	tr := &TransformerShuffle{
-		recordsAndContexts: list.New(),
+		recordsAndContexts: []*types.RecordAndContext{},
 	}
 
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerShuffle) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
 	HandleDefaultDownstreamDone(inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 	// Not end of input stream: retain the record, and emit nothing until end of stream.
 	if !inrecAndContext.EndOfStream {
-		tr.recordsAndContexts.PushBack(inrecAndContext)
+		tr.recordsAndContexts = append(tr.recordsAndContexts, inrecAndContext)
 
 	} else { // end of record stream
 		// Knuth shuffle:
 		// * Initial permutation is identity.
 		// * Make a pseudorandom permutation using pseudorandom swaps in the image map.
-		// TODO: Go list Len() maxes at 2^31. We should track this ourselves in an int64.
-		n := int64(tr.recordsAndContexts.Len())
+		n := int64(len(tr.recordsAndContexts))
 		images := make([]int64, n)
-		for i := int64(0); i < n; i++ {
+		for i := range n {
 			images[i] = i
 		}
 		unusedStart := int64(0)
 		numUnused := n
-		for i := int64(0); i < n; i++ {
+		for i := range n {
 			// Select a pseudorandom element from the pool of unused images.
 			u := lib.RandRange(unusedStart, unusedStart+numUnused)
 			temp := images[u]
@@ -130,25 +121,17 @@ func (tr *TransformerShuffle) Transform(
 			numUnused--
 		}
 
-		// Move the record-pointers from linked list to array.
-		array := make([]*types.RecordAndContext, n)
-		for i := int64(0); i < n; i++ {
-			head := tr.recordsAndContexts.Front()
-			if head == nil {
-				break
-			}
-			array[i] = head.Value.(*types.RecordAndContext)
-			tr.recordsAndContexts.Remove(head)
-		}
+		// Move the record-pointers from slice to array.
+		array := tr.recordsAndContexts
 
 		// Transfer from input array to output list. Because permutations are one-to-one maps,
 		// all input records have ownership transferred exactly once. So, there are no
 		// records to copy here.
-		for i := int64(0); i < n; i++ {
-			outputRecordsAndContexts.PushBack(array[images[i]])
+		for i := range n {
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, array[images[i]])
 		}
 
 		// Emit the stream-terminating null record
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
