@@ -1,10 +1,10 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"net/url"
 	"os"
+	"path/filepath"
 	"strings"
 
 	"github.com/johnkerl/miller/v6/pkg/cli"
@@ -13,7 +13,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameSplit = "split"
 const splitDefaultOutputFileNamePrefix = "split"
 const splitDefaultFileNamePartJoiner = "_"
@@ -37,6 +36,7 @@ func transformerSplitUsage(
 Exactly one  of -m, -n, or -g must be supplied.
 --prefix {p} Specify filename prefix; default "`+splitDefaultOutputFileNamePrefix+`".
 --suffix {s} Specify filename suffix; default is from mlr output format, e.g. "csv".
+--folder {f} Specify output directory; default is current directory.
 -a           Append to existing file(s), if any, rather than overwriting.
 -v           Send records along to downstream verbs as well as splitting to files.
 -e           Do NOT URL-escape names of output files.
@@ -60,6 +60,8 @@ Same but instead of split_1.csv, split_2.csv, etc. there are test_1.dat, test_2.
   mlr --csv --from myfile.csv split -m 10 --prefix test --suffix dat
 Same, but written to the /tmp/ directory.
   mlr --csv --from myfile.csv split -m 10 --prefix /tmp/test --suffix dat
+Or using --folder:
+  mlr --csv --from myfile.csv split -m 10 --folder /tmp --prefix test --suffix dat
 
 If the shape field has values triangle and square, then there will be split_triangle.csv and split_square.csv.
   mlr --csv --from myfile.csv split -g shape
@@ -78,7 +80,7 @@ func transformerSplitParseCLI(
 	args []string,
 	mainOptions *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -96,6 +98,7 @@ func transformerSplitParseCLI(
 	var outputFileNamePrefix string = splitDefaultOutputFileNamePrefix
 	var outputFileNameSuffix string = "uninit"
 	haveOutputFileNameSuffix := false
+	var outputFolder string = ""
 
 	var localOptions *cli.TOptions = nil
 	if mainOptions != nil {
@@ -104,6 +107,7 @@ func transformerSplitParseCLI(
 	}
 
 	// Parse local flags.
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -116,26 +120,47 @@ func transformerSplitParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerSplitUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			n = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			n, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			doSize = true
 
 		} else if opt == "-m" {
-			n = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			n, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			doMod = true
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--prefix" {
-			outputFileNamePrefix = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			outputFileNamePrefix, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "--suffix" {
-			outputFileNameSuffix = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			outputFileNameSuffix, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			haveOutputFileNameSuffix = true
 
+		} else if opt == "--folder" {
+			outputFolder, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+
 		} else if opt == "-a" {
 			doAppend = true
 
@@ -146,7 +171,10 @@ func transformerSplitParseCLI(
 			escapeFileNameCharacters = false
 
 		} else if opt == "-j" {
-			fileNamePartJoiner = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			fileNamePartJoiner, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
 			// This is inelegant. For error-proofing we advance argi already in our
@@ -158,20 +186,17 @@ func transformerSplitParseCLI(
 				// Nothing else to handle here.
 				argi = largi
 			} else {
-				transformerSplitUsage(os.Stderr)
-				os.Exit(1)
+				return nil, cli.VerbErrorf(verb, "output format not recognized")
 			}
 		}
 	}
 
 	doGroup := groupByFieldNames != nil
 	if !doMod && !doSize && !doGroup {
-		fmt.Fprintf(os.Stderr, "mlr %s: At least one of -m, -n, or -g is required.\n", verb)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-n, -g, or -s is required")
 	}
 	if (doMod && doSize) || (doMod && doGroup) || (doSize && doGroup) {
-		fmt.Fprintf(os.Stderr, "mlr %s: Only one of -m, -n, or -g is required.\n", verb)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-n, -g, and -s are mutually exclusive")
 	}
 
 	cli.FinalizeWriterOptions(&localOptions.WriterOptions)
@@ -181,7 +206,7 @@ func transformerSplitParseCLI(
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerSplit(
@@ -195,6 +220,7 @@ func transformerSplitParseCLI(
 		doAppend,
 		outputFileNamePrefix,
 		outputFileNameSuffix,
+		outputFolder,
 		&localOptions.WriterOptions,
 	)
 	if err != nil {
@@ -202,14 +228,14 @@ func transformerSplitParseCLI(
 		os.Exit(1)
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerSplit struct {
 	n                        int64
 	outputFileNamePrefix     string
 	outputFileNameSuffix     string
+	outputFolder             string
 	emitDownstream           bool
 	escapeFileNameCharacters bool
 	fileNamePartJoiner       string
@@ -239,13 +265,22 @@ func NewTransformerSplit(
 	doAppend bool,
 	outputFileNamePrefix string,
 	outputFileNameSuffix string,
+	outputFolder string,
 	recordWriterOptions *cli.TWriterOptions,
 ) (*TransformerSplit, error) {
 
+	if outputFolder != "" {
+		err := os.MkdirAll(outputFolder, 0755)
+		if err != nil {
+			return nil, fmt.Errorf("mlr split: could not create output folder %s: %w", outputFolder, err)
+		}
+	}
+
 	tr := &TransformerSplit{
 		n:                        n,
 		outputFileNamePrefix:     outputFileNamePrefix,
 		outputFileNameSuffix:     outputFileNameSuffix,
+		outputFolder:             outputFolder,
 		emitDownstream:           emitDownstream,
 		escapeFileNameCharacters: escapeFileNameCharacters,
 		fileNamePartJoiner:       fileNamePartJoiner,
@@ -273,7 +308,7 @@ func NewTransformerSplit(
 
 func (tr *TransformerSplit) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -284,7 +319,7 @@ func (tr *TransformerSplit) Transform(
 
 func (tr *TransformerSplit) splitModUngrouped(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -294,18 +329,18 @@ func (tr *TransformerSplit) splitModUngrouped(
 
 		err := tr.outputHandlerManager.WriteRecordAndContext(inrecAndContext, filename)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "mlr: file-write error: %v\n", err)
+			fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 			os.Exit(1)
 		}
 
 		if tr.emitDownstream {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 
 		tr.ungroupedCounter++
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 		errs := tr.outputHandlerManager.Close()
 		if len(errs) > 0 {
 			for _, err := range errs {
@@ -318,7 +353,7 @@ func (tr *TransformerSplit) splitModUngrouped(
 
 func (tr *TransformerSplit) splitSizeUngrouped(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -330,7 +365,7 @@ func (tr *TransformerSplit) splitSizeUngrouped(
 			if tr.outputHandler != nil {
 				err = tr.outputHandler.Close()
 				if err != nil {
-					fmt.Fprintf(os.Stderr, "mlr: file-close error: %v\n", err)
+					fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 					os.Exit(1)
 				}
 			}
@@ -342,7 +377,7 @@ func (tr *TransformerSplit) splitSizeUngrouped(
 				tr.doAppend,
 			)
 			if err != nil {
-				fmt.Fprintf(os.Stderr, "mlr: file-open error: %v\n", err)
+				fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 				os.Exit(1)
 			}
 
@@ -351,23 +386,23 @@ func (tr *TransformerSplit) splitSizeUngrouped(
 
 		err = tr.outputHandler.WriteRecordAndContext(inrecAndContext)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "mlr: file-write error: %v\n", err)
+			fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 			os.Exit(1)
 		}
 
 		if tr.emitDownstream {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 
 		tr.ungroupedCounter++
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 
 		if tr.outputHandler != nil {
 			err := tr.outputHandler.Close()
 			if err != nil {
-				fmt.Fprintf(os.Stderr, "mlr: file-close error: %v\n", err)
+				fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 				os.Exit(1)
 			}
 		}
@@ -376,7 +411,7 @@ func (tr *TransformerSplit) splitSizeUngrouped(
 
 func (tr *TransformerSplit) splitGrouped(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -384,7 +419,12 @@ func (tr *TransformerSplit) splitGrouped(
 		var filename string
 		groupByFieldValues, ok := inrecAndContext.Record.GetSelectedValues(tr.groupByFieldNames)
 		if !ok {
-			filename = fmt.Sprintf("%s_ungrouped.%s", tr.outputFileNamePrefix, tr.outputFileNameSuffix)
+			baseName := fmt.Sprintf("%s_ungrouped.%s", tr.outputFileNamePrefix, tr.outputFileNameSuffix)
+			if tr.outputFolder != "" {
+				filename = filepath.Join(tr.outputFolder, baseName)
+			} else {
+				filename = baseName
+			}
 		} else {
 			filename = tr.makeGroupedOutputFileName(groupByFieldValues)
 		}
@@ -395,11 +435,11 @@ func (tr *TransformerSplit) splitGrouped(
 		}
 
 		if tr.emitDownstream {
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 
 		errs := tr.outputHandlerManager.Close()
 		if len(errs) > 0 {
@@ -411,9 +451,13 @@ func (tr *TransformerSplit) splitGrouped(
 	}
 }
 
-// makeUngroupedOutputFileName example: "split_53.csv"
+// makeUngroupedOutputFileName example: "split_53.csv" or "folder/split_53.csv" with --folder
 func (tr *TransformerSplit) makeUngroupedOutputFileName(k int64) string {
-	return fmt.Sprintf("%s_%d.%s", tr.outputFileNamePrefix, k, tr.outputFileNameSuffix)
+	baseName := fmt.Sprintf("%s_%d.%s", tr.outputFileNamePrefix, k, tr.outputFileNameSuffix)
+	if tr.outputFolder != "" {
+		return filepath.Join(tr.outputFolder, baseName)
+	}
+	return baseName
 }
 
 // makeGroupedOutputFileName example: "split_orange.csv"
@@ -436,5 +480,9 @@ func (tr *TransformerSplit) makeGroupedOutputFileName(
 		fileName = tr.outputFileNamePrefix + tr.fileNamePartJoiner + fileName
 	}
 
-	return fileName + "." + tr.outputFileNameSuffix
+	baseName := fileName + "." + tr.outputFileNameSuffix
+	if tr.outputFolder != "" {
+		return filepath.Join(tr.outputFolder, baseName)
+	}
+	return baseName
 }
