@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -13,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameStats2 = "stats2"
 
 // For joining "x" and "y" into "x...y" for map keys. "," is another natural choice but would break
@@ -58,29 +56,27 @@ func transformerStats2Usage(
 	fmt.Fprintf(o, "Example: %s %s -a corr -f x,y\n", argv0, verb)
 }
 
-// ----------------------------------------------------------------
 func transformerStats2ParseCLI(
 	pargi *int,
 	argc int,
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
 	verb := args[argi]
 	argi++
 
-	argv0 := "mlr"
-
 	var accumulatorNameList []string = nil
 	var valueFieldNameList []string = nil
-	groupByFieldNameList := make([]string, 0)
+	groupByFieldNameList := []string{}
 	doVerbose := false
 	doIterativeStats := false
 	doHoldAndFit := false
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -93,16 +89,25 @@ func transformerStats2ParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerStats2Usage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-a" {
-			accumulatorNameList = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			accumulatorNameList, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-f" {
-			valueFieldNameList = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			valueFieldNameList, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-g" {
-			groupByFieldNameList = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNameList, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-v" {
 			doVerbose = true
@@ -123,34 +128,26 @@ func transformerStats2ParseCLI(
 			// for all applicable stats2 accumulators (i.e. none of them).
 
 		} else {
-			transformerStats2Usage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if doIterativeStats && doHoldAndFit {
-		transformerStats2Usage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "cannot combine -I and -H")
 	}
 	if accumulatorNameList == nil {
-		fmt.Fprintf(os.Stderr, "%s %s: -a option is required.\n", argv0, verb)
-		fmt.Fprintf(os.Stderr, "Please see %s %s --help for more information.\n", argv0, verb)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-a option is required")
 	}
 	if valueFieldNameList == nil {
-		fmt.Fprintf(os.Stderr, "%s %s: -f option is required.\n", argv0, verb)
-		fmt.Fprintf(os.Stderr, "Please see %s %s --help for more information.\n", argv0, verb)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-f option is required")
 	}
 	if len(valueFieldNameList)%2 != 0 {
-		fmt.Fprintf(os.Stderr, "%s %s: argument to -f must have even number of fields.\n", argv0, verb)
-		fmt.Fprintf(os.Stderr, "Please see %s %s --help for more information.\n", argv0, verb)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "argument to -f must have even number of fields")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerStats2(
@@ -162,14 +159,12 @@ func transformerStats2ParseCLI(
 		doHoldAndFit,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerStats2 struct {
 	// Input:
 	accumulatorNameList  []string
@@ -188,13 +183,13 @@ type TransformerStats2 struct {
 	// This would be
 	//   namedAccumulators map[string]map[string]map[string]IStats2Accumulator
 	// except we need maps that preserve insertion order.
-	namedAccumulators *lib.OrderedMap
+	namedAccumulators *lib.OrderedMap[*lib.OrderedMap[*lib.OrderedMap[utils.IStats2Accumulator]]]
 
-	groupingKeysToGroupByFieldValues *lib.OrderedMap
+	groupingKeysToGroupByFieldValues *lib.OrderedMap[[]*mlrval.Mlrval]
 
 	// For hold-and-fit:
 	// ordered map from grouping-key to list of RecordAndContext
-	recordGroups *lib.OrderedMap
+	recordGroups *lib.OrderedMap[*[]*types.RecordAndContext]
 }
 
 func NewTransformerStats2(
@@ -207,7 +202,7 @@ func NewTransformerStats2(
 ) (*TransformerStats2, error) {
 	for _, name := range accumulatorNameList {
 		if !utils.ValidateStats2AccumulatorName(name) {
-			return nil, fmt.Errorf("mlr stats2: accumulator \"%s\" not found.", name)
+			return nil, fmt.Errorf(`mlr stats2: accumulator "%s" not found`, name)
 		}
 	}
 
@@ -219,14 +214,13 @@ func NewTransformerStats2(
 		doIterativeStats:                 doIterativeStats,
 		doHoldAndFit:                     doHoldAndFit,
 		accumulatorFactory:               utils.NewStats2AccumulatorFactory(),
-		namedAccumulators:                lib.NewOrderedMap(),
-		groupingKeysToGroupByFieldValues: lib.NewOrderedMap(),
-		recordGroups:                     lib.NewOrderedMap(),
+		namedAccumulators:                lib.NewOrderedMap[*lib.OrderedMap[*lib.OrderedMap[utils.IStats2Accumulator]]](),
+		groupingKeysToGroupByFieldValues: lib.NewOrderedMap[[]*mlrval.Mlrval](),
+		recordGroups:                     lib.NewOrderedMap[*[]*types.RecordAndContext](),
 	}
 	return tr, nil
 }
 
-// ================================================================
 // Given: accumulate corr,cov on values x,y group by a,b.
 // Example input:       Example output:
 //   a b x y            a b x_corr x_cov y_corr y_cov
@@ -259,13 +253,10 @@ func NewTransformerStats2(
 //
 // In the iterative case, add to the current record its current group's stats fields.
 // In the non-iterative case, produce output only at the end of the input stream.
-// ================================================================
-
-// ----------------------------------------------------------------
 
 func (tr *TransformerStats2) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -276,7 +267,7 @@ func (tr *TransformerStats2) Transform(
 
 		if tr.doIterativeStats {
 			// The input record is modified in this case, with new fields appended
-			outputRecordsAndContexts.PushBack(inrecAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		}
 		// if tr.doHoldAndFit, the input record is held by the ingestor
 
@@ -288,11 +279,10 @@ func (tr *TransformerStats2) Transform(
 				tr.emit(outputRecordsAndContexts, &inrecAndContext.Context)
 			}
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerStats2) ingest(
 	inrecAndContext *types.RecordAndContext,
 ) {
@@ -309,17 +299,18 @@ func (tr *TransformerStats2) ingest(
 
 	groupToValueFields := tr.namedAccumulators.Get(groupingKey)
 	if groupToValueFields == nil {
-		groupToValueFields = lib.NewOrderedMap()
+		groupToValueFields = lib.NewOrderedMap[*lib.OrderedMap[utils.IStats2Accumulator]]()
 		tr.namedAccumulators.Put(groupingKey, groupToValueFields)
 	}
 
 	if tr.doHoldAndFit { // Retain the input record in memory, for fitting and delivery at end of stream
 		groupToRecords := tr.recordGroups.Get(groupingKey)
 		if groupToRecords == nil {
-			groupToRecords = list.New()
+			records := []*types.RecordAndContext{}
+			groupToRecords = &records
 			tr.recordGroups.Put(groupingKey, groupToRecords)
 		}
-		groupToRecords.(*list.List).PushBack(inrecAndContext)
+		*groupToRecords = append(*groupToRecords, inrecAndContext)
 	}
 
 	// for [["x","y"]]
@@ -330,10 +321,10 @@ func (tr *TransformerStats2) ingest(
 
 		key := valueFieldName1 + stats2KeySeparator + valueFieldName2
 
-		valueFieldsToAccumulator := groupToValueFields.(*lib.OrderedMap).Get(key)
+		valueFieldsToAccumulator := groupToValueFields.Get(key)
 		if valueFieldsToAccumulator == nil {
-			valueFieldsToAccumulator = lib.NewOrderedMap()
-			groupToValueFields.(*lib.OrderedMap).Put(key, valueFieldsToAccumulator)
+			valueFieldsToAccumulator = lib.NewOrderedMap[utils.IStats2Accumulator]()
+			groupToValueFields.Put(key, valueFieldsToAccumulator)
 		}
 
 		mval1 := inrec.Get(valueFieldName1)
@@ -347,7 +338,7 @@ func (tr *TransformerStats2) ingest(
 
 		// for ["corr", "cov"]
 		for _, accumulatorName := range tr.accumulatorNameList {
-			accumulator := valueFieldsToAccumulator.(*lib.OrderedMap).Get(accumulatorName)
+			accumulator := valueFieldsToAccumulator.Get(accumulatorName)
 			if accumulator == nil {
 				accumulator = tr.accumulatorFactory.Make(
 					valueFieldName1,
@@ -356,14 +347,12 @@ func (tr *TransformerStats2) ingest(
 					tr.doVerbose,
 				)
 				if accumulator == nil {
-					fmt.Fprintf(os.Stderr, "%s %s: accumulator \"%s\" not found.\n",
-						"mlr", verbNameStats2, accumulatorName,
-					)
+					fmt.Fprintf(os.Stderr, "mlr stats2: accumulator creation failed\n")
 					os.Exit(1)
 				}
-				valueFieldsToAccumulator.(*lib.OrderedMap).Put(accumulatorName, accumulator)
+				valueFieldsToAccumulator.Put(accumulatorName, accumulator)
 			}
-			accumulator.(utils.IStats2Accumulator).Ingest(
+			accumulator.Ingest(
 				mval1.GetNumericToFloatValueOrDie(),
 				mval2.GetNumericToFloatValueOrDie(),
 			)
@@ -374,15 +363,14 @@ func (tr *TransformerStats2) ingest(
 				inrecAndContext.Record,
 				valueFieldName1,
 				valueFieldName2,
-				valueFieldsToAccumulator.(*lib.OrderedMap),
+				valueFieldsToAccumulator,
 			)
 		}
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerStats2) emit(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	context *types.Context,
 ) {
 	for pa := tr.namedAccumulators.Head; pa != nil; pa = pa.Next {
@@ -390,13 +378,13 @@ func (tr *TransformerStats2) emit(
 
 		// Add in a=s,b=t fields:
 		groupingKey := pa.Key
-		groupByFieldValues := tr.groupingKeysToGroupByFieldValues.Get(groupingKey).([]*mlrval.Mlrval)
+		groupByFieldValues := tr.groupingKeysToGroupByFieldValues.Get(groupingKey)
 		for i, groupByFieldName := range tr.groupByFieldNameList {
 			outrec.PutReference(groupByFieldName, groupByFieldValues[i].Copy())
 		}
 
 		// Add in fields such as x_y_corr, etc.
-		groupToValueFields := tr.namedAccumulators.Get(groupingKey).(*lib.OrderedMap)
+		groupToValueFields := tr.namedAccumulators.Get(groupingKey)
 
 		// For "x","y"
 		for pc := groupToValueFields.Head; pc != nil; pc = pc.Next {
@@ -404,18 +392,18 @@ func (tr *TransformerStats2) emit(
 			pairs := strings.Split(pc.Key, stats2KeySeparator)
 			valueFieldName1 := pairs[0]
 			valueFieldName2 := pairs[1]
-			valueFieldsToAccumulator := pc.Value.(*lib.OrderedMap)
+			valueFieldsToAccumulator := pc.Value
 
 			tr.populateRecord(outrec, valueFieldName1, valueFieldName2, valueFieldsToAccumulator)
 
 			// For "corr", "linreg"
 			for pd := valueFieldsToAccumulator.Head; pd != nil; pd = pd.Next {
-				accumulator := pd.Value.(utils.IStats2Accumulator)
+				accumulator := pd.Value
 				accumulator.Populate(valueFieldName1, valueFieldName2, outrec)
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(types.NewRecordAndContext(outrec, context))
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(outrec, context))
 	}
 }
 
@@ -423,25 +411,26 @@ func (tr *TransformerStats2) populateRecord(
 	outrec *mlrval.Mlrmap,
 	valueFieldName1 string,
 	valueFieldName2 string,
-	valueFieldsToAccumulator *lib.OrderedMap,
+	valueFieldsToAccumulator *lib.OrderedMap[utils.IStats2Accumulator],
 ) {
 	// For "corr", "linreg"
 	for pe := valueFieldsToAccumulator.Head; pe != nil; pe = pe.Next {
-		accumulator := pe.Value.(utils.IStats2Accumulator)
+		accumulator := pe.Value
 		accumulator.Populate(valueFieldName1, valueFieldName2, outrec)
 	}
 }
 
 func (tr *TransformerStats2) fit(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	for pa := tr.namedAccumulators.Head; pa != nil; pa = pa.Next {
 		groupingKey := pa.Key
-		groupToValueFields := pa.Value.(*lib.OrderedMap)
-		recordsAndContexts := tr.recordGroups.Get(groupingKey).(*list.List)
-
-		for recordsAndContexts.Front() != nil {
-			recordAndContext := recordsAndContexts.Remove(recordsAndContexts.Front()).(*types.RecordAndContext)
+		groupToValueFields := pa.Value
+		recordsAndContexts := tr.recordGroups.Get(groupingKey)
+		if recordsAndContexts == nil {
+			continue
+		}
+		for _, recordAndContext := range *recordsAndContexts {
 			record := recordAndContext.Record
 
 			// For "x","y"
@@ -449,11 +438,11 @@ func (tr *TransformerStats2) fit(
 				pairs := strings.Split(pb.Key, stats2KeySeparator)
 				valueFieldName1 := pairs[0]
 				valueFieldName2 := pairs[1]
-				valueFieldsToAccumulator := pb.Value.(*lib.OrderedMap)
+				valueFieldsToAccumulator := pb.Value
 
 				// For "linreg-ols", "logireg"
 				for pc := valueFieldsToAccumulator.Head; pc != nil; pc = pc.Next {
-					accumulator := pc.Value.(utils.IStats2Accumulator)
+					accumulator := pc.Value
 
 					// Note R2, cov, corr, etc have no non-trivial fit-function
 					mval1 := record.Get(valueFieldName1)
@@ -468,7 +457,8 @@ func (tr *TransformerStats2) fit(
 				}
 			}
 
-			outputRecordsAndContexts.PushBack(recordAndContext)
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, recordAndContext)
 		}
+		*recordsAndContexts = (*recordsAndContexts)[:0]
 	}
 }
