@@ -1,4 +1,3 @@
-// ================================================================
 // Options for the step verb are mostly simple operations involving the previous record and the
 // current record, optionally grouped by one or more group-by field names. For example, with input
 // data
@@ -63,12 +62,10 @@
 //   window object for their grouping key.  We don't know a priori when the end of the record stream
 //   is so we keep the last n records for each grouping key.  At end of the record stream we process
 //   these.
-// ================================================================
 
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -84,7 +81,6 @@ import (
 // For EWMA
 const DEFAULT_STRING_ALPHA = "0.5"
 
-// ----------------------------------------------------------------
 const verbNameStep = "step"
 
 var StepSetup = TransformerSetup{
@@ -147,7 +143,7 @@ func transformerStepParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -172,51 +168,67 @@ func transformerStepParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerStepUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-a" {
 			// Let them do '-a delta -a rsum' or '-a delta,rsum'
-			stepperNames := cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			stepperNames, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 			for _, stepperName := range stepperNames {
 				stepperInput := stepperInputFromName(stepperName)
 				if stepperInput == nil {
-					fmt.Fprintf(os.Stderr, "mlr %s: stepper \"%s\" not found.\n",
-						verbNameStep, stepperName)
-					os.Exit(1)
+					return nil, cli.VerbErrorf(verb, "stepper \"%s\" not found", stepperName)
 				}
 				stepperInputs = append(stepperInputs, stepperInput)
 			}
 
 		} else if opt == "-f" {
 			// Let them do '-f x -f y' or '-f x,y'
-			valueFieldNames = append(valueFieldNames, cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)...)
+			arr, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			valueFieldNames = append(valueFieldNames, arr...)
 
 		} else if opt == "-g" {
 			// Let them do '-g a -g b' or '-g a,b'
-			groupByFieldNames = append(groupByFieldNames, cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)...)
+			arr, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			groupByFieldNames = append(groupByFieldNames, arr...)
 
 		} else if opt == "-d" {
 			// Let them do '-d 0.8 -d 0.9' or '-d 0.8,0.9'
-			stringAlphas = append(stringAlphas, cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)...)
+			arr, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			stringAlphas = append(stringAlphas, arr...)
 
 		} else if opt == "-o" {
 			// Let them do '-o fast -o slow' or '-o fast,slow'
-			ewmaSuffixes = append(ewmaSuffixes, cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)...)
+			arr, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			ewmaSuffixes = append(ewmaSuffixes, arr...)
 
 		} else if opt == "-F" {
 			// As of Miller 6 this happens automatically, but the flag is accepted
 			// as a no-op for backward compatibility with Miller 5 and below.
 
 		} else {
-			transformerStepUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerStep(
@@ -227,14 +239,12 @@ func transformerStepParseCLI(
 		ewmaSuffixes,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 // This is the "stepper log" referred to in comments at the top of this file.
 type tStepLogEntry struct {
 	recordAndContext *types.RecordAndContext
@@ -269,7 +279,7 @@ type TransformerStep struct {
 
 	// Ordered map from stringified pointer to recordAndContext, to *tStepLogEntry,
 	// as described in comments at the top of this file.
-	log *lib.OrderedMap
+	log *lib.OrderedMap[*tStepLogEntry]
 }
 
 func NewTransformerStep(
@@ -312,13 +322,12 @@ func NewTransformerStep(
 		maxNumRecordsForward:  maxNumRecordsForward,
 		groups:                make(map[string]map[string]map[string]tStepper),
 		windowKeepers:         make(map[string]*utils.TWindowKeeper),
-		log:                   lib.NewOrderedMap(),
+		log:                   lib.NewOrderedMap[*tStepLogEntry](),
 	}
 
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
 // Multilevel hashmap structure for the `groups` field example:
 //
 // * Group-by field names = ["a", "b"]
@@ -350,7 +359,7 @@ func NewTransformerStep(
 
 func (tr *TransformerStep) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -363,14 +372,14 @@ func (tr *TransformerStep) Transform(
 		// As described in comments at the top of this file: process through all delayed-input
 		// records for shift_lead, forward-sliding-window, etc. steppers.
 		for pe := tr.log.Head; pe != nil; pe = pe.Next {
-			logEntry := pe.Value.(*tStepLogEntry)
+			logEntry := pe.Value
 			// Shift by one -- if 'current' is the 9th record and 'next' is 10th, and there's no
 			// 11th, 'current' becomes the 10th and the 'next' becomes nil.
 			logEntry.windowKeeper.Ingest(nil)
 			tr.handleDrainRecord(logEntry, outputRecordsAndContexts)
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		return
 	}
 }
@@ -381,7 +390,7 @@ func (tr *TransformerStep) Transform(
 // delayed-input records in the order in which they were received.
 func (tr *TransformerStep) handleRecord(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	inrec := inrecAndContext.Record
 
@@ -390,7 +399,7 @@ func (tr *TransformerStep) handleRecord(
 	// Grouping key is "s,t"
 	groupingKey, gok := inrec.GetSelectedValuesJoined(tr.groupByFieldNames)
 	if !gok { // current record doesn't have fields to be stepped; pass it along
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 		return
 	}
 
@@ -442,8 +451,7 @@ func (tr *TransformerStep) handleRecord(
 					tr.ewmaSuffixes,
 				)
 				if stepper == nil {
-					fmt.Fprintf(os.Stderr, "mlr %s: stepper \"%s\" not found.\n",
-						verbNameStep, stepperInput.name)
+					fmt.Fprintf(os.Stderr, "mlr step: stepper allocation failed\n")
 					os.Exit(1)
 				}
 				accFieldToAccState[stepperInput.name] = stepper
@@ -455,7 +463,7 @@ func (tr *TransformerStep) handleRecord(
 
 	if windowKeeper.Get(0) != nil {
 		outrecAndContext := windowKeeper.Get(0).(*types.RecordAndContext)
-		outputRecordsAndContexts.PushBack(outrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 		tr.removeFromLog(outrecAndContext)
 	}
 }
@@ -466,7 +474,7 @@ func (tr *TransformerStep) handleRecord(
 // delayed-input records in the order in which they were received.
 func (tr *TransformerStep) handleDrainRecord(
 	logEntry *tStepLogEntry,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	inrecAndContext := logEntry.recordAndContext
 	inrec := inrecAndContext.Record
@@ -496,7 +504,7 @@ func (tr *TransformerStep) handleDrainRecord(
 
 	if windowKeeper.Get(0) != nil {
 		outrecAndContext := windowKeeper.Get(0).(*types.RecordAndContext)
-		outputRecordsAndContexts.PushBack(outrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 	}
 }
 
@@ -535,7 +543,6 @@ func (tr *TransformerStep) makeLogKey(
 	return fmt.Sprintf("%p", inrecAndContext)
 }
 
-// ================================================================
 // Lookups for individual steppers, like "delta" or "rsum"
 
 type tStepperInputFromName func(
@@ -691,10 +698,8 @@ func allocateStepper(
 	return nil
 }
 
-// ================================================================
 // Implementations of individual steppers, like "delta" or "rsum"
 
-// ================================================================
 type tStepperDelta struct {
 	inputFieldName  string
 	outputFieldName string
@@ -751,7 +756,6 @@ func (stepper *tStepperDelta) process(
 	currec.PutCopy(stepper.outputFieldName, delta.Copy())
 }
 
-// ================================================================
 // shift is an alias for shift
 type tStepperShiftLag struct {
 	inputFieldName  string
@@ -827,7 +831,6 @@ func (stepper *tStepperShiftLag) process(
 	}
 }
 
-// ================================================================
 type tStepperShiftLead struct {
 	inputFieldName  string
 	outputFieldName string
@@ -878,7 +881,6 @@ func (stepper *tStepperShiftLead) process(
 	}
 }
 
-// ================================================================
 type tStepperFromFirst struct {
 	first           *mlrval.Mlrval
 	inputFieldName  string
@@ -928,7 +930,6 @@ func (stepper *tStepperFromFirst) process(
 	currec.PutCopy(stepper.outputFieldName, fromFirst)
 }
 
-// ================================================================
 type tStepperRatio struct {
 	inputFieldName  string
 	outputFieldName string
@@ -985,7 +986,6 @@ func (stepper *tStepperRatio) process(
 	currec.PutCopy(stepper.outputFieldName, ratio.Copy())
 }
 
-// ================================================================
 type tStepperRprod struct {
 	rprod           *mlrval.Mlrval
 	inputFieldName  string
@@ -1034,7 +1034,6 @@ func (stepper *tStepperRprod) process(
 	}
 }
 
-// ================================================================
 type tStepperRsum struct {
 	rsum            *mlrval.Mlrval
 	inputFieldName  string
@@ -1083,7 +1082,6 @@ func (stepper *tStepperRsum) process(
 	}
 }
 
-// ================================================================
 type tStepperCounter struct {
 	counter         *mlrval.Mlrval
 	inputFieldName  string
@@ -1132,7 +1130,6 @@ func (stepper *tStepperCounter) process(
 	}
 }
 
-// ================================================================
 // https://en.wikipedia.org/wiki/Moving_average#Exponential_moving_average
 
 type tStepperEWMA struct {
@@ -1233,7 +1230,6 @@ func (stepper *tStepperEWMA) process(
 	}
 }
 
-// ================================================================
 type tStepperSlwin struct {
 	inputFieldName     string
 	numRecordsBackward int
