@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -13,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameSummary = "summary"
 
 type tSummarizerType int
@@ -116,7 +114,7 @@ func transformerSummaryParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -137,6 +135,7 @@ func transformerSummaryParseCLI(
 
 	transposeOutput := false
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -149,30 +148,30 @@ func transformerSummaryParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerSummaryUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "--all" {
 			summarizerNames = allSummarizerNamesList
 
 		} else if opt == "-a" {
-			summarizerNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			summarizerNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			for _, summarizerName := range summarizerNames {
 				if !allSummarizerNamesSet[summarizerName] {
-					fmt.Fprintf(os.Stderr, "mlr %s: unrecognized summarizer name %s\n",
-						verb, summarizerName,
-					)
-					os.Exit(1)
+					return nil, cli.VerbErrorf(verb, "summarizer \"%s\" not found", summarizerName)
 				}
 			}
 
 		} else if opt == "-x" {
-			excludeSummarizerNames := cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			excludeSummarizerNames, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			for _, excludeSummarizerName := range excludeSummarizerNames {
 				if !allSummarizerNamesSet[excludeSummarizerName] {
-					fmt.Fprintf(os.Stderr, "mlr %s: unrecognized Summarizer name %s\n",
-						verb, excludeSummarizerName,
-					)
-					os.Exit(1)
+					return nil, cli.VerbErrorf(verb, "exclude summarizer \"%s\" not found", excludeSummarizerName)
 				}
 			}
 
@@ -181,7 +180,7 @@ func transformerSummaryParseCLI(
 				excludeSummarizerNamesSet[excludeSummarizerName] = true
 			}
 
-			summarizerNames = make([]string, 0)
+			summarizerNames = []string{}
 			for _, summarizerName := range allSummarizerNamesList {
 				if !excludeSummarizerNamesSet[summarizerName] {
 					summarizerNames = append(summarizerNames, summarizerName)
@@ -192,30 +191,27 @@ func transformerSummaryParseCLI(
 			transposeOutput = true
 
 		} else {
-			transformerSummaryUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerSummary(summarizerNames, transposeOutput)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type tFieldSummary struct {
 	// Needs lib.OrderedMap, not map[string]int64, for deterministic regression-test output.
 	// This is a map (a set really) rather than a single value in case of heterogeneous data.
-	fieldTypesMap *lib.OrderedMap
+	fieldTypesMap *lib.OrderedMap[int64]
 
 	accumulators map[string]utils.IStats1Accumulator
 
@@ -224,7 +220,7 @@ type tFieldSummary struct {
 
 func newFieldSummary() *tFieldSummary {
 	fieldSummary := &tFieldSummary{
-		fieldTypesMap: lib.NewOrderedMap(),
+		fieldTypesMap: lib.NewOrderedMap[int64](),
 
 		accumulators: make(map[string]utils.IStats1Accumulator),
 
@@ -253,7 +249,7 @@ func newFieldSummary() *tFieldSummary {
 }
 
 type TransformerSummary struct {
-	fieldSummaries    *lib.OrderedMap
+	fieldSummaries    *lib.OrderedMap[*tFieldSummary]
 	summarizerNames   map[string]bool
 	hasAnyPercentiles bool
 	transposeOutput   bool
@@ -265,7 +261,7 @@ func NewTransformerSummary(
 ) (*TransformerSummary, error) {
 
 	tr := &TransformerSummary{
-		fieldSummaries:  lib.NewOrderedMap(),
+		fieldSummaries:  lib.NewOrderedMap[*tFieldSummary](),
 		summarizerNames: make(map[string]bool),
 		transposeOutput: transposeOutput,
 	}
@@ -288,11 +284,9 @@ func NewTransformerSummary(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerSummary) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -316,24 +310,19 @@ func (tr *TransformerSummary) ingest(
 	for pe := inrec.Head; pe != nil; pe = pe.Next {
 		fieldName := pe.Key
 
-		iFieldSummary := tr.fieldSummaries.Get(fieldName)
-		var fieldSummary *tFieldSummary
-		if iFieldSummary == nil {
+		fieldSummary := tr.fieldSummaries.Get(fieldName)
+		if fieldSummary == nil {
 			fieldSummary = newFieldSummary()
 			tr.fieldSummaries.Put(fieldName, fieldSummary)
-		} else {
-			fieldSummary = iFieldSummary.(*tFieldSummary)
 		}
 
 		if tr.summarizerNames["field_type"] {
-			// Go generics would be grand to put into lib.OrderedMap, but not all platforms
-			// are on recent enough Go compiler versions.
 			typeName := pe.Value.GetTypeName()
-			iValue := fieldSummary.fieldTypesMap.Get(typeName)
-			if iValue == nil {
+			iValue, ok := fieldSummary.fieldTypesMap.GetWithCheck(typeName)
+			if !ok {
 				fieldSummary.fieldTypesMap.Put(typeName, int64(1))
 			} else {
-				fieldSummary.fieldTypesMap.Put(typeName, iValue.(int64)+1)
+				fieldSummary.fieldTypesMap.Put(typeName, iValue+1)
 			}
 		}
 
@@ -351,13 +340,13 @@ func (tr *TransformerSummary) ingest(
 
 func (tr *TransformerSummary) emit(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 
 	for pe := tr.fieldSummaries.Head; pe != nil; pe = pe.Next {
 		newrec := mlrval.NewMlrmapAsRecord()
 		fieldName := pe.Key
-		fieldSummary := pe.Value.(*tFieldSummary)
+		fieldSummary := pe.Value
 
 		newrec.PutCopy("field_name", mlrval.FromString(fieldName))
 
@@ -385,15 +374,15 @@ func (tr *TransformerSummary) emit(
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 	}
 
-	outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 }
 
 func (tr *TransformerSummary) emitTransposed(
 	inrecAndContext *types.RecordAndContext,
-	oracs *list.List, // list of *types.RecordAndContext
+	oracs *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	octx := &inrecAndContext.Context
 
@@ -402,7 +391,7 @@ func (tr *TransformerSummary) emitTransposed(
 		newrec := mlrval.NewMlrmapAsRecord()
 		newrec.PutCopy("field_name", mlrval.FromString("field_type"))
 		for pe := tr.fieldSummaries.Head; pe != nil; pe = pe.Next {
-			fieldSummary := pe.Value.(*tFieldSummary)
+			fieldSummary := pe.Value
 			fieldTypesList := make([]string, fieldSummary.fieldTypesMap.FieldCount)
 			i := 0
 			for pf := fieldSummary.fieldTypesMap.Head; pf != nil; pf = pf.Next {
@@ -412,7 +401,7 @@ func (tr *TransformerSummary) emitTransposed(
 			}
 			newrec.PutCopy(pe.Key, mlrval.FromString(strings.Join(fieldTypesList, "-")))
 		}
-		oracs.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+		*oracs = append(*oracs, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 	}
 
 	for _, info := range allSummarizerInfos {
@@ -423,15 +412,13 @@ func (tr *TransformerSummary) emitTransposed(
 		}
 	}
 
-	oracs.PushBack(inrecAndContext) // end-of-stream marker
+	*oracs = append(*oracs, inrecAndContext) // end-of-stream marker
 }
 
-// ----------------------------------------------------------------
-
 // maybeEmitAccumulatorTransposed is a helper method for emitTransposed,
 // for "count", "sum", "mean", etc.
 func (tr *TransformerSummary) maybeEmitAccumulatorTransposed(
-	oracs *list.List, // list of *types.RecordAndContext
+	oracs *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	octx *types.Context,
 	summarizerName string,
 ) {
@@ -439,17 +426,17 @@ func (tr *TransformerSummary) maybeEmitAccumulatorTransposed(
 		newrec := mlrval.NewMlrmapAsRecord()
 		newrec.PutCopy("field_name", mlrval.FromString(summarizerName))
 		for pe := tr.fieldSummaries.Head; pe != nil; pe = pe.Next {
-			fieldSummary := pe.Value.(*tFieldSummary)
+			fieldSummary := pe.Value
 			newrec.PutCopy(pe.Key, fieldSummary.accumulators[summarizerName].Emit())
 		}
-		oracs.PushBack(types.NewRecordAndContext(newrec, octx))
+		*oracs = append(*oracs, types.NewRecordAndContext(newrec, octx))
 	}
 }
 
 // maybeEmitPercentileNameTransposed is a helper method for emitTransposed,
 // for "median", "iqr", "uof", etc.
 func (tr *TransformerSummary) maybeEmitPercentileNameTransposed(
-	oracs *list.List, // list of *types.RecordAndContext
+	oracs *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	octx *types.Context,
 	summarizerName string,
 ) {
@@ -457,9 +444,9 @@ func (tr *TransformerSummary) maybeEmitPercentileNameTransposed(
 		newrec := mlrval.NewMlrmapAsRecord()
 		newrec.PutCopy("field_name", mlrval.FromString(summarizerName))
 		for pe := tr.fieldSummaries.Head; pe != nil; pe = pe.Next {
-			fieldSummary := pe.Value.(*tFieldSummary)
+			fieldSummary := pe.Value
 			newrec.PutCopy(pe.Key, fieldSummary.percentileKeeper.EmitNamed(summarizerName))
 		}
-		oracs.PushBack(types.NewRecordAndContext(newrec, octx))
+		*oracs = append(*oracs, types.NewRecordAndContext(newrec, octx))
 	}
 }
