@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameTail = "tail"
 
 var TailSetup = TransformerSetup{
@@ -39,7 +37,7 @@ func transformerTailParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -61,10 +59,14 @@ func transformerTailParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerTailUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			tailCount = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			n, err := cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			tailCount = n
 
 			// This is a bit of a hack. In our Getoptify routine we preprocess
 			// the command line sending '-xyz' to '-x -y -z', but leaving
@@ -77,17 +79,21 @@ func transformerTailParseCLI(
 			}
 
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			names, err := cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
+			groupByFieldNames = names
 
 		} else {
 			transformerTailUsage(os.Stderr)
-			os.Exit(1)
+			return nil, fmt.Errorf("%s %s: option \"%s\" not recognized", "mlr", verb, opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerTail(
@@ -95,22 +101,20 @@ func transformerTailParseCLI(
 		groupByFieldNames,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerTail struct {
 	// input
 	tailCount         int64
 	groupByFieldNames []string
 
 	// state
-	// map from string to *list.List
-	recordListsByGroup *lib.OrderedMap
+	// map from string to record slices
+	recordListsByGroup *lib.OrderedMap[*[]*types.RecordAndContext]
 }
 
 func NewTransformerTail(
@@ -122,17 +126,15 @@ func NewTransformerTail(
 		tailCount:         tailCount,
 		groupByFieldNames: groupByFieldNames,
 
-		recordListsByGroup: lib.NewOrderedMap(),
+		recordListsByGroup: lib.NewOrderedMap[*[]*types.RecordAndContext](),
 	}
 
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerTail) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -145,25 +147,22 @@ func (tr *TransformerTail) Transform(
 			return
 		}
 
-		irecordListForGroup := tr.recordListsByGroup.Get(groupingKey)
-		if irecordListForGroup == nil { // first time
-			irecordListForGroup = list.New()
-			tr.recordListsByGroup.Put(groupingKey, irecordListForGroup)
+		recordListForGroup := tr.recordListsByGroup.Get(groupingKey)
+		if recordListForGroup == nil { // first time
+			records := []*types.RecordAndContext{}
+			recordListForGroup = &records
+			tr.recordListsByGroup.Put(groupingKey, recordListForGroup)
 		}
-		recordListForGroup := irecordListForGroup.(*list.List)
 
-		recordListForGroup.PushBack(inrecAndContext)
-		for int64(recordListForGroup.Len()) > tr.tailCount {
-			recordListForGroup.Remove(recordListForGroup.Front())
+		*recordListForGroup = append(*recordListForGroup, inrecAndContext)
+		for int64(len(*recordListForGroup)) > tr.tailCount {
+			*recordListForGroup = (*recordListForGroup)[1:]
 		}
 
 	} else {
 		for outer := tr.recordListsByGroup.Head; outer != nil; outer = outer.Next {
-			recordListForGroup := outer.Value.(*list.List)
-			for inner := recordListForGroup.Front(); inner != nil; inner = inner.Next() {
-				outputRecordsAndContexts.PushBack(inner.Value.(*types.RecordAndContext))
-			}
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, *outer.Value...)
 		}
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
