@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -12,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameTemplate = "template"
 
 var TemplateSetup = TransformerSetup{
@@ -46,7 +44,7 @@ func transformerTemplateParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -56,6 +54,7 @@ func transformerTemplateParseCLI(
 	var fieldNames []string = nil
 	fillWith := ""
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -68,37 +67,43 @@ func transformerTemplateParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerTemplateUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			fieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			fieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-t" {
-			templateFileName := cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			templateFileName, err := cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 			temp, err := lib.ReadCSVHeader(templateFileName)
 			if err != nil {
-				fmt.Println(err)
-				os.Exit(1)
+				return nil, fmt.Errorf("mlr %s: cannot read template file: %w", verb, err)
 			}
 			fieldNames = temp
 
 		} else if opt == "--fill-with" {
-			fillWith = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			fillWith, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerTemplateUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if fieldNames == nil {
-		transformerTemplateUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-f or -t is required")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerTemplate(
@@ -106,14 +111,12 @@ func transformerTemplateParseCLI(
 		fillWith,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerTemplate struct {
 	fieldNameList []string
 	fieldNameSet  map[string]bool
@@ -131,11 +134,9 @@ func NewTransformerTemplate(
 	}, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerTemplate) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -152,8 +153,8 @@ func (tr *TransformerTemplate) Transform(
 			}
 		}
 		outrecAndContext := types.NewRecordAndContext(outrec, &inrecAndContext.Context)
-		outputRecordsAndContexts.PushBack(outrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, outrecAndContext)
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
