@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -13,7 +12,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameTop = "top"
 const verbTopDefaultOutputFieldName = "top_idx"
 
@@ -54,7 +52,7 @@ func transformerTopParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -69,6 +67,7 @@ func transformerTopParseCLI(
 	doMax := true
 	outputFieldName := verbTopDefaultOutputFieldName
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -81,14 +80,23 @@ func transformerTopParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerTopUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-n" {
-			topCount = cli.VerbGetIntArgOrDie(verb, opt, args, &argi, argc)
+			topCount, err = cli.VerbGetIntArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-f" {
-			valueFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			valueFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-g" {
-			groupByFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			groupByFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 		} else if opt == "-a" {
 			showFullRecords = true
 		} else if opt == "--max" {
@@ -98,26 +106,26 @@ func transformerTopParseCLI(
 		} else if opt == "-F" {
 			// Ignored in Miller 6; allowed for command-line backward compatibility
 		} else if opt == "-o" {
-			outputFieldName = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			outputFieldName, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerTopUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	if valueFieldNames == nil {
-		transformerTopUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-f field names required")
 	}
 	if len(valueFieldNames) > 1 && showFullRecords {
-		transformerTopUsage(os.Stderr)
-		os.Exit(1)
+		return nil, cli.VerbErrorf(verb, "-a (full records) incompatible with multiple -f fields")
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, _ := NewTransformerTop(
@@ -129,10 +137,9 @@ func transformerTopParseCLI(
 		outputFieldName,
 	)
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerTop struct {
 	topCount          int64
 	valueFieldNames   []string
@@ -143,11 +150,10 @@ type TransformerTop struct {
 
 	// Two-level map from grouping key (string of joined-together group-by field values),
 	// to string value-field name, to *utils.TopKeeper
-	groups                           *lib.OrderedMap
+	groups                           *lib.OrderedMap[*lib.OrderedMap[*utils.TopKeeper]]
 	groupingKeysToGroupByFieldValues map[string][]*mlrval.Mlrval
 }
 
-// ----------------------------------------------------------------
 func NewTransformerTop(
 	topCount int64,
 	valueFieldNames []string,
@@ -165,7 +171,7 @@ func NewTransformerTop(
 		doMax:             doMax,
 		outputFieldName:   outputFieldName,
 
-		groups:                           lib.NewOrderedMap(),
+		groups:                           lib.NewOrderedMap[*lib.OrderedMap[*utils.TopKeeper]](),
 		groupingKeysToGroupByFieldValues: make(map[string][]*mlrval.Mlrval),
 	}
 
@@ -174,7 +180,7 @@ func NewTransformerTop(
 
 func (tr *TransformerTop) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -200,13 +206,13 @@ func (tr *TransformerTop) ingest(
 		return
 	}
 	iSecondLevel := tr.groups.Get(groupingKey)
-	var secondLevel *lib.OrderedMap = nil
+	var secondLevel *lib.OrderedMap[*utils.TopKeeper] = nil
 	if iSecondLevel == nil {
-		secondLevel = lib.NewOrderedMap()
+		secondLevel = lib.NewOrderedMap[*utils.TopKeeper]()
 		tr.groups.Put(groupingKey, secondLevel)
 		tr.groupingKeysToGroupByFieldValues[groupingKey] = groupByFieldValues
 	} else {
-		secondLevel = iSecondLevel.(*lib.OrderedMap)
+		secondLevel = iSecondLevel
 	}
 
 	// for "x", "y" and "1", "2"
@@ -220,7 +226,7 @@ func (tr *TransformerTop) ingest(
 			topKeeper = utils.NewTopKeeper(tr.topCount, tr.doMax)
 			secondLevel.Put(valueFieldName, topKeeper)
 		} else {
-			topKeeper = iTopKeeper.(*utils.TopKeeper)
+			topKeeper = iTopKeeper
 		}
 
 		var maybeRecordAndContext *types.RecordAndContext = nil
@@ -235,14 +241,13 @@ func (tr *TransformerTop) ingest(
 
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerTop) emit(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
 	for pa := tr.groups.Head; pa != nil; pa = pa.Next {
 		groupingKey := pa.Key
-		secondLevel := pa.Value.(*lib.OrderedMap)
+		secondLevel := pa.Value
 		groupByFieldValues := tr.groupingKeysToGroupByFieldValues[groupingKey]
 
 		// Above we required that there be only one value field in the
@@ -250,9 +255,9 @@ func (tr *TransformerTop) emit(
 		// once, which would need a change in the format presented as output.
 		if tr.showFullRecords {
 			for pb := secondLevel.Head; pb != nil; pb = pb.Next {
-				topKeeper := pb.Value.(*utils.TopKeeper)
+				topKeeper := pb.Value
 				for i := int64(0); i < topKeeper.GetSize(); i++ {
-					outputRecordsAndContexts.PushBack(topKeeper.TopRecordsAndContexts[i].Copy())
+					*outputRecordsAndContexts = append(*outputRecordsAndContexts, topKeeper.TopRecordsAndContexts[i].Copy())
 				}
 			}
 
@@ -270,7 +275,7 @@ func (tr *TransformerTop) emit(
 				// for "x", "y"
 				for pb := secondLevel.Head; pb != nil; pb = pb.Next {
 					valueFieldName := pb.Key
-					topKeeper := pb.Value.(*utils.TopKeeper)
+					topKeeper := pb.Value
 					key := valueFieldName + "_top"
 					if i < topKeeper.GetSize() {
 						newrec.PutReference(tr.outputFieldName, mlrval.FromInt(i+1))
@@ -281,10 +286,10 @@ func (tr *TransformerTop) emit(
 					}
 				}
 
-				outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+				*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 			}
 		}
 	}
 
-	outputRecordsAndContexts.PushBack(inrecAndContext) // emit end-of-stream marker
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // emit end-of-stream marker
 }
