@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -11,7 +10,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameUnspace = "unspace"
 
 var UnspaceSetup = TransformerSetup{
@@ -39,7 +37,7 @@ func transformerUnspaceParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -49,6 +47,7 @@ func transformerUnspaceParseCLI(
 	filler := "_"
 	which := "keys_and_values"
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -61,10 +60,13 @@ func transformerUnspaceParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerUnspaceUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "-f" {
-			filler = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			filler, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-k" {
 			which = "keys_only"
@@ -73,26 +75,23 @@ func transformerUnspaceParseCLI(
 			which = "values_only"
 
 		} else {
-			transformerUnspaceUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerUnspace(filler, which)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerUnspace struct {
 	filler                string
 	recordTransformerFunc RecordTransformerFunc
@@ -115,7 +114,7 @@ func NewTransformerUnspace(
 
 func (tr *TransformerUnspace) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -128,13 +127,13 @@ func (tr *TransformerUnspace) Transform(
 			outputDownstreamDoneChannel,
 		)
 	} else { // end of record stream
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 	}
 }
 
 func (tr *TransformerUnspace) transformKeysOnly(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	_ <-chan bool,
 	__ chan<- bool,
 ) {
@@ -145,12 +144,12 @@ func (tr *TransformerUnspace) transformKeysOnly(
 		// Reference not copy since this is ownership transfer of the value from the now-abandoned inrec
 		newrec.PutReference(newkey, pe.Value)
 	}
-	outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 }
 
 func (tr *TransformerUnspace) transformValuesOnly(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	_ <-chan bool,
 	__ chan<- bool,
 ) {
@@ -161,12 +160,12 @@ func (tr *TransformerUnspace) transformValuesOnly(
 			pe.Value = mlrval.FromString(tr.unspace(stringval))
 		}
 	}
-	outputRecordsAndContexts.PushBack(types.NewRecordAndContext(inrec, &inrecAndContext.Context))
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(inrec, &inrecAndContext.Context))
 }
 
 func (tr *TransformerUnspace) transformKeysAndValues(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	_ <-chan bool,
 	__ chan<- bool,
 ) {
@@ -182,7 +181,7 @@ func (tr *TransformerUnspace) transformKeysAndValues(
 			newrec.PutReference(newkey, pe.Value)
 		}
 	}
-	outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &inrecAndContext.Context))
+	*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &inrecAndContext.Context))
 }
 
 func (tr *TransformerUnspace) unspace(input string) string {
