@@ -1,7 +1,6 @@
 package transformers
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -12,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 const verbNameUnsparsify = "unsparsify"
 
 var UnsparsifySetup = TransformerSetup{
@@ -52,7 +50,7 @@ func transformerUnsparsifyParseCLI(
 	args []string,
 	_ *cli.TOptions,
 	doConstruct bool, // false for first pass of CLI-parse, true for second pass
-) IRecordTransformer {
+) (RecordTransformer, error) {
 
 	// Skip the verb name from the current spot in the mlr command line
 	argi := *pargi
@@ -62,6 +60,7 @@ func transformerUnsparsifyParseCLI(
 	fillerString := ""
 	var specifiedFieldNames []string = nil
 
+	var err error
 	for argi < argc /* variable increment: 1 or 2 depending on flag */ {
 		opt := args[argi]
 		if !strings.HasPrefix(opt, "-") {
@@ -74,23 +73,28 @@ func transformerUnsparsifyParseCLI(
 
 		if opt == "-h" || opt == "--help" {
 			transformerUnsparsifyUsage(os.Stdout)
-			os.Exit(0)
+			return nil, cli.ErrHelpRequested
 
 		} else if opt == "--fill-with" {
-			fillerString = cli.VerbGetStringArgOrDie(verb, opt, args, &argi, argc)
+			fillerString, err = cli.VerbGetStringArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else if opt == "-f" {
-			specifiedFieldNames = cli.VerbGetStringArrayArgOrDie(verb, opt, args, &argi, argc)
+			specifiedFieldNames, err = cli.VerbGetStringArrayArg(verb, opt, args, &argi, argc)
+			if err != nil {
+				return nil, err
+			}
 
 		} else {
-			transformerUnsparsifyUsage(os.Stderr)
-			os.Exit(1)
+			return nil, cli.VerbErrorf(verb, "option \"%s\" not recognized", opt)
 		}
 	}
 
 	*pargi = argi
 	if !doConstruct { // All transformers must do this for main command-line parsing
-		return nil
+		return nil, nil
 	}
 
 	transformer, err := NewTransformerUnsparsify(
@@ -98,18 +102,16 @@ func transformerUnsparsifyParseCLI(
 		specifiedFieldNames,
 	)
 	if err != nil {
-		fmt.Fprintln(os.Stderr, err)
-		os.Exit(1)
+		return nil, err
 	}
 
-	return transformer
+	return transformer, nil
 }
 
-// ----------------------------------------------------------------
 type TransformerUnsparsify struct {
 	fillerMlrval          *mlrval.Mlrval
-	recordsAndContexts    *list.List
-	fieldNamesSeen        *lib.OrderedMap
+	recordsAndContexts    []*types.RecordAndContext
+	fieldNamesSeen        *lib.OrderedMap[string]
 	recordTransformerFunc RecordTransformerFunc
 }
 
@@ -118,14 +120,14 @@ func NewTransformerUnsparsify(
 	specifiedFieldNames []string,
 ) (*TransformerUnsparsify, error) {
 
-	fieldNamesSeen := lib.NewOrderedMap()
+	fieldNamesSeen := lib.NewOrderedMap[string]()
 	for _, specifiedFieldName := range specifiedFieldNames {
 		fieldNamesSeen.Put(specifiedFieldName, specifiedFieldName)
 	}
 
 	tr := &TransformerUnsparsify{
 		fillerMlrval:       mlrval.FromString(fillerString),
-		recordsAndContexts: list.New(),
+		recordsAndContexts: []*types.RecordAndContext{},
 		fieldNamesSeen:     fieldNamesSeen,
 	}
 
@@ -138,11 +140,9 @@ func NewTransformerUnsparsify(
 	return tr, nil
 }
 
-// ----------------------------------------------------------------
-
 func (tr *TransformerUnsparsify) Transform(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -150,10 +150,9 @@ func (tr *TransformerUnsparsify) Transform(
 	tr.recordTransformerFunc(inrecAndContext, outputRecordsAndContexts, inputDownstreamDoneChannel, outputDownstreamDoneChannel)
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerUnsparsify) transformNonStreaming(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -165,10 +164,9 @@ func (tr *TransformerUnsparsify) transformNonStreaming(
 				tr.fieldNamesSeen.Put(key, key)
 			}
 		}
-		tr.recordsAndContexts.PushBack(inrecAndContext)
+		tr.recordsAndContexts = append(tr.recordsAndContexts, inrecAndContext)
 	} else {
-		for e := tr.recordsAndContexts.Front(); e != nil; e = e.Next() {
-			outrecAndContext := e.Value.(*types.RecordAndContext)
+		for _, outrecAndContext := range tr.recordsAndContexts {
 			outrec := outrecAndContext.Record
 
 			newrec := mlrval.NewMlrmapAsRecord()
@@ -181,17 +179,16 @@ func (tr *TransformerUnsparsify) transformNonStreaming(
 				}
 			}
 
-			outputRecordsAndContexts.PushBack(types.NewRecordAndContext(newrec, &outrecAndContext.Context))
+			*outputRecordsAndContexts = append(*outputRecordsAndContexts, types.NewRecordAndContext(newrec, &outrecAndContext.Context))
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
 
-// ----------------------------------------------------------------
 func (tr *TransformerUnsparsify) transformStreaming(
 	inrecAndContext *types.RecordAndContext,
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 	inputDownstreamDoneChannel <-chan bool,
 	outputDownstreamDoneChannel chan<- bool,
 ) {
@@ -204,9 +201,9 @@ func (tr *TransformerUnsparsify) transformStreaming(
 			}
 		}
 
-		outputRecordsAndContexts.PushBack(inrecAndContext)
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext)
 
 	} else {
-		outputRecordsAndContexts.PushBack(inrecAndContext) // end-of-stream marker
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, inrecAndContext) // end-of-stream marker
 	}
 }
