@@ -1,19 +1,15 @@
-// ================================================================
 // Helper data structure for the join verb
-// ================================================================
 
 package utils
 
 import (
-	"container/list"
-
 	"github.com/johnkerl/miller/v6/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 type JoinBucket struct {
 	leftFieldValues    []*mlrval.Mlrval
-	RecordsAndContexts *list.List
+	RecordsAndContexts []*types.RecordAndContext
 	WasPaired          bool
 }
 
@@ -22,7 +18,7 @@ func NewJoinBucket(
 ) *JoinBucket {
 	return &JoinBucket{
 		leftFieldValues:    leftFieldValues,
-		RecordsAndContexts: list.New(),
+		RecordsAndContexts: []*types.RecordAndContext{},
 		WasPaired:          false,
 	}
 }
