@@ -1,4 +1,3 @@
-// ================================================================
 // JOIN_BUCKET_KEEPER
 //
 // This data structure supports Miller's sorted (double-streaming) join.  It is
@@ -40,7 +39,6 @@
 // * the right record with R=f is unpaired, and
 // * the left records with L=c and L=d are unpaired.
 //
-// ----------------------------------------------------------------
 // Now for the sorted (doubly-streaming) case. Here we require that the left
 // and right files be already sorted (lexically ascending) by the join fields.
 // Then the example inputs look like this:
@@ -103,12 +101,10 @@
 // * right record has R==f; left records with L==e are unpaired.
 // * etc.
 //
-// ================================================================
 
 package utils
 
 import (
-	"container/list"
 	"fmt"
 	"os"
 	"strings"
@@ -120,13 +116,12 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/types"
 )
 
-// ----------------------------------------------------------------
 // Data stored in this class
 type JoinBucketKeeper struct {
 	// For streaming through the left-side file
 	recordReader  input.IRecordReader
 	context       *types.Context
-	readerChannel <-chan *list.List // list of *types.RecordAndContext
+	readerChannel <-chan []*types.RecordAndContext // list of *types.RecordAndContext
 	errorChannel  chan error
 	// TODO: merge with leof flag
 	recordReaderDone bool
@@ -152,13 +147,12 @@ type JoinBucketKeeper struct {
 
 	peekRecordAndContext *types.RecordAndContext
 	JoinBucket           *JoinBucket
-	leftUnpaireds        *list.List
+	leftUnpaireds        []*types.RecordAndContext
 
 	leof  bool
 	state tJoinBucketKeeperState
 }
 
-// ----------------------------------------------------------------
 func NewJoinBucketKeeper(
 	// TODO prepipe string,
 	leftFileName string,
@@ -170,7 +164,7 @@ func NewJoinBucketKeeper(
 	// Instantiate the record-reader
 	recordReader, err := input.Create(joinReaderOptions, 1) // TODO: maybe increase records per batch
 	if err != nil {
-		fmt.Fprintf(os.Stderr, "mlr join: %v", err)
+		fmt.Fprintf(os.Stderr, "mlr join: %v\n", err)
 		os.Exit(1)
 	}
 
@@ -181,7 +175,7 @@ func NewJoinBucketKeeper(
 	initialContext.UpdateForStartOfFile(leftFileName)
 
 	// Set up channels for the record-reader
-	readerChannel := make(chan *list.List, 2) // list of *types.RecordAndContext
+	readerChannel := make(chan []*types.RecordAndContext, 2) // list of *types.RecordAndContext
 	errorChannel := make(chan error, 1)
 	downstreamDoneChannel := make(chan bool, 1)
 
@@ -201,7 +195,7 @@ func NewJoinBucketKeeper(
 
 		JoinBucket:           NewJoinBucket(nil),
 		peekRecordAndContext: nil,
-		leftUnpaireds:        list.New(),
+		leftUnpaireds:        []*types.RecordAndContext{},
 
 		leof:  false,
 		state: LEFT_STATE_0_PREFILL,
@@ -210,7 +204,6 @@ func NewJoinBucketKeeper(
 	return keeper
 }
 
-// ----------------------------------------------------------------
 // For JoinBucketKeeper state machine
 type tJoinBucketKeeperState int
 
@@ -229,19 +222,16 @@ func (keeper *JoinBucketKeeper) computeState() tJoinBucketKeeperState {
 	if keeper.JoinBucket.leftFieldValues == nil {
 		if !keeper.leof {
 			return LEFT_STATE_0_PREFILL
-		} else {
-			return LEFT_STATE_3_EOF
 		}
+		return LEFT_STATE_3_EOF
+	}
+	if keeper.peekRecordAndContext == nil {
+		return LEFT_STATE_2_LAST_BUCKET
 	} else {
-		if keeper.peekRecordAndContext == nil {
-			return LEFT_STATE_2_LAST_BUCKET
-		} else {
-			return LEFT_STATE_1_FULL
-		}
+		return LEFT_STATE_1_FULL
 	}
 }
 
-// ----------------------------------------------------------------
 // This is the main entry point for the join verb.  Given the right-field
 // values from the current right-file record, this method finds left-file
 // join-bucket (if any) and points keeper.JoinBucket at it.
@@ -289,7 +279,7 @@ func (keeper *JoinBucketKeeper) FindJoinBucket(
 				}
 
 				// TODO: privatize more
-				if keeper.JoinBucket.RecordsAndContexts.Len() > 0 {
+				if len(keeper.JoinBucket.RecordsAndContexts) > 0 {
 					cmp := compareLexically(
 						keeper.JoinBucket.leftFieldValues,
 						rightFieldValues,
@@ -328,7 +318,6 @@ func (keeper *JoinBucketKeeper) FindJoinBucket(
 	return isPaired
 }
 
-// ----------------------------------------------------------------
 // This finds the first peek record which possesses all the necessary join-field
 // keys.  Any other records found along the way, lacking the necessary
 // join-field keys, are moved to the left-unpaired list.
@@ -344,7 +333,7 @@ func (keeper *JoinBucketKeeper) prepareForFirstJoinBucket() {
 		if keeper.peekRecordAndContext.Record.HasSelectedKeys(keeper.leftJoinFieldNames) {
 			break
 		}
-		keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+		keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 	}
 
 	if keeper.peekRecordAndContext == nil {
@@ -353,7 +342,6 @@ func (keeper *JoinBucketKeeper) prepareForFirstJoinBucket() {
 	}
 }
 
-// ----------------------------------------------------------------
 // After right-file input has moved past the current join-bucket, this finds
 // the next peek record which possesses all the necessary join-field keys.  Any
 // other records found along the way, lacking the necessary join-field keys,
@@ -374,7 +362,7 @@ func (keeper *JoinBucketKeeper) prepareForNewJoinBucket(
 	rightFieldValues []*mlrval.Mlrval,
 ) {
 	if !keeper.JoinBucket.WasPaired {
-		moveRecordsAndContexts(keeper.leftUnpaireds, keeper.JoinBucket.RecordsAndContexts)
+		moveRecordsAndContexts(&keeper.leftUnpaireds, &keeper.JoinBucket.RecordsAndContexts)
 	}
 	keeper.JoinBucket = NewJoinBucket(nil)
 
@@ -401,7 +389,7 @@ func (keeper *JoinBucketKeeper) prepareForNewJoinBucket(
 	// Keep seeking and filling the bucket until = or >; this may or may not
 	// end up being a match.
 	for {
-		keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+		keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 		keeper.peekRecordAndContext = nil
 
 		for {
@@ -416,7 +404,7 @@ func (keeper *JoinBucketKeeper) prepareForNewJoinBucket(
 			if peekRec.HasSelectedKeys(keeper.leftJoinFieldNames) {
 				break
 			}
-			keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+			keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 		}
 
 		// Double break from double for-loop
@@ -439,7 +427,6 @@ func (keeper *JoinBucketKeeper) prepareForNewJoinBucket(
 	}
 }
 
-// ----------------------------------------------------------------
 // This takes the peek record and forms a complete join-bucket with all records
 // having its join-field values. E.g. if the join-field is "id" and the peek
 // record has id=5, it's moved to a new join bucket with id=5 and all other
@@ -470,7 +457,7 @@ func (keeper *JoinBucketKeeper) fillNextJoinBucket() {
 	}
 
 	keeper.JoinBucket.leftFieldValues = mlrval.CopyMlrvalArray(peekFieldValues)
-	keeper.JoinBucket.RecordsAndContexts.PushBack(keeper.peekRecordAndContext)
+	keeper.JoinBucket.RecordsAndContexts = append(keeper.JoinBucket.RecordsAndContexts, keeper.peekRecordAndContext)
 	keeper.JoinBucket.WasPaired = false
 
 	keeper.peekRecordAndContext = nil
@@ -497,26 +484,25 @@ func (keeper *JoinBucketKeeper) fillNextJoinBucket() {
 			if cmp != 0 {
 				break
 			}
-			keeper.JoinBucket.RecordsAndContexts.PushBack(keeper.peekRecordAndContext)
+			keeper.JoinBucket.RecordsAndContexts = append(keeper.JoinBucket.RecordsAndContexts, keeper.peekRecordAndContext)
 		} else {
-			keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+			keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 		}
 		keeper.peekRecordAndContext = nil
 	}
 }
 
-// ----------------------------------------------------------------
 // TODO: comment
 func (keeper *JoinBucketKeeper) markRemainingsAsUnpaired() {
 	// 1. Any records already in keeper.JoinBucket.records (current bucket)
 	if !keeper.JoinBucket.WasPaired {
-		moveRecordsAndContexts(keeper.leftUnpaireds, keeper.JoinBucket.RecordsAndContexts)
+		moveRecordsAndContexts(&keeper.leftUnpaireds, &keeper.JoinBucket.RecordsAndContexts)
 	}
 	keeper.JoinBucket.RecordsAndContexts = nil
 
 	// 2. Peek-record, if any
 	if keeper.peekRecordAndContext != nil {
-		keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+		keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 		keeper.peekRecordAndContext = nil
 	}
 
@@ -526,42 +512,29 @@ func (keeper *JoinBucketKeeper) markRemainingsAsUnpaired() {
 		if keeper.peekRecordAndContext == nil {
 			break
 		}
-		keeper.leftUnpaireds.PushBack(keeper.peekRecordAndContext)
+		keeper.leftUnpaireds = append(keeper.leftUnpaireds, keeper.peekRecordAndContext)
 	}
 }
 
-// ----------------------------------------------------------------
 // TODO: comment
 func (keeper *JoinBucketKeeper) OutputAndReleaseLeftUnpaireds(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
-	for {
-		element := keeper.leftUnpaireds.Front()
-		if element == nil {
-			break
-		}
-		recordAndContext := element.Value.(*types.RecordAndContext)
-		outputRecordsAndContexts.PushBack(recordAndContext)
-		keeper.leftUnpaireds.Remove(element)
+	for len(keeper.leftUnpaireds) > 0 {
+		recordAndContext := keeper.leftUnpaireds[0]
+		*outputRecordsAndContexts = append(*outputRecordsAndContexts, recordAndContext)
+		keeper.leftUnpaireds = keeper.leftUnpaireds[1:]
 	}
 }
 
 func (keeper *JoinBucketKeeper) ReleaseLeftUnpaireds(
-	outputRecordsAndContexts *list.List, // list of *types.RecordAndContext
+	outputRecordsAndContexts *[]*types.RecordAndContext, // list of *types.RecordAndContext
 ) {
-	for {
-		element := keeper.leftUnpaireds.Front()
-		if element == nil {
-			break
-		}
-		keeper.leftUnpaireds.Remove(element)
-	}
+	keeper.leftUnpaireds = keeper.leftUnpaireds[:0]
 }
 
-// ================================================================
 // HELPER FUNCTIONS
 
-// ----------------------------------------------------------------
 // Method to get the next left-file record from the record-reader goroutine.
 // Returns nil at EOF.
 
@@ -572,42 +545,33 @@ func (keeper *JoinBucketKeeper) readRecord() *types.RecordAndContext {
 
 	select {
 	case err := <-keeper.errorChannel:
-		fmt.Fprintln(os.Stderr, "mlr", ": ", err)
+		fmt.Fprintf(os.Stderr, "mlr: %v\n", err)
 		os.Exit(1)
 	case leftrecsAndContexts := <-keeper.readerChannel:
 		// TODO: temp
-		lib.InternalCodingErrorIf(leftrecsAndContexts.Len() != 1)
-		leftrecAndContext := leftrecsAndContexts.Front().Value.(*types.RecordAndContext)
+		lib.InternalCodingErrorIf(len(leftrecsAndContexts) != 1)
+		leftrecAndContext := leftrecsAndContexts[0]
 		leftrecAndContext.Record = KeepLeftFieldNames(leftrecAndContext.Record, keeper.leftKeepFieldNameSet)
 		if leftrecAndContext.EndOfStream { // end-of-stream marker
 			keeper.recordReaderDone = true
 			return nil
-		} else {
-			return leftrecAndContext
 		}
+		return leftrecAndContext
 	}
 
 	return nil
 }
 
-// ----------------------------------------------------------------
 // Pops everything off second-argument list and push to first-argument list.
 
 func moveRecordsAndContexts(
-	destination *list.List,
-	source *list.List,
+	destination *[]*types.RecordAndContext,
+	source *[]*types.RecordAndContext,
 ) {
-	for {
-		element := source.Front()
-		if element == nil {
-			break
-		}
-		destination.PushBack(element.Value.(*types.RecordAndContext))
-		source.Remove(element)
-	}
+	*destination = append(*destination, (*source)...)
+	*source = (*source)[:0]
 }
 
-// ----------------------------------------------------------------
 // Returns -1, 0, 1 as left <, ==, > right, using lexical comparison only (even
 // for numerical values).
 
@@ -617,7 +581,7 @@ func compareLexically(
 ) int {
 	lib.InternalCodingErrorIf(len(leftFieldValues) != len(rightFieldValues))
 	n := len(leftFieldValues)
-	for i := 0; i < n; i++ {
+	for i := range n {
 		left := leftFieldValues[i].String()
 		right := rightFieldValues[i].String()
 		// Returns -1, 0, 1 as left <, ==, > right
@@ -639,15 +603,14 @@ func KeepLeftFieldNames(
 	} else if leftKeepFieldNameSet == nil {
 		// Normal case
 		return inrec
-	} else {
-		outrec := mlrval.NewMlrmap()
-		for pe := inrec.Head; pe != nil; pe = pe.Next {
-			if leftKeepFieldNameSet[pe.Key] {
-				// PutReference, not PutCopy, since the inrec will be freed and this
-				// is an ownership transfer.
-				outrec.PutReference(pe.Key, pe.Value)
-			}
-		}
-		return outrec
 	}
+	outrec := mlrval.NewMlrmap()
+	for pe := inrec.Head; pe != nil; pe = pe.Next {
+		if leftKeepFieldNameSet[pe.Key] {
+			// PutReference, not PutCopy, since the inrec will be freed and this
+			// is an ownership transfer.
+			outrec.PutReference(pe.Key, pe.Value)
+		}
+	}
+	return outrec
 }
