@@ -1,6 +1,4 @@
-// ================================================================
 // For stats2
-// ================================================================
 
 package utils
 
@@ -13,7 +11,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
-// ----------------------------------------------------------------
 type IStats2Accumulator interface {
 	Ingest(
 		x float64,
@@ -84,7 +81,6 @@ var stats2AccumulatorInfos []stats2AccumulatorInfo = []stats2AccumulatorInfo{
 	},
 }
 
-// ----------------------------------------------------------------
 type Stats2AccumulatorFactory struct {
 }
 
@@ -109,7 +105,7 @@ func ValidateStats2AccumulatorName(
 	return false
 }
 
-func (factory *Stats2AccumulatorFactory) Make(
+func (fac *Stats2AccumulatorFactory) Make(
 	valueFieldName1 string,
 	valueFieldName2 string,
 	accumulatorName string,
@@ -124,7 +120,6 @@ func (factory *Stats2AccumulatorFactory) Make(
 	return nil
 }
 
-// ================================================================
 type Stats2LinRegOLSAccumulator struct {
 	count              int64
 	sumx               float64
@@ -216,7 +211,6 @@ func (acc *Stats2LinRegOLSAccumulator) Fit(
 	}
 }
 
-// ================================================================
 const LOGIREG_DVECTOR_INITIAL_SIZE = 16
 
 type Stats2LogiRegAccumulator struct {
@@ -300,7 +294,6 @@ func (acc *Stats2LogiRegAccumulator) Fit(
 	}
 }
 
-// ================================================================
 // http://en.wikipedia.org/wiki/Pearson_product-moment_correlation_coefficient
 // Alternatively, just use sqrt(corr) as defined above.
 
@@ -375,7 +368,6 @@ func (acc *Stats2R2Accumulator) Fit(
 ) {
 }
 
-// ================================================================
 // Shared code for Corr, Cov, CovX, and LinRegPCA.
 // Corr(X,Y) = Cov(X,Y) / sigma_X sigma_Y.
 
@@ -426,7 +418,6 @@ type Stats2CorrCovAccumulator struct {
 	q        float64
 }
 
-// ----------------------------------------------------------------
 func NewStats2CorrCovAccumulator(
 	valueFieldName1 string,
 	valueFieldName2 string,
@@ -556,9 +547,9 @@ func (acc *Stats2CorrCovAccumulator) Populate(
 
 			l1, l2, v1, v2 := lib.GetRealSymmetricEigensystem(Q)
 
-			x_mean := acc.sumx / float64(acc.count)
-			y_mean := acc.sumy / float64(acc.count)
-			m, b, q := lib.GetLinearRegressionPCA(l1, l2, v1, v2, x_mean, y_mean)
+			xMean := acc.sumx / float64(acc.count)
+			yMean := acc.sumy / float64(acc.count)
+			m, b, q := lib.GetLinearRegressionPCA(l1, l2, v1, v2, xMean, yMean)
 
 			outrec.PutReference(keym, mlrval.FromFloat(m))
 			outrec.PutReference(keyb, mlrval.FromFloat(b))
@@ -612,9 +603,9 @@ func (acc *Stats2CorrCovAccumulator) Fit(
 
 		l1, l2, v1, v2 := lib.GetRealSymmetricEigensystem(Q)
 
-		x_mean := acc.sumx / float64(acc.count)
-		y_mean := acc.sumy / float64(acc.count)
-		acc.m, acc.b, acc.q = lib.GetLinearRegressionPCA(l1, l2, v1, v2, x_mean, y_mean)
+		xMean := acc.sumx / float64(acc.count)
+		yMean := acc.sumy / float64(acc.count)
+		acc.m, acc.b, acc.q = lib.GetLinearRegressionPCA(l1, l2, v1, v2, xMean, yMean)
 
 		acc.fitReady = true
 	}
@@ -626,7 +617,6 @@ func (acc *Stats2CorrCovAccumulator) Fit(
 	}
 }
 
-// ================================================================
 func NewStats2CorrAccumulator(
 	valueFieldName1 string,
 	valueFieldName2 string,
