@@ -1,7 +1,5 @@
-// ================================================================
 // Support for things like 'num x = $a + $b' in the DSL, wherein we check types
 // at assignment time.
-// ================================================================
 
 package types
 
@@ -11,7 +9,6 @@ import (
 	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
-// ----------------------------------------------------------------
 type TypeGatedMlrvalName struct {
 	Name     string
 	TypeName string
@@ -24,7 +21,7 @@ func NewTypeGatedMlrvalName(
 ) (*TypeGatedMlrvalName, error) {
 	typeMask, ok := mlrval.TypeNameToMask(typeName)
 	if !ok {
-		return nil, fmt.Errorf("mlr: couldn't resolve type name \"%s\".", typeName)
+		return nil, fmt.Errorf(`couldn't resolve type name "%s"`, typeName)
 	}
 	return &TypeGatedMlrvalName{
 		Name:     name,
@@ -37,15 +34,13 @@ func (tname *TypeGatedMlrvalName) Check(value *mlrval.Mlrval) error {
 	bit := value.GetTypeBit()
 	if bit&tname.TypeMask != 0 {
 		return nil
-	} else {
-		return fmt.Errorf(
-			"mlr: couldn't assign variable %s %s from value %s %s\n",
-			tname.TypeName, tname.Name, value.GetTypeName(), value.String(),
-		)
 	}
+	return fmt.Errorf(
+		"couldn't assign variable %s %s from value %s %s",
+		tname.TypeName, tname.Name, value.GetTypeName(), value.String(),
+	)
 }
 
-// ----------------------------------------------------------------
 type TypeGatedMlrvalVariable struct {
 	typeGatedMlrvalName *TypeGatedMlrvalName
 	value               *mlrval.Mlrval
@@ -72,18 +67,10 @@ func NewTypeGatedMlrvalVariable(
 	}, nil
 }
 
-func (tvar *TypeGatedMlrvalVariable) GetName() string {
-	return tvar.typeGatedMlrvalName.Name
-}
-
 func (tvar *TypeGatedMlrvalVariable) GetValue() *mlrval.Mlrval {
 	return tvar.value
 }
 
-func (tvar *TypeGatedMlrvalVariable) ValueString() string {
-	return tvar.value.String()
-}
-
 func (tvar *TypeGatedMlrvalVariable) Assign(value *mlrval.Mlrval) error {
 	err := tvar.typeGatedMlrvalName.Check(value)
 	if err != nil {
